if not modules then modules = { } end modules ['char-emj'] = {
    version   = 1.001,
    comment   = "companion to char-ini.mkiv",
    author    = "Hans Hagen, PRAGMA-ADE, Hasselt NL",
    copyright = "PRAGMA ADE / ConTeXt Development Team",
    license   = "see context related readme files",
    dataonly  = true,
}

-- This table is generated.

return {
 ["1st place medal"]={ 0x1F947 },
 ["2nd place medal"]={ 0x1F948 },
 ["3rd place medal"]={ 0x1F949 },
 ["a button (blood type)"]={ 0x1F170, 0xFE0F },
 ["ab button (blood type)"]={ 0x1F18E },
 ["abacus"]={ 0x1F9EE },
 ["accordion"]={ 0x1FA97 },
 ["adhesive bandage"]={ 0x1FA79 },
 ["admission tickets"]={ 0x1F39F, 0xFE0F },
 ["aerial tramway"]={ 0x1F6A1 },
 ["airplane"]={ 0x2708, 0xFE0F },
 ["airplane arrival"]={ 0x1F6EC },
 ["airplane departure"]={ 0x1F6EB },
 ["alarm clock"]={ 0x23F0 },
 ["alembic"]={ 0x2697, 0xFE0F },
 ["alien"]={ 0x1F47D },
 ["alien monster"]={ 0x1F47E },
 ["ambulance"]={ 0x1F691 },
 ["american football"]={ 0x1F3C8 },
 ["amphora"]={ 0x1F3FA },
 ["anatomical heart"]={ 0x1FAC0 },
 ["anchor"]={ 0x2693 },
 ["anger symbol"]={ 0x1F4A2 },
 ["angry face"]={ 0x1F620 },
 ["angry face with horns"]={ 0x1F47F },
 ["anguished face"]={ 0x1F627 },
 ["ant"]={ 0x1F41C },
 ["antenna bars"]={ 0x1F4F6 },
 ["anxious face with sweat"]={ 0x1F630 },
 ["aquarius"]={ 0x2652 },
 ["aries"]={ 0x2648 },
 ["articulated lorry"]={ 0x1F69B },
 ["artist"]={ 0x1F9D1, 0x200D, 0x1F3A8 },
 ["artist palette"]={ 0x1F3A8 },
 ["artist: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F3A8 },
 ["artist: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F3A8 },
 ["artist: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F3A8 },
 ["artist: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F3A8 },
 ["artist: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F3A8 },
 ["astonished face"]={ 0x1F632 },
 ["astronaut"]={ 0x1F9D1, 0x200D, 0x1F680 },
 ["astronaut: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F680 },
 ["astronaut: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F680 },
 ["astronaut: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F680 },
 ["astronaut: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F680 },
 ["astronaut: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F680 },
 ["atm sign"]={ 0x1F3E7 },
 ["atom symbol"]={ 0x269B, 0xFE0F },
 ["auto rickshaw"]={ 0x1F6FA },
 ["automobile"]={ 0x1F697 },
 ["avocado"]={ 0x1F951 },
 ["axe"]={ 0x1FA93 },
 ["b button (blood type)"]={ 0x1F171, 0xFE0F },
 ["baby"]={ 0x1F476 },
 ["baby angel"]={ 0x1F47C },
 ["baby angel: dark skin tone"]={ 0x1F47C, 0x1F3FF },
 ["baby angel: light skin tone"]={ 0x1F47C, 0x1F3FB },
 ["baby angel: medium skin tone"]={ 0x1F47C, 0x1F3FD },
 ["baby angel: medium-dark skin tone"]={ 0x1F47C, 0x1F3FE },
 ["baby angel: medium-light skin tone"]={ 0x1F47C, 0x1F3FC },
 ["baby bottle"]={ 0x1F37C },
 ["baby chick"]={ 0x1F424 },
 ["baby symbol"]={ 0x1F6BC },
 ["baby: dark skin tone"]={ 0x1F476, 0x1F3FF },
 ["baby: light skin tone"]={ 0x1F476, 0x1F3FB },
 ["baby: medium skin tone"]={ 0x1F476, 0x1F3FD },
 ["baby: medium-dark skin tone"]={ 0x1F476, 0x1F3FE },
 ["baby: medium-light skin tone"]={ 0x1F476, 0x1F3FC },
 ["back arrow"]={ 0x1F519 },
 ["backhand index pointing down"]={ 0x1F447 },
 ["backhand index pointing down: dark skin tone"]={ 0x1F447, 0x1F3FF },
 ["backhand index pointing down: light skin tone"]={ 0x1F447, 0x1F3FB },
 ["backhand index pointing down: medium skin tone"]={ 0x1F447, 0x1F3FD },
 ["backhand index pointing down: medium-dark skin tone"]={ 0x1F447, 0x1F3FE },
 ["backhand index pointing down: medium-light skin tone"]={ 0x1F447, 0x1F3FC },
 ["backhand index pointing left"]={ 0x1F448 },
 ["backhand index pointing left: dark skin tone"]={ 0x1F448, 0x1F3FF },
 ["backhand index pointing left: light skin tone"]={ 0x1F448, 0x1F3FB },
 ["backhand index pointing left: medium skin tone"]={ 0x1F448, 0x1F3FD },
 ["backhand index pointing left: medium-dark skin tone"]={ 0x1F448, 0x1F3FE },
 ["backhand index pointing left: medium-light skin tone"]={ 0x1F448, 0x1F3FC },
 ["backhand index pointing right"]={ 0x1F449 },
 ["backhand index pointing right: dark skin tone"]={ 0x1F449, 0x1F3FF },
 ["backhand index pointing right: light skin tone"]={ 0x1F449, 0x1F3FB },
 ["backhand index pointing right: medium skin tone"]={ 0x1F449, 0x1F3FD },
 ["backhand index pointing right: medium-dark skin tone"]={ 0x1F449, 0x1F3FE },
 ["backhand index pointing right: medium-light skin tone"]={ 0x1F449, 0x1F3FC },
 ["backhand index pointing up"]={ 0x1F446 },
 ["backhand index pointing up: dark skin tone"]={ 0x1F446, 0x1F3FF },
 ["backhand index pointing up: light skin tone"]={ 0x1F446, 0x1F3FB },
 ["backhand index pointing up: medium skin tone"]={ 0x1F446, 0x1F3FD },
 ["backhand index pointing up: medium-dark skin tone"]={ 0x1F446, 0x1F3FE },
 ["backhand index pointing up: medium-light skin tone"]={ 0x1F446, 0x1F3FC },
 ["backpack"]={ 0x1F392 },
 ["bacon"]={ 0x1F953 },
 ["badger"]={ 0x1F9A1 },
 ["badminton"]={ 0x1F3F8 },
 ["bagel"]={ 0x1F96F },
 ["baggage claim"]={ 0x1F6C4 },
 ["baguette bread"]={ 0x1F956 },
 ["balance scale"]={ 0x2696, 0xFE0F },
 ["ballet shoes"]={ 0x1FA70 },
 ["balloon"]={ 0x1F388 },
 ["ballot box with ballot"]={ 0x1F5F3, 0xFE0F },
 ["banana"]={ 0x1F34C },
 ["banjo"]={ 0x1FA95 },
 ["bank"]={ 0x1F3E6 },
 ["bar chart"]={ 0x1F4CA },
 ["barber pole"]={ 0x1F488 },
 ["baseball"]={ 0x26BE },
 ["basket"]={ 0x1F9FA },
 ["basketball"]={ 0x1F3C0 },
 ["bat"]={ 0x1F987 },
 ["bathtub"]={ 0x1F6C1 },
 ["battery"]={ 0x1F50B },
 ["beach with umbrella"]={ 0x1F3D6, 0xFE0F },
 ["beaming face with smiling eyes"]={ 0x1F601 },
 ["bear"]={ 0x1F43B },
 ["beating heart"]={ 0x1F493 },
 ["beaver"]={ 0x1F9AB },
 ["bed"]={ 0x1F6CF, 0xFE0F },
 ["beer mug"]={ 0x1F37A },
 ["beetle"]={ 0x1FAB2 },
 ["bell"]={ 0x1F514 },
 ["bell pepper"]={ 0x1FAD1 },
 ["bell with slash"]={ 0x1F515 },
 ["bellhop bell"]={ 0x1F6CE, 0xFE0F },
 ["bento box"]={ 0x1F371 },
 ["beverage box"]={ 0x1F9C3 },
 ["bicycle"]={ 0x1F6B2 },
 ["bikini"]={ 0x1F459 },
 ["billed cap"]={ 0x1F9E2 },
 ["biohazard"]={ 0x2623, 0xFE0F },
 ["bird"]={ 0x1F426 },
 ["birthday cake"]={ 0x1F382 },
 ["bison"]={ 0x1F9AC },
 ["black cat"]={ 0x1F408, 0x200D, 0x2B1B },
 ["black circle"]={ 0x26AB },
 ["black flag"]={ 0x1F3F4 },
 ["black heart"]={ 0x1F5A4 },
 ["black large square"]={ 0x2B1B },
 ["black medium square"]={ 0x25FC, 0xFE0F },
 ["black medium-small square"]={ 0x25FE },
 ["black nib"]={ 0x2712, 0xFE0F },
 ["black small square"]={ 0x25AA, 0xFE0F },
 ["black square button"]={ 0x1F532 },
 ["blossom"]={ 0x1F33C },
 ["blowfish"]={ 0x1F421 },
 ["blue book"]={ 0x1F4D8 },
 ["blue circle"]={ 0x1F535 },
 ["blue heart"]={ 0x1F499 },
 ["blue square"]={ 0x1F7E6 },
 ["blueberries"]={ 0x1FAD0 },
 ["boar"]={ 0x1F417 },
 ["bomb"]={ 0x1F4A3 },
 ["bone"]={ 0x1F9B4 },
 ["bookmark"]={ 0x1F516 },
 ["bookmark tabs"]={ 0x1F4D1 },
 ["books"]={ 0x1F4DA },
 ["boomerang"]={ 0x1FA83 },
 ["bottle with popping cork"]={ 0x1F37E },
 ["bouquet"]={ 0x1F490 },
 ["bow and arrow"]={ 0x1F3F9 },
 ["bowl with spoon"]={ 0x1F963 },
 ["bowling"]={ 0x1F3B3 },
 ["boxing glove"]={ 0x1F94A },
 ["boy"]={ 0x1F466 },
 ["boy: dark skin tone"]={ 0x1F466, 0x1F3FF },
 ["boy: light skin tone"]={ 0x1F466, 0x1F3FB },
 ["boy: medium skin tone"]={ 0x1F466, 0x1F3FD },
 ["boy: medium-dark skin tone"]={ 0x1F466, 0x1F3FE },
 ["boy: medium-light skin tone"]={ 0x1F466, 0x1F3FC },
 ["brain"]={ 0x1F9E0 },
 ["bread"]={ 0x1F35E },
 ["breast-feeding"]={ 0x1F931 },
 ["breast-feeding: dark skin tone"]={ 0x1F931, 0x1F3FF },
 ["breast-feeding: light skin tone"]={ 0x1F931, 0x1F3FB },
 ["breast-feeding: medium skin tone"]={ 0x1F931, 0x1F3FD },
 ["breast-feeding: medium-dark skin tone"]={ 0x1F931, 0x1F3FE },
 ["breast-feeding: medium-light skin tone"]={ 0x1F931, 0x1F3FC },
 ["brick"]={ 0x1F9F1 },
 ["bridge at night"]={ 0x1F309 },
 ["briefcase"]={ 0x1F4BC },
 ["briefs"]={ 0x1FA72 },
 ["bright button"]={ 0x1F506 },
 ["broccoli"]={ 0x1F966 },
 ["broken heart"]={ 0x1F494 },
 ["broom"]={ 0x1F9F9 },
 ["brown circle"]={ 0x1F7E4 },
 ["brown heart"]={ 0x1F90E },
 ["brown square"]={ 0x1F7EB },
 ["bubble tea"]={ 0x1F9CB },
 ["bucket"]={ 0x1FAA3 },
 ["bug"]={ 0x1F41B },
 ["building construction"]={ 0x1F3D7, 0xFE0F },
 ["bullet train"]={ 0x1F685 },
 ["burrito"]={ 0x1F32F },
 ["bus"]={ 0x1F68C },
 ["bus stop"]={ 0x1F68F },
 ["bust in silhouette"]={ 0x1F464 },
 ["busts in silhouette"]={ 0x1F465 },
 ["butter"]={ 0x1F9C8 },
 ["butterfly"]={ 0x1F98B },
 ["cactus"]={ 0x1F335 },
 ["calendar"]={ 0x1F4C5 },
 ["call me hand"]={ 0x1F919 },
 ["call me hand: dark skin tone"]={ 0x1F919, 0x1F3FF },
 ["call me hand: light skin tone"]={ 0x1F919, 0x1F3FB },
 ["call me hand: medium skin tone"]={ 0x1F919, 0x1F3FD },
 ["call me hand: medium-dark skin tone"]={ 0x1F919, 0x1F3FE },
 ["call me hand: medium-light skin tone"]={ 0x1F919, 0x1F3FC },
 ["camel"]={ 0x1F42A },
 ["camera"]={ 0x1F4F7 },
 ["camera with flash"]={ 0x1F4F8 },
 ["camping"]={ 0x1F3D5, 0xFE0F },
 ["cancer"]={ 0x264B },
 ["candle"]={ 0x1F56F, 0xFE0F },
 ["candy"]={ 0x1F36C },
 ["canned food"]={ 0x1F96B },
 ["canoe"]={ 0x1F6F6 },
 ["capricorn"]={ 0x2651 },
 ["card file box"]={ 0x1F5C3, 0xFE0F },
 ["card index"]={ 0x1F4C7 },
 ["card index dividers"]={ 0x1F5C2, 0xFE0F },
 ["carousel horse"]={ 0x1F3A0 },
 ["carp streamer"]={ 0x1F38F },
 ["carpentry saw"]={ 0x1FA9A },
 ["carrot"]={ 0x1F955 },
 ["castle"]={ 0x1F3F0 },
 ["cat"]={ 0x1F408 },
 ["cat face"]={ 0x1F431 },
 ["cat with tears of joy"]={ 0x1F639 },
 ["cat with wry smile"]={ 0x1F63C },
 ["chains"]={ 0x26D3, 0xFE0F },
 ["chair"]={ 0x1FA91 },
 ["chart decreasing"]={ 0x1F4C9 },
 ["chart increasing"]={ 0x1F4C8 },
 ["chart increasing with yen"]={ 0x1F4B9 },
 ["check box with check"]={ 0x2611, 0xFE0F },
 ["check mark"]={ 0x2714, 0xFE0F },
 ["check mark button"]={ 0x2705 },
 ["cheese wedge"]={ 0x1F9C0 },
 ["chequered flag"]={ 0x1F3C1 },
 ["cherries"]={ 0x1F352 },
 ["cherry blossom"]={ 0x1F338 },
 ["chess pawn"]={ 0x265F, 0xFE0F },
 ["chestnut"]={ 0x1F330 },
 ["chicken"]={ 0x1F414 },
 ["child"]={ 0x1F9D2 },
 ["child: dark skin tone"]={ 0x1F9D2, 0x1F3FF },
 ["child: light skin tone"]={ 0x1F9D2, 0x1F3FB },
 ["child: medium skin tone"]={ 0x1F9D2, 0x1F3FD },
 ["child: medium-dark skin tone"]={ 0x1F9D2, 0x1F3FE },
 ["child: medium-light skin tone"]={ 0x1F9D2, 0x1F3FC },
 ["children crossing"]={ 0x1F6B8 },
 ["chipmunk"]={ 0x1F43F, 0xFE0F },
 ["chocolate bar"]={ 0x1F36B },
 ["chopsticks"]={ 0x1F962 },
 ["christmas tree"]={ 0x1F384 },
 ["church"]={ 0x26EA },
 ["cigarette"]={ 0x1F6AC },
 ["cinema"]={ 0x1F3A6 },
 ["circled m"]={ 0x24C2, 0xFE0F },
 ["circus tent"]={ 0x1F3AA },
 ["cityscape"]={ 0x1F3D9, 0xFE0F },
 ["cityscape at dusk"]={ 0x1F306 },
 ["cl button"]={ 0x1F191 },
 ["clamp"]={ 0x1F5DC, 0xFE0F },
 ["clapper board"]={ 0x1F3AC },
 ["clapping hands"]={ 0x1F44F },
 ["clapping hands: dark skin tone"]={ 0x1F44F, 0x1F3FF },
 ["clapping hands: light skin tone"]={ 0x1F44F, 0x1F3FB },
 ["clapping hands: medium skin tone"]={ 0x1F44F, 0x1F3FD },
 ["clapping hands: medium-dark skin tone"]={ 0x1F44F, 0x1F3FE },
 ["clapping hands: medium-light skin tone"]={ 0x1F44F, 0x1F3FC },
 ["classical building"]={ 0x1F3DB, 0xFE0F },
 ["clinking beer mugs"]={ 0x1F37B },
 ["clinking glasses"]={ 0x1F942 },
 ["clipboard"]={ 0x1F4CB },
 ["clockwise vertical arrows"]={ 0x1F503 },
 ["closed book"]={ 0x1F4D5 },
 ["closed mailbox with lowered flag"]={ 0x1F4EA },
 ["closed mailbox with raised flag"]={ 0x1F4EB },
 ["closed umbrella"]={ 0x1F302 },
 ["cloud"]={ 0x2601, 0xFE0F },
 ["cloud with lightning"]={ 0x1F329, 0xFE0F },
 ["cloud with lightning and rain"]={ 0x26C8, 0xFE0F },
 ["cloud with rain"]={ 0x1F327, 0xFE0F },
 ["cloud with snow"]={ 0x1F328, 0xFE0F },
 ["clown face"]={ 0x1F921 },
 ["club suit"]={ 0x2663, 0xFE0F },
 ["clutch bag"]={ 0x1F45D },
 ["coat"]={ 0x1F9E5 },
 ["cockroach"]={ 0x1FAB3 },
 ["cocktail glass"]={ 0x1F378 },
 ["coconut"]={ 0x1F965 },
 ["coffin"]={ 0x26B0, 0xFE0F },
 ["coin"]={ 0x1FA99 },
 ["cold face"]={ 0x1F976 },
 ["collision"]={ 0x1F4A5 },
 ["comet"]={ 0x2604, 0xFE0F },
 ["compass"]={ 0x1F9ED },
 ["computer disk"]={ 0x1F4BD },
 ["computer mouse"]={ 0x1F5B1, 0xFE0F },
 ["confetti ball"]={ 0x1F38A },
 ["confounded face"]={ 0x1F616 },
 ["confused face"]={ 0x1F615 },
 ["construction"]={ 0x1F6A7 },
 ["construction worker"]={ 0x1F477 },
 ["construction worker: dark skin tone"]={ 0x1F477, 0x1F3FF },
 ["construction worker: light skin tone"]={ 0x1F477, 0x1F3FB },
 ["construction worker: medium skin tone"]={ 0x1F477, 0x1F3FD },
 ["construction worker: medium-dark skin tone"]={ 0x1F477, 0x1F3FE },
 ["construction worker: medium-light skin tone"]={ 0x1F477, 0x1F3FC },
 ["control knobs"]={ 0x1F39B, 0xFE0F },
 ["convenience store"]={ 0x1F3EA },
 ["cook"]={ 0x1F9D1, 0x200D, 0x1F373 },
 ["cook: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F373 },
 ["cook: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F373 },
 ["cook: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F373 },
 ["cook: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F373 },
 ["cook: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F373 },
 ["cooked rice"]={ 0x1F35A },
 ["cookie"]={ 0x1F36A },
 ["cooking"]={ 0x1F373 },
 ["cool button"]={ 0x1F192 },
 ["copyright"]={ 0xA9, 0xFE0F },
 ["couch and lamp"]={ 0x1F6CB, 0xFE0F },
 ["counterclockwise arrows button"]={ 0x1F504 },
 ["couple with heart"]={ 0x1F491 },
 ["couple with heart: man, man"]={ 0x1F468, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F468 },
 ["couple with heart: woman, man"]={ 0x1F469, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F468 },
 ["couple with heart: woman, woman"]={ 0x1F469, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F469 },
 ["cow"]={ 0x1F404 },
 ["cow face"]={ 0x1F42E },
 ["cowboy hat face"]={ 0x1F920 },
 ["crab"]={ 0x1F980 },
 ["crayon"]={ 0x1F58D, 0xFE0F },
 ["credit card"]={ 0x1F4B3 },
 ["crescent moon"]={ 0x1F319 },
 ["cricket"]={ 0x1F997 },
 ["cricket game"]={ 0x1F3CF },
 ["crocodile"]={ 0x1F40A },
 ["croissant"]={ 0x1F950 },
 ["cross mark"]={ 0x274C },
 ["cross mark button"]={ 0x274E },
 ["crossed fingers"]={ 0x1F91E },
 ["crossed fingers: dark skin tone"]={ 0x1F91E, 0x1F3FF },
 ["crossed fingers: light skin tone"]={ 0x1F91E, 0x1F3FB },
 ["crossed fingers: medium skin tone"]={ 0x1F91E, 0x1F3FD },
 ["crossed fingers: medium-dark skin tone"]={ 0x1F91E, 0x1F3FE },
 ["crossed fingers: medium-light skin tone"]={ 0x1F91E, 0x1F3FC },
 ["crossed flags"]={ 0x1F38C },
 ["crossed swords"]={ 0x2694, 0xFE0F },
 ["crown"]={ 0x1F451 },
 ["crying cat"]={ 0x1F63F },
 ["crying face"]={ 0x1F622 },
 ["crystal ball"]={ 0x1F52E },
 ["cucumber"]={ 0x1F952 },
 ["cup with straw"]={ 0x1F964 },
 ["cupcake"]={ 0x1F9C1 },
 ["curling stone"]={ 0x1F94C },
 ["curly loop"]={ 0x27B0 },
 ["currency exchange"]={ 0x1F4B1 },
 ["curry rice"]={ 0x1F35B },
 ["custard"]={ 0x1F36E },
 ["customs"]={ 0x1F6C3 },
 ["cut of meat"]={ 0x1F969 },
 ["cyclone"]={ 0x1F300 },
 ["dagger"]={ 0x1F5E1, 0xFE0F },
 ["dango"]={ 0x1F361 },
 ["dashing away"]={ 0x1F4A8 },
 ["deaf man"]={ 0x1F9CF, 0x200D, 0x2642, 0xFE0F },
 ["deaf man: dark skin tone"]={ 0x1F9CF, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["deaf man: light skin tone"]={ 0x1F9CF, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["deaf man: medium skin tone"]={ 0x1F9CF, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["deaf man: medium-dark skin tone"]={ 0x1F9CF, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["deaf man: medium-light skin tone"]={ 0x1F9CF, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["deaf person"]={ 0x1F9CF },
 ["deaf person: dark skin tone"]={ 0x1F9CF, 0x1F3FF },
 ["deaf person: light skin tone"]={ 0x1F9CF, 0x1F3FB },
 ["deaf person: medium skin tone"]={ 0x1F9CF, 0x1F3FD },
 ["deaf person: medium-dark skin tone"]={ 0x1F9CF, 0x1F3FE },
 ["deaf person: medium-light skin tone"]={ 0x1F9CF, 0x1F3FC },
 ["deaf woman"]={ 0x1F9CF, 0x200D, 0x2640, 0xFE0F },
 ["deaf woman: dark skin tone"]={ 0x1F9CF, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["deaf woman: light skin tone"]={ 0x1F9CF, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["deaf woman: medium skin tone"]={ 0x1F9CF, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["deaf woman: medium-dark skin tone"]={ 0x1F9CF, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["deaf woman: medium-light skin tone"]={ 0x1F9CF, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["deciduous tree"]={ 0x1F333 },
 ["deer"]={ 0x1F98C },
 ["delivery truck"]={ 0x1F69A },
 ["department store"]={ 0x1F3EC },
 ["derelict house"]={ 0x1F3DA, 0xFE0F },
 ["desert"]={ 0x1F3DC, 0xFE0F },
 ["desert island"]={ 0x1F3DD, 0xFE0F },
 ["desktop computer"]={ 0x1F5A5, 0xFE0F },
 ["detective"]={ 0x1F575, 0xFE0F },
 ["detective: dark skin tone"]={ 0x1F575, 0x1F3FF },
 ["detective: light skin tone"]={ 0x1F575, 0x1F3FB },
 ["detective: medium skin tone"]={ 0x1F575, 0x1F3FD },
 ["detective: medium-dark skin tone"]={ 0x1F575, 0x1F3FE },
 ["detective: medium-light skin tone"]={ 0x1F575, 0x1F3FC },
 ["diamond suit"]={ 0x2666, 0xFE0F },
 ["diamond with a dot"]={ 0x1F4A0 },
 ["dim button"]={ 0x1F505 },
 ["direct hit"]={ 0x1F3AF },
 ["disappointed face"]={ 0x1F61E },
 ["disguised face"]={ 0x1F978 },
 ["divide"]={ 0x2797 },
 ["diving mask"]={ 0x1F93F },
 ["diya lamp"]={ 0x1FA94 },
 ["dizzy"]={ 0x1F4AB },
 ["dizzy face"]={ 0x1F635 },
 ["dna"]={ 0x1F9EC },
 ["dodo"]={ 0x1F9A4 },
 ["dog"]={ 0x1F415 },
 ["dog face"]={ 0x1F436 },
 ["dollar banknote"]={ 0x1F4B5 },
 ["dolphin"]={ 0x1F42C },
 ["door"]={ 0x1F6AA },
 ["dotted six-pointed star"]={ 0x1F52F },
 ["double curly loop"]={ 0x27BF },
 ["double exclamation mark"]={ 0x203C, 0xFE0F },
 ["doughnut"]={ 0x1F369 },
 ["dove"]={ 0x1F54A, 0xFE0F },
 ["down arrow"]={ 0x2B07, 0xFE0F },
 ["down-left arrow"]={ 0x2199, 0xFE0F },
 ["down-right arrow"]={ 0x2198, 0xFE0F },
 ["downcast face with sweat"]={ 0x1F613 },
 ["downwards button"]={ 0x1F53D },
 ["dragon"]={ 0x1F409 },
 ["dragon face"]={ 0x1F432 },
 ["dress"]={ 0x1F457 },
 ["drooling face"]={ 0x1F924 },
 ["drop of blood"]={ 0x1FA78 },
 ["droplet"]={ 0x1F4A7 },
 ["drum"]={ 0x1F941 },
 ["duck"]={ 0x1F986 },
 ["dumpling"]={ 0x1F95F },
 ["dvd"]={ 0x1F4C0 },
 ["e-mail"]={ 0x1F4E7 },
 ["eagle"]={ 0x1F985 },
 ["ear"]={ 0x1F442 },
 ["ear of corn"]={ 0x1F33D },
 ["ear with hearing aid"]={ 0x1F9BB },
 ["ear with hearing aid: dark skin tone"]={ 0x1F9BB, 0x1F3FF },
 ["ear with hearing aid: light skin tone"]={ 0x1F9BB, 0x1F3FB },
 ["ear with hearing aid: medium skin tone"]={ 0x1F9BB, 0x1F3FD },
 ["ear with hearing aid: medium-dark skin tone"]={ 0x1F9BB, 0x1F3FE },
 ["ear with hearing aid: medium-light skin tone"]={ 0x1F9BB, 0x1F3FC },
 ["ear: dark skin tone"]={ 0x1F442, 0x1F3FF },
 ["ear: light skin tone"]={ 0x1F442, 0x1F3FB },
 ["ear: medium skin tone"]={ 0x1F442, 0x1F3FD },
 ["ear: medium-dark skin tone"]={ 0x1F442, 0x1F3FE },
 ["ear: medium-light skin tone"]={ 0x1F442, 0x1F3FC },
 ["egg"]={ 0x1F95A },
 ["eggplant"]={ 0x1F346 },
 ["eight o’clock"]={ 0x1F557 },
 ["eight-pointed star"]={ 0x2734, 0xFE0F },
 ["eight-spoked asterisk"]={ 0x2733, 0xFE0F },
 ["eight-thirty"]={ 0x1F563 },
 ["eject button"]={ 0x23CF, 0xFE0F },
 ["electric plug"]={ 0x1F50C },
 ["elephant"]={ 0x1F418 },
 ["elevator"]={ 0x1F6D7 },
 ["eleven o’clock"]={ 0x1F55A },
 ["eleven-thirty"]={ 0x1F566 },
 ["elf"]={ 0x1F9DD },
 ["elf: dark skin tone"]={ 0x1F9DD, 0x1F3FF },
 ["elf: light skin tone"]={ 0x1F9DD, 0x1F3FB },
 ["elf: medium skin tone"]={ 0x1F9DD, 0x1F3FD },
 ["elf: medium-dark skin tone"]={ 0x1F9DD, 0x1F3FE },
 ["elf: medium-light skin tone"]={ 0x1F9DD, 0x1F3FC },
 ["end arrow"]={ 0x1F51A },
 ["envelope"]={ 0x2709, 0xFE0F },
 ["envelope with arrow"]={ 0x1F4E9 },
 ["euro banknote"]={ 0x1F4B6 },
 ["evergreen tree"]={ 0x1F332 },
 ["ewe"]={ 0x1F411 },
 ["exclamation mark"]={ 0x2757 },
 ["exclamation question mark"]={ 0x2049, 0xFE0F },
 ["exploding head"]={ 0x1F92F },
 ["expressionless face"]={ 0x1F611 },
 ["eye"]={ 0x1F441, 0xFE0F },
 ["eye in speech bubble"]={ 0x1F441, 0xFE0F, 0x200D, 0x1F5E8, 0xFE0F },
 ["eyes"]={ 0x1F440 },
 ["face blowing a kiss"]={ 0x1F618 },
 ["face savoring food"]={ 0x1F60B },
 ["face screaming in fear"]={ 0x1F631 },
 ["face vomiting"]={ 0x1F92E },
 ["face with hand over mouth"]={ 0x1F92D },
 ["face with head-bandage"]={ 0x1F915 },
 ["face with medical mask"]={ 0x1F637 },
 ["face with monocle"]={ 0x1F9D0 },
 ["face with open mouth"]={ 0x1F62E },
 ["face with raised eyebrow"]={ 0x1F928 },
 ["face with rolling eyes"]={ 0x1F644 },
 ["face with steam from nose"]={ 0x1F624 },
 ["face with symbols on mouth"]={ 0x1F92C },
 ["face with tears of joy"]={ 0x1F602 },
 ["face with thermometer"]={ 0x1F912 },
 ["face with tongue"]={ 0x1F61B },
 ["face without mouth"]={ 0x1F636 },
 ["factory"]={ 0x1F3ED },
 ["factory worker"]={ 0x1F9D1, 0x200D, 0x1F3ED },
 ["factory worker: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F3ED },
 ["factory worker: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F3ED },
 ["factory worker: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F3ED },
 ["factory worker: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F3ED },
 ["factory worker: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F3ED },
 ["fairy"]={ 0x1F9DA },
 ["fairy: dark skin tone"]={ 0x1F9DA, 0x1F3FF },
 ["fairy: light skin tone"]={ 0x1F9DA, 0x1F3FB },
 ["fairy: medium skin tone"]={ 0x1F9DA, 0x1F3FD },
 ["fairy: medium-dark skin tone"]={ 0x1F9DA, 0x1F3FE },
 ["fairy: medium-light skin tone"]={ 0x1F9DA, 0x1F3FC },
 ["falafel"]={ 0x1F9C6 },
 ["fallen leaf"]={ 0x1F342 },
 ["family"]={ 0x1F46A },
 ["family: man, boy"]={ 0x1F468, 0x200D, 0x1F466 },
 ["family: man, boy, boy"]={ 0x1F468, 0x200D, 0x1F466, 0x200D, 0x1F466 },
 ["family: man, girl"]={ 0x1F468, 0x200D, 0x1F467 },
 ["family: man, girl, boy"]={ 0x1F468, 0x200D, 0x1F467, 0x200D, 0x1F466 },
 ["family: man, girl, girl"]={ 0x1F468, 0x200D, 0x1F467, 0x200D, 0x1F467 },
 ["family: man, man, boy"]={ 0x1F468, 0x200D, 0x1F468, 0x200D, 0x1F466 },
 ["family: man, man, boy, boy"]={ 0x1F468, 0x200D, 0x1F468, 0x200D, 0x1F466, 0x200D, 0x1F466 },
 ["family: man, man, girl"]={ 0x1F468, 0x200D, 0x1F468, 0x200D, 0x1F467 },
 ["family: man, man, girl, boy"]={ 0x1F468, 0x200D, 0x1F468, 0x200D, 0x1F467, 0x200D, 0x1F466 },
 ["family: man, man, girl, girl"]={ 0x1F468, 0x200D, 0x1F468, 0x200D, 0x1F467, 0x200D, 0x1F467 },
 ["family: man, woman, boy"]={ 0x1F468, 0x200D, 0x1F469, 0x200D, 0x1F466 },
 ["family: man, woman, boy, boy"]={ 0x1F468, 0x200D, 0x1F469, 0x200D, 0x1F466, 0x200D, 0x1F466 },
 ["family: man, woman, girl"]={ 0x1F468, 0x200D, 0x1F469, 0x200D, 0x1F467 },
 ["family: man, woman, girl, boy"]={ 0x1F468, 0x200D, 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F466 },
 ["family: man, woman, girl, girl"]={ 0x1F468, 0x200D, 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F467 },
 ["family: woman, boy"]={ 0x1F469, 0x200D, 0x1F466 },
 ["family: woman, boy, boy"]={ 0x1F469, 0x200D, 0x1F466, 0x200D, 0x1F466 },
 ["family: woman, girl"]={ 0x1F469, 0x200D, 0x1F467 },
 ["family: woman, girl, boy"]={ 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F466 },
 ["family: woman, girl, girl"]={ 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F467 },
 ["family: woman, woman, boy"]={ 0x1F469, 0x200D, 0x1F469, 0x200D, 0x1F466 },
 ["family: woman, woman, boy, boy"]={ 0x1F469, 0x200D, 0x1F469, 0x200D, 0x1F466, 0x200D, 0x1F466 },
 ["family: woman, woman, girl"]={ 0x1F469, 0x200D, 0x1F469, 0x200D, 0x1F467 },
 ["family: woman, woman, girl, boy"]={ 0x1F469, 0x200D, 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F466 },
 ["family: woman, woman, girl, girl"]={ 0x1F469, 0x200D, 0x1F469, 0x200D, 0x1F467, 0x200D, 0x1F467 },
 ["farmer"]={ 0x1F9D1, 0x200D, 0x1F33E },
 ["farmer: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F33E },
 ["farmer: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F33E },
 ["farmer: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F33E },
 ["farmer: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F33E },
 ["farmer: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F33E },
 ["fast down button"]={ 0x23EC },
 ["fast reverse button"]={ 0x23EA },
 ["fast up button"]={ 0x23EB },
 ["fast-forward button"]={ 0x23E9 },
 ["fax machine"]={ 0x1F4E0 },
 ["fearful face"]={ 0x1F628 },
 ["feather"]={ 0x1FAB6 },
 ["female sign"]={ 0x2640, 0xFE0F },
 ["ferris wheel"]={ 0x1F3A1 },
 ["ferry"]={ 0x26F4, 0xFE0F },
 ["field hockey"]={ 0x1F3D1 },
 ["file cabinet"]={ 0x1F5C4, 0xFE0F },
 ["file folder"]={ 0x1F4C1 },
 ["film frames"]={ 0x1F39E, 0xFE0F },
 ["film projector"]={ 0x1F4FD, 0xFE0F },
 ["fire"]={ 0x1F525 },
 ["fire engine"]={ 0x1F692 },
 ["fire extinguisher"]={ 0x1F9EF },
 ["firecracker"]={ 0x1F9E8 },
 ["firefighter"]={ 0x1F9D1, 0x200D, 0x1F692 },
 ["firefighter: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F692 },
 ["firefighter: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F692 },
 ["firefighter: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F692 },
 ["firefighter: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F692 },
 ["firefighter: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F692 },
 ["fireworks"]={ 0x1F386 },
 ["first quarter moon"]={ 0x1F313 },
 ["first quarter moon face"]={ 0x1F31B },
 ["fish"]={ 0x1F41F },
 ["fish cake with swirl"]={ 0x1F365 },
 ["fishing pole"]={ 0x1F3A3 },
 ["five o’clock"]={ 0x1F554 },
 ["five-thirty"]={ 0x1F560 },
 ["flag in hole"]={ 0x26F3 },
 ["flag: afghanistan"]={ 0x1F1E6, 0x1F1EB },
 ["flag: albania"]={ 0x1F1E6, 0x1F1F1 },
 ["flag: algeria"]={ 0x1F1E9, 0x1F1FF },
 ["flag: american samoa"]={ 0x1F1E6, 0x1F1F8 },
 ["flag: andorra"]={ 0x1F1E6, 0x1F1E9 },
 ["flag: angola"]={ 0x1F1E6, 0x1F1F4 },
 ["flag: anguilla"]={ 0x1F1E6, 0x1F1EE },
 ["flag: antarctica"]={ 0x1F1E6, 0x1F1F6 },
 ["flag: antigua & barbuda"]={ 0x1F1E6, 0x1F1EC },
 ["flag: argentina"]={ 0x1F1E6, 0x1F1F7 },
 ["flag: armenia"]={ 0x1F1E6, 0x1F1F2 },
 ["flag: aruba"]={ 0x1F1E6, 0x1F1FC },
 ["flag: ascension island"]={ 0x1F1E6, 0x1F1E8 },
 ["flag: australia"]={ 0x1F1E6, 0x1F1FA },
 ["flag: austria"]={ 0x1F1E6, 0x1F1F9 },
 ["flag: azerbaijan"]={ 0x1F1E6, 0x1F1FF },
 ["flag: bahamas"]={ 0x1F1E7, 0x1F1F8 },
 ["flag: bahrain"]={ 0x1F1E7, 0x1F1ED },
 ["flag: bangladesh"]={ 0x1F1E7, 0x1F1E9 },
 ["flag: barbados"]={ 0x1F1E7, 0x1F1E7 },
 ["flag: belarus"]={ 0x1F1E7, 0x1F1FE },
 ["flag: belgium"]={ 0x1F1E7, 0x1F1EA },
 ["flag: belize"]={ 0x1F1E7, 0x1F1FF },
 ["flag: benin"]={ 0x1F1E7, 0x1F1EF },
 ["flag: bermuda"]={ 0x1F1E7, 0x1F1F2 },
 ["flag: bhutan"]={ 0x1F1E7, 0x1F1F9 },
 ["flag: bolivia"]={ 0x1F1E7, 0x1F1F4 },
 ["flag: bosnia & herzegovina"]={ 0x1F1E7, 0x1F1E6 },
 ["flag: botswana"]={ 0x1F1E7, 0x1F1FC },
 ["flag: bouvet island"]={ 0x1F1E7, 0x1F1FB },
 ["flag: brazil"]={ 0x1F1E7, 0x1F1F7 },
 ["flag: british indian ocean territory"]={ 0x1F1EE, 0x1F1F4 },
 ["flag: british virgin islands"]={ 0x1F1FB, 0x1F1EC },
 ["flag: brunei"]={ 0x1F1E7, 0x1F1F3 },
 ["flag: bulgaria"]={ 0x1F1E7, 0x1F1EC },
 ["flag: burkina faso"]={ 0x1F1E7, 0x1F1EB },
 ["flag: burundi"]={ 0x1F1E7, 0x1F1EE },
 ["flag: cambodia"]={ 0x1F1F0, 0x1F1ED },
 ["flag: cameroon"]={ 0x1F1E8, 0x1F1F2 },
 ["flag: canada"]={ 0x1F1E8, 0x1F1E6 },
 ["flag: canary islands"]={ 0x1F1EE, 0x1F1E8 },
 ["flag: cape verde"]={ 0x1F1E8, 0x1F1FB },
 ["flag: caribbean netherlands"]={ 0x1F1E7, 0x1F1F6 },
 ["flag: cayman islands"]={ 0x1F1F0, 0x1F1FE },
 ["flag: central african republic"]={ 0x1F1E8, 0x1F1EB },
 ["flag: ceuta & melilla"]={ 0x1F1EA, 0x1F1E6 },
 ["flag: chad"]={ 0x1F1F9, 0x1F1E9 },
 ["flag: chile"]={ 0x1F1E8, 0x1F1F1 },
 ["flag: china"]={ 0x1F1E8, 0x1F1F3 },
 ["flag: christmas island"]={ 0x1F1E8, 0x1F1FD },
 ["flag: clipperton island"]={ 0x1F1E8, 0x1F1F5 },
 ["flag: cocos (keeling) islands"]={ 0x1F1E8, 0x1F1E8 },
 ["flag: colombia"]={ 0x1F1E8, 0x1F1F4 },
 ["flag: comoros"]={ 0x1F1F0, 0x1F1F2 },
 ["flag: congo - brazzaville"]={ 0x1F1E8, 0x1F1EC },
 ["flag: congo - kinshasa"]={ 0x1F1E8, 0x1F1E9 },
 ["flag: cook islands"]={ 0x1F1E8, 0x1F1F0 },
 ["flag: costa rica"]={ 0x1F1E8, 0x1F1F7 },
 ["flag: croatia"]={ 0x1F1ED, 0x1F1F7 },
 ["flag: cuba"]={ 0x1F1E8, 0x1F1FA },
 ["flag: curaçao"]={ 0x1F1E8, 0x1F1FC },
 ["flag: cyprus"]={ 0x1F1E8, 0x1F1FE },
 ["flag: czechia"]={ 0x1F1E8, 0x1F1FF },
 ["flag: côte d’ivoire"]={ 0x1F1E8, 0x1F1EE },
 ["flag: denmark"]={ 0x1F1E9, 0x1F1F0 },
 ["flag: diego garcia"]={ 0x1F1E9, 0x1F1EC },
 ["flag: djibouti"]={ 0x1F1E9, 0x1F1EF },
 ["flag: dominica"]={ 0x1F1E9, 0x1F1F2 },
 ["flag: dominican republic"]={ 0x1F1E9, 0x1F1F4 },
 ["flag: ecuador"]={ 0x1F1EA, 0x1F1E8 },
 ["flag: egypt"]={ 0x1F1EA, 0x1F1EC },
 ["flag: el salvador"]={ 0x1F1F8, 0x1F1FB },
 ["flag: england"]={ 0x1F3F4, 0xE0067, 0xE0062, 0xE0065, 0xE006E, 0xE0067, 0xE007F },
 ["flag: equatorial guinea"]={ 0x1F1EC, 0x1F1F6 },
 ["flag: eritrea"]={ 0x1F1EA, 0x1F1F7 },
 ["flag: estonia"]={ 0x1F1EA, 0x1F1EA },
 ["flag: eswatini"]={ 0x1F1F8, 0x1F1FF },
 ["flag: ethiopia"]={ 0x1F1EA, 0x1F1F9 },
 ["flag: european union"]={ 0x1F1EA, 0x1F1FA },
 ["flag: falkland islands"]={ 0x1F1EB, 0x1F1F0 },
 ["flag: faroe islands"]={ 0x1F1EB, 0x1F1F4 },
 ["flag: fiji"]={ 0x1F1EB, 0x1F1EF },
 ["flag: finland"]={ 0x1F1EB, 0x1F1EE },
 ["flag: france"]={ 0x1F1EB, 0x1F1F7 },
 ["flag: french guiana"]={ 0x1F1EC, 0x1F1EB },
 ["flag: french polynesia"]={ 0x1F1F5, 0x1F1EB },
 ["flag: french southern territories"]={ 0x1F1F9, 0x1F1EB },
 ["flag: gabon"]={ 0x1F1EC, 0x1F1E6 },
 ["flag: gambia"]={ 0x1F1EC, 0x1F1F2 },
 ["flag: georgia"]={ 0x1F1EC, 0x1F1EA },
 ["flag: germany"]={ 0x1F1E9, 0x1F1EA },
 ["flag: ghana"]={ 0x1F1EC, 0x1F1ED },
 ["flag: gibraltar"]={ 0x1F1EC, 0x1F1EE },
 ["flag: greece"]={ 0x1F1EC, 0x1F1F7 },
 ["flag: greenland"]={ 0x1F1EC, 0x1F1F1 },
 ["flag: grenada"]={ 0x1F1EC, 0x1F1E9 },
 ["flag: guadeloupe"]={ 0x1F1EC, 0x1F1F5 },
 ["flag: guam"]={ 0x1F1EC, 0x1F1FA },
 ["flag: guatemala"]={ 0x1F1EC, 0x1F1F9 },
 ["flag: guernsey"]={ 0x1F1EC, 0x1F1EC },
 ["flag: guinea"]={ 0x1F1EC, 0x1F1F3 },
 ["flag: guinea-bissau"]={ 0x1F1EC, 0x1F1FC },
 ["flag: guyana"]={ 0x1F1EC, 0x1F1FE },
 ["flag: haiti"]={ 0x1F1ED, 0x1F1F9 },
 ["flag: heard & mcdonald islands"]={ 0x1F1ED, 0x1F1F2 },
 ["flag: honduras"]={ 0x1F1ED, 0x1F1F3 },
 ["flag: hong kong sar china"]={ 0x1F1ED, 0x1F1F0 },
 ["flag: hungary"]={ 0x1F1ED, 0x1F1FA },
 ["flag: iceland"]={ 0x1F1EE, 0x1F1F8 },
 ["flag: india"]={ 0x1F1EE, 0x1F1F3 },
 ["flag: indonesia"]={ 0x1F1EE, 0x1F1E9 },
 ["flag: iran"]={ 0x1F1EE, 0x1F1F7 },
 ["flag: iraq"]={ 0x1F1EE, 0x1F1F6 },
 ["flag: ireland"]={ 0x1F1EE, 0x1F1EA },
 ["flag: isle of man"]={ 0x1F1EE, 0x1F1F2 },
 ["flag: israel"]={ 0x1F1EE, 0x1F1F1 },
 ["flag: italy"]={ 0x1F1EE, 0x1F1F9 },
 ["flag: jamaica"]={ 0x1F1EF, 0x1F1F2 },
 ["flag: japan"]={ 0x1F1EF, 0x1F1F5 },
 ["flag: jersey"]={ 0x1F1EF, 0x1F1EA },
 ["flag: jordan"]={ 0x1F1EF, 0x1F1F4 },
 ["flag: kazakhstan"]={ 0x1F1F0, 0x1F1FF },
 ["flag: kenya"]={ 0x1F1F0, 0x1F1EA },
 ["flag: kiribati"]={ 0x1F1F0, 0x1F1EE },
 ["flag: kosovo"]={ 0x1F1FD, 0x1F1F0 },
 ["flag: kuwait"]={ 0x1F1F0, 0x1F1FC },
 ["flag: kyrgyzstan"]={ 0x1F1F0, 0x1F1EC },
 ["flag: laos"]={ 0x1F1F1, 0x1F1E6 },
 ["flag: latvia"]={ 0x1F1F1, 0x1F1FB },
 ["flag: lebanon"]={ 0x1F1F1, 0x1F1E7 },
 ["flag: lesotho"]={ 0x1F1F1, 0x1F1F8 },
 ["flag: liberia"]={ 0x1F1F1, 0x1F1F7 },
 ["flag: libya"]={ 0x1F1F1, 0x1F1FE },
 ["flag: liechtenstein"]={ 0x1F1F1, 0x1F1EE },
 ["flag: lithuania"]={ 0x1F1F1, 0x1F1F9 },
 ["flag: luxembourg"]={ 0x1F1F1, 0x1F1FA },
 ["flag: macao sar china"]={ 0x1F1F2, 0x1F1F4 },
 ["flag: madagascar"]={ 0x1F1F2, 0x1F1EC },
 ["flag: malawi"]={ 0x1F1F2, 0x1F1FC },
 ["flag: malaysia"]={ 0x1F1F2, 0x1F1FE },
 ["flag: maldives"]={ 0x1F1F2, 0x1F1FB },
 ["flag: mali"]={ 0x1F1F2, 0x1F1F1 },
 ["flag: malta"]={ 0x1F1F2, 0x1F1F9 },
 ["flag: marshall islands"]={ 0x1F1F2, 0x1F1ED },
 ["flag: martinique"]={ 0x1F1F2, 0x1F1F6 },
 ["flag: mauritania"]={ 0x1F1F2, 0x1F1F7 },
 ["flag: mauritius"]={ 0x1F1F2, 0x1F1FA },
 ["flag: mayotte"]={ 0x1F1FE, 0x1F1F9 },
 ["flag: mexico"]={ 0x1F1F2, 0x1F1FD },
 ["flag: micronesia"]={ 0x1F1EB, 0x1F1F2 },
 ["flag: moldova"]={ 0x1F1F2, 0x1F1E9 },
 ["flag: monaco"]={ 0x1F1F2, 0x1F1E8 },
 ["flag: mongolia"]={ 0x1F1F2, 0x1F1F3 },
 ["flag: montenegro"]={ 0x1F1F2, 0x1F1EA },
 ["flag: montserrat"]={ 0x1F1F2, 0x1F1F8 },
 ["flag: morocco"]={ 0x1F1F2, 0x1F1E6 },
 ["flag: mozambique"]={ 0x1F1F2, 0x1F1FF },
 ["flag: myanmar (burma)"]={ 0x1F1F2, 0x1F1F2 },
 ["flag: namibia"]={ 0x1F1F3, 0x1F1E6 },
 ["flag: nauru"]={ 0x1F1F3, 0x1F1F7 },
 ["flag: nepal"]={ 0x1F1F3, 0x1F1F5 },
 ["flag: netherlands"]={ 0x1F1F3, 0x1F1F1 },
 ["flag: new caledonia"]={ 0x1F1F3, 0x1F1E8 },
 ["flag: new zealand"]={ 0x1F1F3, 0x1F1FF },
 ["flag: nicaragua"]={ 0x1F1F3, 0x1F1EE },
 ["flag: niger"]={ 0x1F1F3, 0x1F1EA },
 ["flag: nigeria"]={ 0x1F1F3, 0x1F1EC },
 ["flag: niue"]={ 0x1F1F3, 0x1F1FA },
 ["flag: norfolk island"]={ 0x1F1F3, 0x1F1EB },
 ["flag: north korea"]={ 0x1F1F0, 0x1F1F5 },
 ["flag: north macedonia"]={ 0x1F1F2, 0x1F1F0 },
 ["flag: northern mariana islands"]={ 0x1F1F2, 0x1F1F5 },
 ["flag: norway"]={ 0x1F1F3, 0x1F1F4 },
 ["flag: oman"]={ 0x1F1F4, 0x1F1F2 },
 ["flag: pakistan"]={ 0x1F1F5, 0x1F1F0 },
 ["flag: palau"]={ 0x1F1F5, 0x1F1FC },
 ["flag: palestinian territories"]={ 0x1F1F5, 0x1F1F8 },
 ["flag: panama"]={ 0x1F1F5, 0x1F1E6 },
 ["flag: papua new guinea"]={ 0x1F1F5, 0x1F1EC },
 ["flag: paraguay"]={ 0x1F1F5, 0x1F1FE },
 ["flag: peru"]={ 0x1F1F5, 0x1F1EA },
 ["flag: philippines"]={ 0x1F1F5, 0x1F1ED },
 ["flag: pitcairn islands"]={ 0x1F1F5, 0x1F1F3 },
 ["flag: poland"]={ 0x1F1F5, 0x1F1F1 },
 ["flag: portugal"]={ 0x1F1F5, 0x1F1F9 },
 ["flag: puerto rico"]={ 0x1F1F5, 0x1F1F7 },
 ["flag: qatar"]={ 0x1F1F6, 0x1F1E6 },
 ["flag: romania"]={ 0x1F1F7, 0x1F1F4 },
 ["flag: russia"]={ 0x1F1F7, 0x1F1FA },
 ["flag: rwanda"]={ 0x1F1F7, 0x1F1FC },
 ["flag: réunion"]={ 0x1F1F7, 0x1F1EA },
 ["flag: samoa"]={ 0x1F1FC, 0x1F1F8 },
 ["flag: san marino"]={ 0x1F1F8, 0x1F1F2 },
 ["flag: saudi arabia"]={ 0x1F1F8, 0x1F1E6 },
 ["flag: scotland"]={ 0x1F3F4, 0xE0067, 0xE0062, 0xE0073, 0xE0063, 0xE0074, 0xE007F },
 ["flag: senegal"]={ 0x1F1F8, 0x1F1F3 },
 ["flag: serbia"]={ 0x1F1F7, 0x1F1F8 },
 ["flag: seychelles"]={ 0x1F1F8, 0x1F1E8 },
 ["flag: sierra leone"]={ 0x1F1F8, 0x1F1F1 },
 ["flag: singapore"]={ 0x1F1F8, 0x1F1EC },
 ["flag: sint maarten"]={ 0x1F1F8, 0x1F1FD },
 ["flag: slovakia"]={ 0x1F1F8, 0x1F1F0 },
 ["flag: slovenia"]={ 0x1F1F8, 0x1F1EE },
 ["flag: solomon islands"]={ 0x1F1F8, 0x1F1E7 },
 ["flag: somalia"]={ 0x1F1F8, 0x1F1F4 },
 ["flag: south africa"]={ 0x1F1FF, 0x1F1E6 },
 ["flag: south georgia & south sandwich islands"]={ 0x1F1EC, 0x1F1F8 },
 ["flag: south korea"]={ 0x1F1F0, 0x1F1F7 },
 ["flag: south sudan"]={ 0x1F1F8, 0x1F1F8 },
 ["flag: spain"]={ 0x1F1EA, 0x1F1F8 },
 ["flag: sri lanka"]={ 0x1F1F1, 0x1F1F0 },
 ["flag: st. barthélemy"]={ 0x1F1E7, 0x1F1F1 },
 ["flag: st. helena"]={ 0x1F1F8, 0x1F1ED },
 ["flag: st. kitts & nevis"]={ 0x1F1F0, 0x1F1F3 },
 ["flag: st. lucia"]={ 0x1F1F1, 0x1F1E8 },
 ["flag: st. martin"]={ 0x1F1F2, 0x1F1EB },
 ["flag: st. pierre & miquelon"]={ 0x1F1F5, 0x1F1F2 },
 ["flag: st. vincent & grenadines"]={ 0x1F1FB, 0x1F1E8 },
 ["flag: sudan"]={ 0x1F1F8, 0x1F1E9 },
 ["flag: suriname"]={ 0x1F1F8, 0x1F1F7 },
 ["flag: svalbard & jan mayen"]={ 0x1F1F8, 0x1F1EF },
 ["flag: sweden"]={ 0x1F1F8, 0x1F1EA },
 ["flag: switzerland"]={ 0x1F1E8, 0x1F1ED },
 ["flag: syria"]={ 0x1F1F8, 0x1F1FE },
 ["flag: são tomé & príncipe"]={ 0x1F1F8, 0x1F1F9 },
 ["flag: taiwan"]={ 0x1F1F9, 0x1F1FC },
 ["flag: tajikistan"]={ 0x1F1F9, 0x1F1EF },
 ["flag: tanzania"]={ 0x1F1F9, 0x1F1FF },
 ["flag: thailand"]={ 0x1F1F9, 0x1F1ED },
 ["flag: timor-leste"]={ 0x1F1F9, 0x1F1F1 },
 ["flag: togo"]={ 0x1F1F9, 0x1F1EC },
 ["flag: tokelau"]={ 0x1F1F9, 0x1F1F0 },
 ["flag: tonga"]={ 0x1F1F9, 0x1F1F4 },
 ["flag: trinidad & tobago"]={ 0x1F1F9, 0x1F1F9 },
 ["flag: tristan da cunha"]={ 0x1F1F9, 0x1F1E6 },
 ["flag: tunisia"]={ 0x1F1F9, 0x1F1F3 },
 ["flag: turkey"]={ 0x1F1F9, 0x1F1F7 },
 ["flag: turkmenistan"]={ 0x1F1F9, 0x1F1F2 },
 ["flag: turks & caicos islands"]={ 0x1F1F9, 0x1F1E8 },
 ["flag: tuvalu"]={ 0x1F1F9, 0x1F1FB },
 ["flag: u.s. outlying islands"]={ 0x1F1FA, 0x1F1F2 },
 ["flag: u.s. virgin islands"]={ 0x1F1FB, 0x1F1EE },
 ["flag: uganda"]={ 0x1F1FA, 0x1F1EC },
 ["flag: ukraine"]={ 0x1F1FA, 0x1F1E6 },
 ["flag: united arab emirates"]={ 0x1F1E6, 0x1F1EA },
 ["flag: united kingdom"]={ 0x1F1EC, 0x1F1E7 },
 ["flag: united nations"]={ 0x1F1FA, 0x1F1F3 },
 ["flag: united states"]={ 0x1F1FA, 0x1F1F8 },
 ["flag: uruguay"]={ 0x1F1FA, 0x1F1FE },
 ["flag: uzbekistan"]={ 0x1F1FA, 0x1F1FF },
 ["flag: vanuatu"]={ 0x1F1FB, 0x1F1FA },
 ["flag: vatican city"]={ 0x1F1FB, 0x1F1E6 },
 ["flag: venezuela"]={ 0x1F1FB, 0x1F1EA },
 ["flag: vietnam"]={ 0x1F1FB, 0x1F1F3 },
 ["flag: wales"]={ 0x1F3F4, 0xE0067, 0xE0062, 0xE0077, 0xE006C, 0xE0073, 0xE007F },
 ["flag: wallis & futuna"]={ 0x1F1FC, 0x1F1EB },
 ["flag: western sahara"]={ 0x1F1EA, 0x1F1ED },
 ["flag: yemen"]={ 0x1F1FE, 0x1F1EA },
 ["flag: zambia"]={ 0x1F1FF, 0x1F1F2 },
 ["flag: zimbabwe"]={ 0x1F1FF, 0x1F1FC },
 ["flag: Åland islands"]={ 0x1F1E6, 0x1F1FD },
 ["flamingo"]={ 0x1F9A9 },
 ["flashlight"]={ 0x1F526 },
 ["flat shoe"]={ 0x1F97F },
 ["flatbread"]={ 0x1FAD3 },
 ["fleur-de-lis"]={ 0x269C, 0xFE0F },
 ["flexed biceps"]={ 0x1F4AA },
 ["flexed biceps: dark skin tone"]={ 0x1F4AA, 0x1F3FF },
 ["flexed biceps: light skin tone"]={ 0x1F4AA, 0x1F3FB },
 ["flexed biceps: medium skin tone"]={ 0x1F4AA, 0x1F3FD },
 ["flexed biceps: medium-dark skin tone"]={ 0x1F4AA, 0x1F3FE },
 ["flexed biceps: medium-light skin tone"]={ 0x1F4AA, 0x1F3FC },
 ["floppy disk"]={ 0x1F4BE },
 ["flower playing cards"]={ 0x1F3B4 },
 ["flushed face"]={ 0x1F633 },
 ["fly"]={ 0x1FAB0 },
 ["flying disc"]={ 0x1F94F },
 ["flying saucer"]={ 0x1F6F8 },
 ["fog"]={ 0x1F32B, 0xFE0F },
 ["foggy"]={ 0x1F301 },
 ["folded hands"]={ 0x1F64F },
 ["folded hands: dark skin tone"]={ 0x1F64F, 0x1F3FF },
 ["folded hands: light skin tone"]={ 0x1F64F, 0x1F3FB },
 ["folded hands: medium skin tone"]={ 0x1F64F, 0x1F3FD },
 ["folded hands: medium-dark skin tone"]={ 0x1F64F, 0x1F3FE },
 ["folded hands: medium-light skin tone"]={ 0x1F64F, 0x1F3FC },
 ["fondue"]={ 0x1FAD5 },
 ["foot"]={ 0x1F9B6 },
 ["foot: dark skin tone"]={ 0x1F9B6, 0x1F3FF },
 ["foot: light skin tone"]={ 0x1F9B6, 0x1F3FB },
 ["foot: medium skin tone"]={ 0x1F9B6, 0x1F3FD },
 ["foot: medium-dark skin tone"]={ 0x1F9B6, 0x1F3FE },
 ["foot: medium-light skin tone"]={ 0x1F9B6, 0x1F3FC },
 ["footprints"]={ 0x1F463 },
 ["fork and knife"]={ 0x1F374 },
 ["fork and knife with plate"]={ 0x1F37D, 0xFE0F },
 ["fortune cookie"]={ 0x1F960 },
 ["fountain"]={ 0x26F2 },
 ["fountain pen"]={ 0x1F58B, 0xFE0F },
 ["four leaf clover"]={ 0x1F340 },
 ["four o’clock"]={ 0x1F553 },
 ["four-thirty"]={ 0x1F55F },
 ["fox"]={ 0x1F98A },
 ["framed picture"]={ 0x1F5BC, 0xFE0F },
 ["free button"]={ 0x1F193 },
 ["french fries"]={ 0x1F35F },
 ["fried shrimp"]={ 0x1F364 },
 ["frog"]={ 0x1F438 },
 ["front-facing baby chick"]={ 0x1F425 },
 ["frowning face"]={ 0x2639, 0xFE0F },
 ["frowning face with open mouth"]={ 0x1F626 },
 ["fuel pump"]={ 0x26FD },
 ["full moon"]={ 0x1F315 },
 ["full moon face"]={ 0x1F31D },
 ["funeral urn"]={ 0x26B1, 0xFE0F },
 ["game die"]={ 0x1F3B2 },
 ["garlic"]={ 0x1F9C4 },
 ["gear"]={ 0x2699, 0xFE0F },
 ["gem stone"]={ 0x1F48E },
 ["gemini"]={ 0x264A },
 ["genie"]={ 0x1F9DE },
 ["ghost"]={ 0x1F47B },
 ["giraffe"]={ 0x1F992 },
 ["girl"]={ 0x1F467 },
 ["girl: dark skin tone"]={ 0x1F467, 0x1F3FF },
 ["girl: light skin tone"]={ 0x1F467, 0x1F3FB },
 ["girl: medium skin tone"]={ 0x1F467, 0x1F3FD },
 ["girl: medium-dark skin tone"]={ 0x1F467, 0x1F3FE },
 ["girl: medium-light skin tone"]={ 0x1F467, 0x1F3FC },
 ["glass of milk"]={ 0x1F95B },
 ["glasses"]={ 0x1F453 },
 ["globe showing americas"]={ 0x1F30E },
 ["globe showing asia-australia"]={ 0x1F30F },
 ["globe showing europe-africa"]={ 0x1F30D },
 ["globe with meridians"]={ 0x1F310 },
 ["gloves"]={ 0x1F9E4 },
 ["glowing star"]={ 0x1F31F },
 ["goal net"]={ 0x1F945 },
 ["goat"]={ 0x1F410 },
 ["goblin"]={ 0x1F47A },
 ["goggles"]={ 0x1F97D },
 ["gorilla"]={ 0x1F98D },
 ["graduation cap"]={ 0x1F393 },
 ["grapes"]={ 0x1F347 },
 ["green apple"]={ 0x1F34F },
 ["green book"]={ 0x1F4D7 },
 ["green circle"]={ 0x1F7E2 },
 ["green heart"]={ 0x1F49A },
 ["green salad"]={ 0x1F957 },
 ["green square"]={ 0x1F7E9 },
 ["grimacing face"]={ 0x1F62C },
 ["grinning cat"]={ 0x1F63A },
 ["grinning cat with smiling eyes"]={ 0x1F638 },
 ["grinning face"]={ 0x1F600 },
 ["grinning face with big eyes"]={ 0x1F603 },
 ["grinning face with smiling eyes"]={ 0x1F604 },
 ["grinning face with sweat"]={ 0x1F605 },
 ["grinning squinting face"]={ 0x1F606 },
 ["growing heart"]={ 0x1F497 },
 ["guard"]={ 0x1F482 },
 ["guard: dark skin tone"]={ 0x1F482, 0x1F3FF },
 ["guard: light skin tone"]={ 0x1F482, 0x1F3FB },
 ["guard: medium skin tone"]={ 0x1F482, 0x1F3FD },
 ["guard: medium-dark skin tone"]={ 0x1F482, 0x1F3FE },
 ["guard: medium-light skin tone"]={ 0x1F482, 0x1F3FC },
 ["guide dog"]={ 0x1F9AE },
 ["guitar"]={ 0x1F3B8 },
 ["hamburger"]={ 0x1F354 },
 ["hammer"]={ 0x1F528 },
 ["hammer and pick"]={ 0x2692, 0xFE0F },
 ["hammer and wrench"]={ 0x1F6E0, 0xFE0F },
 ["hamster"]={ 0x1F439 },
 ["hand with fingers splayed"]={ 0x1F590, 0xFE0F },
 ["hand with fingers splayed: dark skin tone"]={ 0x1F590, 0x1F3FF },
 ["hand with fingers splayed: light skin tone"]={ 0x1F590, 0x1F3FB },
 ["hand with fingers splayed: medium skin tone"]={ 0x1F590, 0x1F3FD },
 ["hand with fingers splayed: medium-dark skin tone"]={ 0x1F590, 0x1F3FE },
 ["hand with fingers splayed: medium-light skin tone"]={ 0x1F590, 0x1F3FC },
 ["handbag"]={ 0x1F45C },
 ["handshake"]={ 0x1F91D },
 ["hatching chick"]={ 0x1F423 },
 ["headphone"]={ 0x1F3A7 },
 ["headstone"]={ 0x1FAA6 },
 ["health worker"]={ 0x1F9D1, 0x200D, 0x2695, 0xFE0F },
 ["health worker: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x2695, 0xFE0F },
 ["health worker: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x2695, 0xFE0F },
 ["health worker: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x2695, 0xFE0F },
 ["health worker: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x2695, 0xFE0F },
 ["health worker: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x2695, 0xFE0F },
 ["hear-no-evil monkey"]={ 0x1F649 },
 ["heart decoration"]={ 0x1F49F },
 ["heart exclamation"]={ 0x2763, 0xFE0F },
 ["heart suit"]={ 0x2665, 0xFE0F },
 ["heart with arrow"]={ 0x1F498 },
 ["heart with ribbon"]={ 0x1F49D },
 ["heavy dollar sign"]={ 0x1F4B2 },
 ["hedgehog"]={ 0x1F994 },
 ["helicopter"]={ 0x1F681 },
 ["herb"]={ 0x1F33F },
 ["hibiscus"]={ 0x1F33A },
 ["high voltage"]={ 0x26A1 },
 ["high-heeled shoe"]={ 0x1F460 },
 ["high-speed train"]={ 0x1F684 },
 ["hiking boot"]={ 0x1F97E },
 ["hindu temple"]={ 0x1F6D5 },
 ["hippopotamus"]={ 0x1F99B },
 ["hole"]={ 0x1F573, 0xFE0F },
 ["hollow red circle"]={ 0x2B55 },
 ["honey pot"]={ 0x1F36F },
 ["honeybee"]={ 0x1F41D },
 ["hook"]={ 0x1FA9D },
 ["horizontal traffic light"]={ 0x1F6A5 },
 ["horse"]={ 0x1F40E },
 ["horse face"]={ 0x1F434 },
 ["horse racing"]={ 0x1F3C7 },
 ["horse racing: dark skin tone"]={ 0x1F3C7, 0x1F3FF },
 ["horse racing: light skin tone"]={ 0x1F3C7, 0x1F3FB },
 ["horse racing: medium skin tone"]={ 0x1F3C7, 0x1F3FD },
 ["horse racing: medium-dark skin tone"]={ 0x1F3C7, 0x1F3FE },
 ["horse racing: medium-light skin tone"]={ 0x1F3C7, 0x1F3FC },
 ["hospital"]={ 0x1F3E5 },
 ["hot beverage"]={ 0x2615 },
 ["hot dog"]={ 0x1F32D },
 ["hot face"]={ 0x1F975 },
 ["hot pepper"]={ 0x1F336, 0xFE0F },
 ["hot springs"]={ 0x2668, 0xFE0F },
 ["hotel"]={ 0x1F3E8 },
 ["hourglass done"]={ 0x231B },
 ["hourglass not done"]={ 0x23F3 },
 ["house"]={ 0x1F3E0 },
 ["house with garden"]={ 0x1F3E1 },
 ["houses"]={ 0x1F3D8, 0xFE0F },
 ["hugging face"]={ 0x1F917 },
 ["hundred points"]={ 0x1F4AF },
 ["hushed face"]={ 0x1F62F },
 ["hut"]={ 0x1F6D6 },
 ["ice"]={ 0x1F9CA },
 ["ice cream"]={ 0x1F368 },
 ["ice hockey"]={ 0x1F3D2 },
 ["ice skate"]={ 0x26F8, 0xFE0F },
 ["id button"]={ 0x1F194 },
 ["inbox tray"]={ 0x1F4E5 },
 ["incoming envelope"]={ 0x1F4E8 },
 ["index pointing up"]={ 0x261D, 0xFE0F },
 ["index pointing up: dark skin tone"]={ 0x261D, 0x1F3FF },
 ["index pointing up: light skin tone"]={ 0x261D, 0x1F3FB },
 ["index pointing up: medium skin tone"]={ 0x261D, 0x1F3FD },
 ["index pointing up: medium-dark skin tone"]={ 0x261D, 0x1F3FE },
 ["index pointing up: medium-light skin tone"]={ 0x261D, 0x1F3FC },
 ["infinity"]={ 0x267E, 0xFE0F },
 ["information"]={ 0x2139, 0xFE0F },
 ["input latin letters"]={ 0x1F524 },
 ["input latin lowercase"]={ 0x1F521 },
 ["input latin uppercase"]={ 0x1F520 },
 ["input numbers"]={ 0x1F522 },
 ["input symbols"]={ 0x1F523 },
 ["jack-o-lantern"]={ 0x1F383 },
 ["japanese castle"]={ 0x1F3EF },
 ["japanese dolls"]={ 0x1F38E },
 ["japanese post office"]={ 0x1F3E3 },
 ["japanese symbol for beginner"]={ 0x1F530 },
 ["japanese “acceptable” button"]={ 0x1F251 },
 ["japanese “application” button"]={ 0x1F238 },
 ["japanese “bargain” button"]={ 0x1F250 },
 ["japanese “congratulations” button"]={ 0x3297, 0xFE0F },
 ["japanese “discount” button"]={ 0x1F239 },
 ["japanese “free of charge” button"]={ 0x1F21A },
 ["japanese “here” button"]={ 0x1F201 },
 ["japanese “monthly amount” button"]={ 0x1F237, 0xFE0F },
 ["japanese “no vacancy” button"]={ 0x1F235 },
 ["japanese “not free of charge” button"]={ 0x1F236 },
 ["japanese “open for business” button"]={ 0x1F23A },
 ["japanese “passing grade” button"]={ 0x1F234 },
 ["japanese “prohibited” button"]={ 0x1F232 },
 ["japanese “reserved” button"]={ 0x1F22F },
 ["japanese “secret” button"]={ 0x3299, 0xFE0F },
 ["japanese “service charge” button"]={ 0x1F202, 0xFE0F },
 ["japanese “vacancy” button"]={ 0x1F233 },
 ["jeans"]={ 0x1F456 },
 ["joker"]={ 0x1F0CF },
 ["joystick"]={ 0x1F579, 0xFE0F },
 ["judge"]={ 0x1F9D1, 0x200D, 0x2696, 0xFE0F },
 ["judge: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x2696, 0xFE0F },
 ["judge: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x2696, 0xFE0F },
 ["judge: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x2696, 0xFE0F },
 ["judge: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x2696, 0xFE0F },
 ["judge: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x2696, 0xFE0F },
 ["kaaba"]={ 0x1F54B },
 ["kangaroo"]={ 0x1F998 },
 ["key"]={ 0x1F511 },
 ["keyboard"]={ 0x2328, 0xFE0F },
 ["keycap: 0"]={ 0x30, 0xFE0F, 0x20E3 },
 ["keycap: 1"]={ 0x31, 0xFE0F, 0x20E3 },
 ["keycap: 10"]={ 0x1F51F },
 ["keycap: 2"]={ 0x32, 0xFE0F, 0x20E3 },
 ["keycap: 3"]={ 0x33, 0xFE0F, 0x20E3 },
 ["keycap: 4"]={ 0x34, 0xFE0F, 0x20E3 },
 ["keycap: 5"]={ 0x35, 0xFE0F, 0x20E3 },
 ["keycap: 6"]={ 0x36, 0xFE0F, 0x20E3 },
 ["keycap: 7"]={ 0x37, 0xFE0F, 0x20E3 },
 ["keycap: 8"]={ 0x38, 0xFE0F, 0x20E3 },
 ["keycap: 9"]={ 0x39, 0xFE0F, 0x20E3 },
 ["keycap: asterisk"]={ 0x2A, 0xFE0F, 0x20E3 },
 ["keycap: hash"]={ 0x23, 0xFE0F, 0x20E3 },
 ["kick scooter"]={ 0x1F6F4 },
 ["kimono"]={ 0x1F458 },
 ["kiss"]={ 0x1F48F },
 ["kiss mark"]={ 0x1F48B },
 ["kiss: man, man"]={ 0x1F468, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F48B, 0x200D, 0x1F468 },
 ["kiss: woman, man"]={ 0x1F469, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F48B, 0x200D, 0x1F468 },
 ["kiss: woman, woman"]={ 0x1F469, 0x200D, 0x2764, 0xFE0F, 0x200D, 0x1F48B, 0x200D, 0x1F469 },
 ["kissing cat"]={ 0x1F63D },
 ["kissing face"]={ 0x1F617 },
 ["kissing face with closed eyes"]={ 0x1F61A },
 ["kissing face with smiling eyes"]={ 0x1F619 },
 ["kitchen knife"]={ 0x1F52A },
 ["kite"]={ 0x1FA81 },
 ["kiwi fruit"]={ 0x1F95D },
 ["knot"]={ 0x1FAA2 },
 ["koala"]={ 0x1F428 },
 ["lab coat"]={ 0x1F97C },
 ["label"]={ 0x1F3F7, 0xFE0F },
 ["lacrosse"]={ 0x1F94D },
 ["ladder"]={ 0x1FA9C },
 ["lady beetle"]={ 0x1F41E },
 ["laptop"]={ 0x1F4BB },
 ["large blue diamond"]={ 0x1F537 },
 ["large orange diamond"]={ 0x1F536 },
 ["last quarter moon"]={ 0x1F317 },
 ["last quarter moon face"]={ 0x1F31C },
 ["last track button"]={ 0x23EE, 0xFE0F },
 ["latin cross"]={ 0x271D, 0xFE0F },
 ["leaf fluttering in wind"]={ 0x1F343 },
 ["leafy green"]={ 0x1F96C },
 ["ledger"]={ 0x1F4D2 },
 ["left arrow"]={ 0x2B05, 0xFE0F },
 ["left arrow curving right"]={ 0x21AA, 0xFE0F },
 ["left luggage"]={ 0x1F6C5 },
 ["left speech bubble"]={ 0x1F5E8, 0xFE0F },
 ["left-facing fist"]={ 0x1F91B },
 ["left-facing fist: dark skin tone"]={ 0x1F91B, 0x1F3FF },
 ["left-facing fist: light skin tone"]={ 0x1F91B, 0x1F3FB },
 ["left-facing fist: medium skin tone"]={ 0x1F91B, 0x1F3FD },
 ["left-facing fist: medium-dark skin tone"]={ 0x1F91B, 0x1F3FE },
 ["left-facing fist: medium-light skin tone"]={ 0x1F91B, 0x1F3FC },
 ["left-right arrow"]={ 0x2194, 0xFE0F },
 ["leg"]={ 0x1F9B5 },
 ["leg: dark skin tone"]={ 0x1F9B5, 0x1F3FF },
 ["leg: light skin tone"]={ 0x1F9B5, 0x1F3FB },
 ["leg: medium skin tone"]={ 0x1F9B5, 0x1F3FD },
 ["leg: medium-dark skin tone"]={ 0x1F9B5, 0x1F3FE },
 ["leg: medium-light skin tone"]={ 0x1F9B5, 0x1F3FC },
 ["lemon"]={ 0x1F34B },
 ["leo"]={ 0x264C },
 ["leopard"]={ 0x1F406 },
 ["level slider"]={ 0x1F39A, 0xFE0F },
 ["libra"]={ 0x264E },
 ["light bulb"]={ 0x1F4A1 },
 ["light rail"]={ 0x1F688 },
 ["link"]={ 0x1F517 },
 ["linked paperclips"]={ 0x1F587, 0xFE0F },
 ["lion"]={ 0x1F981 },
 ["lipstick"]={ 0x1F484 },
 ["litter in bin sign"]={ 0x1F6AE },
 ["lizard"]={ 0x1F98E },
 ["llama"]={ 0x1F999 },
 ["lobster"]={ 0x1F99E },
 ["locked"]={ 0x1F512 },
 ["locked with key"]={ 0x1F510 },
 ["locked with pen"]={ 0x1F50F },
 ["locomotive"]={ 0x1F682 },
 ["lollipop"]={ 0x1F36D },
 ["long drum"]={ 0x1FA98 },
 ["lotion bottle"]={ 0x1F9F4 },
 ["loudly crying face"]={ 0x1F62D },
 ["loudspeaker"]={ 0x1F4E2 },
 ["love hotel"]={ 0x1F3E9 },
 ["love letter"]={ 0x1F48C },
 ["love-you gesture"]={ 0x1F91F },
 ["love-you gesture: dark skin tone"]={ 0x1F91F, 0x1F3FF },
 ["love-you gesture: light skin tone"]={ 0x1F91F, 0x1F3FB },
 ["love-you gesture: medium skin tone"]={ 0x1F91F, 0x1F3FD },
 ["love-you gesture: medium-dark skin tone"]={ 0x1F91F, 0x1F3FE },
 ["love-you gesture: medium-light skin tone"]={ 0x1F91F, 0x1F3FC },
 ["luggage"]={ 0x1F9F3 },
 ["lungs"]={ 0x1FAC1 },
 ["lying face"]={ 0x1F925 },
 ["mage"]={ 0x1F9D9 },
 ["mage: dark skin tone"]={ 0x1F9D9, 0x1F3FF },
 ["mage: light skin tone"]={ 0x1F9D9, 0x1F3FB },
 ["mage: medium skin tone"]={ 0x1F9D9, 0x1F3FD },
 ["mage: medium-dark skin tone"]={ 0x1F9D9, 0x1F3FE },
 ["mage: medium-light skin tone"]={ 0x1F9D9, 0x1F3FC },
 ["magic wand"]={ 0x1FA84 },
 ["magnet"]={ 0x1F9F2 },
 ["magnifying glass tilted left"]={ 0x1F50D },
 ["magnifying glass tilted right"]={ 0x1F50E },
 ["mahjong red dragon"]={ 0x1F004 },
 ["male sign"]={ 0x2642, 0xFE0F },
 ["mammoth"]={ 0x1F9A3 },
 ["man"]={ 0x1F468 },
 ["man artist"]={ 0x1F468, 0x200D, 0x1F3A8 },
 ["man artist: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F3A8 },
 ["man artist: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F3A8 },
 ["man artist: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F3A8 },
 ["man artist: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F3A8 },
 ["man artist: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F3A8 },
 ["man astronaut"]={ 0x1F468, 0x200D, 0x1F680 },
 ["man astronaut: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F680 },
 ["man astronaut: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F680 },
 ["man astronaut: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F680 },
 ["man astronaut: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F680 },
 ["man astronaut: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F680 },
 ["man biking"]={ 0x1F6B4, 0x200D, 0x2642, 0xFE0F },
 ["man biking: dark skin tone"]={ 0x1F6B4, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man biking: light skin tone"]={ 0x1F6B4, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man biking: medium skin tone"]={ 0x1F6B4, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man biking: medium-dark skin tone"]={ 0x1F6B4, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man biking: medium-light skin tone"]={ 0x1F6B4, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball"]={ 0x26F9, 0xFE0F, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball: dark skin tone"]={ 0x26F9, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball: light skin tone"]={ 0x26F9, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball: medium skin tone"]={ 0x26F9, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball: medium-dark skin tone"]={ 0x26F9, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man bouncing ball: medium-light skin tone"]={ 0x26F9, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man bowing"]={ 0x1F647, 0x200D, 0x2642, 0xFE0F },
 ["man bowing: dark skin tone"]={ 0x1F647, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man bowing: light skin tone"]={ 0x1F647, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man bowing: medium skin tone"]={ 0x1F647, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man bowing: medium-dark skin tone"]={ 0x1F647, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man bowing: medium-light skin tone"]={ 0x1F647, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling"]={ 0x1F938, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling: dark skin tone"]={ 0x1F938, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling: light skin tone"]={ 0x1F938, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling: medium skin tone"]={ 0x1F938, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling: medium-dark skin tone"]={ 0x1F938, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man cartwheeling: medium-light skin tone"]={ 0x1F938, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man climbing"]={ 0x1F9D7, 0x200D, 0x2642, 0xFE0F },
 ["man climbing: dark skin tone"]={ 0x1F9D7, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man climbing: light skin tone"]={ 0x1F9D7, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man climbing: medium skin tone"]={ 0x1F9D7, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man climbing: medium-dark skin tone"]={ 0x1F9D7, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man climbing: medium-light skin tone"]={ 0x1F9D7, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker"]={ 0x1F477, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker: dark skin tone"]={ 0x1F477, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker: light skin tone"]={ 0x1F477, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker: medium skin tone"]={ 0x1F477, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker: medium-dark skin tone"]={ 0x1F477, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man construction worker: medium-light skin tone"]={ 0x1F477, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man cook"]={ 0x1F468, 0x200D, 0x1F373 },
 ["man cook: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F373 },
 ["man cook: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F373 },
 ["man cook: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F373 },
 ["man cook: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F373 },
 ["man cook: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F373 },
 ["man dancing"]={ 0x1F57A },
 ["man dancing: dark skin tone"]={ 0x1F57A, 0x1F3FF },
 ["man dancing: light skin tone"]={ 0x1F57A, 0x1F3FB },
 ["man dancing: medium skin tone"]={ 0x1F57A, 0x1F3FD },
 ["man dancing: medium-dark skin tone"]={ 0x1F57A, 0x1F3FE },
 ["man dancing: medium-light skin tone"]={ 0x1F57A, 0x1F3FC },
 ["man detective"]={ 0x1F575, 0xFE0F, 0x200D, 0x2642, 0xFE0F },
 ["man detective: dark skin tone"]={ 0x1F575, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man detective: light skin tone"]={ 0x1F575, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man detective: medium skin tone"]={ 0x1F575, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man detective: medium-dark skin tone"]={ 0x1F575, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man detective: medium-light skin tone"]={ 0x1F575, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man elf"]={ 0x1F9DD, 0x200D, 0x2642, 0xFE0F },
 ["man elf: dark skin tone"]={ 0x1F9DD, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man elf: light skin tone"]={ 0x1F9DD, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man elf: medium skin tone"]={ 0x1F9DD, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man elf: medium-dark skin tone"]={ 0x1F9DD, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man elf: medium-light skin tone"]={ 0x1F9DD, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming"]={ 0x1F926, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming: dark skin tone"]={ 0x1F926, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming: light skin tone"]={ 0x1F926, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming: medium skin tone"]={ 0x1F926, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming: medium-dark skin tone"]={ 0x1F926, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man facepalming: medium-light skin tone"]={ 0x1F926, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man factory worker"]={ 0x1F468, 0x200D, 0x1F3ED },
 ["man factory worker: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F3ED },
 ["man factory worker: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F3ED },
 ["man factory worker: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F3ED },
 ["man factory worker: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F3ED },
 ["man factory worker: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F3ED },
 ["man fairy"]={ 0x1F9DA, 0x200D, 0x2642, 0xFE0F },
 ["man fairy: dark skin tone"]={ 0x1F9DA, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man fairy: light skin tone"]={ 0x1F9DA, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man fairy: medium skin tone"]={ 0x1F9DA, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man fairy: medium-dark skin tone"]={ 0x1F9DA, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man fairy: medium-light skin tone"]={ 0x1F9DA, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man farmer"]={ 0x1F468, 0x200D, 0x1F33E },
 ["man farmer: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F33E },
 ["man farmer: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F33E },
 ["man farmer: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F33E },
 ["man farmer: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F33E },
 ["man farmer: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F33E },
 ["man feeding baby"]={ 0x1F468, 0x200D, 0x1F37C },
 ["man feeding baby: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F37C },
 ["man feeding baby: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F37C },
 ["man feeding baby: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F37C },
 ["man feeding baby: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F37C },
 ["man feeding baby: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F37C },
 ["man firefighter"]={ 0x1F468, 0x200D, 0x1F692 },
 ["man firefighter: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F692 },
 ["man firefighter: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F692 },
 ["man firefighter: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F692 },
 ["man firefighter: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F692 },
 ["man firefighter: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F692 },
 ["man frowning"]={ 0x1F64D, 0x200D, 0x2642, 0xFE0F },
 ["man frowning: dark skin tone"]={ 0x1F64D, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man frowning: light skin tone"]={ 0x1F64D, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man frowning: medium skin tone"]={ 0x1F64D, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man frowning: medium-dark skin tone"]={ 0x1F64D, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man frowning: medium-light skin tone"]={ 0x1F64D, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man genie"]={ 0x1F9DE, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no"]={ 0x1F645, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no: dark skin tone"]={ 0x1F645, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no: light skin tone"]={ 0x1F645, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no: medium skin tone"]={ 0x1F645, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no: medium-dark skin tone"]={ 0x1F645, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing no: medium-light skin tone"]={ 0x1F645, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok"]={ 0x1F646, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok: dark skin tone"]={ 0x1F646, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok: light skin tone"]={ 0x1F646, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok: medium skin tone"]={ 0x1F646, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok: medium-dark skin tone"]={ 0x1F646, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man gesturing ok: medium-light skin tone"]={ 0x1F646, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut"]={ 0x1F487, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut: dark skin tone"]={ 0x1F487, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut: light skin tone"]={ 0x1F487, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut: medium skin tone"]={ 0x1F487, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut: medium-dark skin tone"]={ 0x1F487, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man getting haircut: medium-light skin tone"]={ 0x1F487, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage"]={ 0x1F486, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage: dark skin tone"]={ 0x1F486, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage: light skin tone"]={ 0x1F486, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage: medium skin tone"]={ 0x1F486, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage: medium-dark skin tone"]={ 0x1F486, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man getting massage: medium-light skin tone"]={ 0x1F486, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man golfing"]={ 0x1F3CC, 0xFE0F, 0x200D, 0x2642, 0xFE0F },
 ["man golfing: dark skin tone"]={ 0x1F3CC, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man golfing: light skin tone"]={ 0x1F3CC, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man golfing: medium skin tone"]={ 0x1F3CC, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man golfing: medium-dark skin tone"]={ 0x1F3CC, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man golfing: medium-light skin tone"]={ 0x1F3CC, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man guard"]={ 0x1F482, 0x200D, 0x2642, 0xFE0F },
 ["man guard: dark skin tone"]={ 0x1F482, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man guard: light skin tone"]={ 0x1F482, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man guard: medium skin tone"]={ 0x1F482, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man guard: medium-dark skin tone"]={ 0x1F482, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man guard: medium-light skin tone"]={ 0x1F482, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man health worker"]={ 0x1F468, 0x200D, 0x2695, 0xFE0F },
 ["man health worker: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x2695, 0xFE0F },
 ["man health worker: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x2695, 0xFE0F },
 ["man health worker: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x2695, 0xFE0F },
 ["man health worker: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x2695, 0xFE0F },
 ["man health worker: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x2695, 0xFE0F },
 ["man in lotus position"]={ 0x1F9D8, 0x200D, 0x2642, 0xFE0F },
 ["man in lotus position: dark skin tone"]={ 0x1F9D8, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man in lotus position: light skin tone"]={ 0x1F9D8, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man in lotus position: medium skin tone"]={ 0x1F9D8, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man in lotus position: medium-dark skin tone"]={ 0x1F9D8, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man in lotus position: medium-light skin tone"]={ 0x1F9D8, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man in manual wheelchair"]={ 0x1F468, 0x200D, 0x1F9BD },
 ["man in manual wheelchair: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9BD },
 ["man in manual wheelchair: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9BD },
 ["man in manual wheelchair: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9BD },
 ["man in manual wheelchair: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9BD },
 ["man in manual wheelchair: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9BD },
 ["man in motorized wheelchair"]={ 0x1F468, 0x200D, 0x1F9BC },
 ["man in motorized wheelchair: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9BC },
 ["man in motorized wheelchair: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9BC },
 ["man in motorized wheelchair: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9BC },
 ["man in motorized wheelchair: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9BC },
 ["man in motorized wheelchair: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9BC },
 ["man in steamy room"]={ 0x1F9D6, 0x200D, 0x2642, 0xFE0F },
 ["man in steamy room: dark skin tone"]={ 0x1F9D6, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man in steamy room: light skin tone"]={ 0x1F9D6, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man in steamy room: medium skin tone"]={ 0x1F9D6, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man in steamy room: medium-dark skin tone"]={ 0x1F9D6, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man in steamy room: medium-light skin tone"]={ 0x1F9D6, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo"]={ 0x1F935, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo: dark skin tone"]={ 0x1F935, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo: light skin tone"]={ 0x1F935, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo: medium skin tone"]={ 0x1F935, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo: medium-dark skin tone"]={ 0x1F935, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man in tuxedo: medium-light skin tone"]={ 0x1F935, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man judge"]={ 0x1F468, 0x200D, 0x2696, 0xFE0F },
 ["man judge: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x2696, 0xFE0F },
 ["man judge: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x2696, 0xFE0F },
 ["man judge: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x2696, 0xFE0F },
 ["man judge: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x2696, 0xFE0F },
 ["man judge: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x2696, 0xFE0F },
 ["man juggling"]={ 0x1F939, 0x200D, 0x2642, 0xFE0F },
 ["man juggling: dark skin tone"]={ 0x1F939, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man juggling: light skin tone"]={ 0x1F939, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man juggling: medium skin tone"]={ 0x1F939, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man juggling: medium-dark skin tone"]={ 0x1F939, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man juggling: medium-light skin tone"]={ 0x1F939, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling"]={ 0x1F9CE, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling: dark skin tone"]={ 0x1F9CE, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling: light skin tone"]={ 0x1F9CE, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling: medium skin tone"]={ 0x1F9CE, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling: medium-dark skin tone"]={ 0x1F9CE, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man kneeling: medium-light skin tone"]={ 0x1F9CE, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights"]={ 0x1F3CB, 0xFE0F, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights: dark skin tone"]={ 0x1F3CB, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights: light skin tone"]={ 0x1F3CB, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights: medium skin tone"]={ 0x1F3CB, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights: medium-dark skin tone"]={ 0x1F3CB, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man lifting weights: medium-light skin tone"]={ 0x1F3CB, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man mage"]={ 0x1F9D9, 0x200D, 0x2642, 0xFE0F },
 ["man mage: dark skin tone"]={ 0x1F9D9, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man mage: light skin tone"]={ 0x1F9D9, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man mage: medium skin tone"]={ 0x1F9D9, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man mage: medium-dark skin tone"]={ 0x1F9D9, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man mage: medium-light skin tone"]={ 0x1F9D9, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man mechanic"]={ 0x1F468, 0x200D, 0x1F527 },
 ["man mechanic: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F527 },
 ["man mechanic: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F527 },
 ["man mechanic: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F527 },
 ["man mechanic: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F527 },
 ["man mechanic: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F527 },
 ["man mountain biking"]={ 0x1F6B5, 0x200D, 0x2642, 0xFE0F },
 ["man mountain biking: dark skin tone"]={ 0x1F6B5, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man mountain biking: light skin tone"]={ 0x1F6B5, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man mountain biking: medium skin tone"]={ 0x1F6B5, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man mountain biking: medium-dark skin tone"]={ 0x1F6B5, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man mountain biking: medium-light skin tone"]={ 0x1F6B5, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man office worker"]={ 0x1F468, 0x200D, 0x1F4BC },
 ["man office worker: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F4BC },
 ["man office worker: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F4BC },
 ["man office worker: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F4BC },
 ["man office worker: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F4BC },
 ["man office worker: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F4BC },
 ["man pilot"]={ 0x1F468, 0x200D, 0x2708, 0xFE0F },
 ["man pilot: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x2708, 0xFE0F },
 ["man pilot: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x2708, 0xFE0F },
 ["man pilot: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x2708, 0xFE0F },
 ["man pilot: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x2708, 0xFE0F },
 ["man pilot: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x2708, 0xFE0F },
 ["man playing handball"]={ 0x1F93E, 0x200D, 0x2642, 0xFE0F },
 ["man playing handball: dark skin tone"]={ 0x1F93E, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man playing handball: light skin tone"]={ 0x1F93E, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man playing handball: medium skin tone"]={ 0x1F93E, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man playing handball: medium-dark skin tone"]={ 0x1F93E, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man playing handball: medium-light skin tone"]={ 0x1F93E, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo"]={ 0x1F93D, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo: dark skin tone"]={ 0x1F93D, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo: light skin tone"]={ 0x1F93D, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo: medium skin tone"]={ 0x1F93D, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo: medium-dark skin tone"]={ 0x1F93D, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man playing water polo: medium-light skin tone"]={ 0x1F93D, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man police officer"]={ 0x1F46E, 0x200D, 0x2642, 0xFE0F },
 ["man police officer: dark skin tone"]={ 0x1F46E, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man police officer: light skin tone"]={ 0x1F46E, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man police officer: medium skin tone"]={ 0x1F46E, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man police officer: medium-dark skin tone"]={ 0x1F46E, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man police officer: medium-light skin tone"]={ 0x1F46E, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man pouting"]={ 0x1F64E, 0x200D, 0x2642, 0xFE0F },
 ["man pouting: dark skin tone"]={ 0x1F64E, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man pouting: light skin tone"]={ 0x1F64E, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man pouting: medium skin tone"]={ 0x1F64E, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man pouting: medium-dark skin tone"]={ 0x1F64E, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man pouting: medium-light skin tone"]={ 0x1F64E, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand"]={ 0x1F64B, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand: dark skin tone"]={ 0x1F64B, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand: light skin tone"]={ 0x1F64B, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand: medium skin tone"]={ 0x1F64B, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand: medium-dark skin tone"]={ 0x1F64B, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man raising hand: medium-light skin tone"]={ 0x1F64B, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat"]={ 0x1F6A3, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat: dark skin tone"]={ 0x1F6A3, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat: light skin tone"]={ 0x1F6A3, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat: medium skin tone"]={ 0x1F6A3, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat: medium-dark skin tone"]={ 0x1F6A3, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man rowing boat: medium-light skin tone"]={ 0x1F6A3, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man running"]={ 0x1F3C3, 0x200D, 0x2642, 0xFE0F },
 ["man running: dark skin tone"]={ 0x1F3C3, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man running: light skin tone"]={ 0x1F3C3, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man running: medium skin tone"]={ 0x1F3C3, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man running: medium-dark skin tone"]={ 0x1F3C3, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man running: medium-light skin tone"]={ 0x1F3C3, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man scientist"]={ 0x1F468, 0x200D, 0x1F52C },
 ["man scientist: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F52C },
 ["man scientist: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F52C },
 ["man scientist: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F52C },
 ["man scientist: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F52C },
 ["man scientist: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F52C },
 ["man shrugging"]={ 0x1F937, 0x200D, 0x2642, 0xFE0F },
 ["man shrugging: dark skin tone"]={ 0x1F937, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man shrugging: light skin tone"]={ 0x1F937, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man shrugging: medium skin tone"]={ 0x1F937, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man shrugging: medium-dark skin tone"]={ 0x1F937, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man shrugging: medium-light skin tone"]={ 0x1F937, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man singer"]={ 0x1F468, 0x200D, 0x1F3A4 },
 ["man singer: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F3A4 },
 ["man singer: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F3A4 },
 ["man singer: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F3A4 },
 ["man singer: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F3A4 },
 ["man singer: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F3A4 },
 ["man standing"]={ 0x1F9CD, 0x200D, 0x2642, 0xFE0F },
 ["man standing: dark skin tone"]={ 0x1F9CD, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man standing: light skin tone"]={ 0x1F9CD, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man standing: medium skin tone"]={ 0x1F9CD, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man standing: medium-dark skin tone"]={ 0x1F9CD, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man standing: medium-light skin tone"]={ 0x1F9CD, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man student"]={ 0x1F468, 0x200D, 0x1F393 },
 ["man student: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F393 },
 ["man student: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F393 },
 ["man student: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F393 },
 ["man student: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F393 },
 ["man student: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F393 },
 ["man superhero"]={ 0x1F9B8, 0x200D, 0x2642, 0xFE0F },
 ["man superhero: dark skin tone"]={ 0x1F9B8, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man superhero: light skin tone"]={ 0x1F9B8, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man superhero: medium skin tone"]={ 0x1F9B8, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man superhero: medium-dark skin tone"]={ 0x1F9B8, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man superhero: medium-light skin tone"]={ 0x1F9B8, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain"]={ 0x1F9B9, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain: dark skin tone"]={ 0x1F9B9, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain: light skin tone"]={ 0x1F9B9, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain: medium skin tone"]={ 0x1F9B9, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain: medium-dark skin tone"]={ 0x1F9B9, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man supervillain: medium-light skin tone"]={ 0x1F9B9, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man surfing"]={ 0x1F3C4, 0x200D, 0x2642, 0xFE0F },
 ["man surfing: dark skin tone"]={ 0x1F3C4, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man surfing: light skin tone"]={ 0x1F3C4, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man surfing: medium skin tone"]={ 0x1F3C4, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man surfing: medium-dark skin tone"]={ 0x1F3C4, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man surfing: medium-light skin tone"]={ 0x1F3C4, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man swimming"]={ 0x1F3CA, 0x200D, 0x2642, 0xFE0F },
 ["man swimming: dark skin tone"]={ 0x1F3CA, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man swimming: light skin tone"]={ 0x1F3CA, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man swimming: medium skin tone"]={ 0x1F3CA, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man swimming: medium-dark skin tone"]={ 0x1F3CA, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man swimming: medium-light skin tone"]={ 0x1F3CA, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man teacher"]={ 0x1F468, 0x200D, 0x1F3EB },
 ["man teacher: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F3EB },
 ["man teacher: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F3EB },
 ["man teacher: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F3EB },
 ["man teacher: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F3EB },
 ["man teacher: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F3EB },
 ["man technologist"]={ 0x1F468, 0x200D, 0x1F4BB },
 ["man technologist: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F4BB },
 ["man technologist: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F4BB },
 ["man technologist: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F4BB },
 ["man technologist: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F4BB },
 ["man technologist: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F4BB },
 ["man tipping hand"]={ 0x1F481, 0x200D, 0x2642, 0xFE0F },
 ["man tipping hand: dark skin tone"]={ 0x1F481, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man tipping hand: light skin tone"]={ 0x1F481, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man tipping hand: medium skin tone"]={ 0x1F481, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man tipping hand: medium-dark skin tone"]={ 0x1F481, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man tipping hand: medium-light skin tone"]={ 0x1F481, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man vampire"]={ 0x1F9DB, 0x200D, 0x2642, 0xFE0F },
 ["man vampire: dark skin tone"]={ 0x1F9DB, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man vampire: light skin tone"]={ 0x1F9DB, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man vampire: medium skin tone"]={ 0x1F9DB, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man vampire: medium-dark skin tone"]={ 0x1F9DB, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man vampire: medium-light skin tone"]={ 0x1F9DB, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man walking"]={ 0x1F6B6, 0x200D, 0x2642, 0xFE0F },
 ["man walking: dark skin tone"]={ 0x1F6B6, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man walking: light skin tone"]={ 0x1F6B6, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man walking: medium skin tone"]={ 0x1F6B6, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man walking: medium-dark skin tone"]={ 0x1F6B6, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man walking: medium-light skin tone"]={ 0x1F6B6, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban"]={ 0x1F473, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban: dark skin tone"]={ 0x1F473, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban: light skin tone"]={ 0x1F473, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban: medium skin tone"]={ 0x1F473, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban: medium-dark skin tone"]={ 0x1F473, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man wearing turban: medium-light skin tone"]={ 0x1F473, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man with veil"]={ 0x1F470, 0x200D, 0x2642, 0xFE0F },
 ["man with veil: dark skin tone"]={ 0x1F470, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man with veil: light skin tone"]={ 0x1F470, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man with veil: medium skin tone"]={ 0x1F470, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man with veil: medium-dark skin tone"]={ 0x1F470, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man with veil: medium-light skin tone"]={ 0x1F470, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man with white cane"]={ 0x1F468, 0x200D, 0x1F9AF },
 ["man with white cane: dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9AF },
 ["man with white cane: light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9AF },
 ["man with white cane: medium skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9AF },
 ["man with white cane: medium-dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9AF },
 ["man with white cane: medium-light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9AF },
 ["man zombie"]={ 0x1F9DF, 0x200D, 0x2642, 0xFE0F },
 ["man: bald"]={ 0x1F468, 0x200D, 0x1F9B2 },
 ["man: beard"]={ 0x1F9D4 },
 ["man: blond hair"]={ 0x1F471, 0x200D, 0x2642, 0xFE0F },
 ["man: curly hair"]={ 0x1F468, 0x200D, 0x1F9B1 },
 ["man: dark skin tone"]={ 0x1F468, 0x1F3FF },
 ["man: dark skin tone, bald"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9B2 },
 ["man: dark skin tone, beard"]={ 0x1F9D4, 0x1F3FF },
 ["man: dark skin tone, blond hair"]={ 0x1F471, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["man: dark skin tone, curly hair"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9B1 },
 ["man: dark skin tone, red hair"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9B0 },
 ["man: dark skin tone, white hair"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F9B3 },
 ["man: light skin tone"]={ 0x1F468, 0x1F3FB },
 ["man: light skin tone, bald"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9B2 },
 ["man: light skin tone, beard"]={ 0x1F9D4, 0x1F3FB },
 ["man: light skin tone, blond hair"]={ 0x1F471, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["man: light skin tone, curly hair"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9B1 },
 ["man: light skin tone, red hair"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9B0 },
 ["man: light skin tone, white hair"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F9B3 },
 ["man: medium skin tone"]={ 0x1F468, 0x1F3FD },
 ["man: medium skin tone, bald"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9B2 },
 ["man: medium skin tone, beard"]={ 0x1F9D4, 0x1F3FD },
 ["man: medium skin tone, blond hair"]={ 0x1F471, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["man: medium skin tone, curly hair"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9B1 },
 ["man: medium skin tone, red hair"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9B0 },
 ["man: medium skin tone, white hair"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F9B3 },
 ["man: medium-dark skin tone"]={ 0x1F468, 0x1F3FE },
 ["man: medium-dark skin tone, bald"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9B2 },
 ["man: medium-dark skin tone, beard"]={ 0x1F9D4, 0x1F3FE },
 ["man: medium-dark skin tone, blond hair"]={ 0x1F471, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["man: medium-dark skin tone, curly hair"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9B1 },
 ["man: medium-dark skin tone, red hair"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9B0 },
 ["man: medium-dark skin tone, white hair"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F9B3 },
 ["man: medium-light skin tone"]={ 0x1F468, 0x1F3FC },
 ["man: medium-light skin tone, bald"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9B2 },
 ["man: medium-light skin tone, beard"]={ 0x1F9D4, 0x1F3FC },
 ["man: medium-light skin tone, blond hair"]={ 0x1F471, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["man: medium-light skin tone, curly hair"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9B1 },
 ["man: medium-light skin tone, red hair"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9B0 },
 ["man: medium-light skin tone, white hair"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F9B3 },
 ["man: red hair"]={ 0x1F468, 0x200D, 0x1F9B0 },
 ["man: white hair"]={ 0x1F468, 0x200D, 0x1F9B3 },
 ["mango"]={ 0x1F96D },
 ["mantelpiece clock"]={ 0x1F570, 0xFE0F },
 ["manual wheelchair"]={ 0x1F9BD },
 ["man’s shoe"]={ 0x1F45E },
 ["map of japan"]={ 0x1F5FE },
 ["maple leaf"]={ 0x1F341 },
 ["martial arts uniform"]={ 0x1F94B },
 ["mate"]={ 0x1F9C9 },
 ["meat on bone"]={ 0x1F356 },
 ["mechanic"]={ 0x1F9D1, 0x200D, 0x1F527 },
 ["mechanic: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F527 },
 ["mechanic: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F527 },
 ["mechanic: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F527 },
 ["mechanic: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F527 },
 ["mechanic: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F527 },
 ["mechanical arm"]={ 0x1F9BE },
 ["mechanical leg"]={ 0x1F9BF },
 ["medical symbol"]={ 0x2695, 0xFE0F },
 ["megaphone"]={ 0x1F4E3 },
 ["melon"]={ 0x1F348 },
 ["memo"]={ 0x1F4DD },
 ["men holding hands"]={ 0x1F46C },
 ["men holding hands: dark skin tone"]={ 0x1F46C, 0x1F3FF },
 ["men holding hands: dark skin tone, light skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["men holding hands: dark skin tone, medium skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["men holding hands: dark skin tone, medium-dark skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["men holding hands: dark skin tone, medium-light skin tone"]={ 0x1F468, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["men holding hands: light skin tone"]={ 0x1F46C, 0x1F3FB },
 ["men holding hands: light skin tone, dark skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["men holding hands: light skin tone, medium skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["men holding hands: light skin tone, medium-dark skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["men holding hands: light skin tone, medium-light skin tone"]={ 0x1F468, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["men holding hands: medium skin tone"]={ 0x1F46C, 0x1F3FD },
 ["men holding hands: medium skin tone, dark skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["men holding hands: medium skin tone, light skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["men holding hands: medium skin tone, medium-dark skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["men holding hands: medium skin tone, medium-light skin tone"]={ 0x1F468, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["men holding hands: medium-dark skin tone"]={ 0x1F46C, 0x1F3FE },
 ["men holding hands: medium-dark skin tone, dark skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["men holding hands: medium-dark skin tone, light skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["men holding hands: medium-dark skin tone, medium skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["men holding hands: medium-dark skin tone, medium-light skin tone"]={ 0x1F468, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["men holding hands: medium-light skin tone"]={ 0x1F46C, 0x1F3FC },
 ["men holding hands: medium-light skin tone, dark skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["men holding hands: medium-light skin tone, light skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["men holding hands: medium-light skin tone, medium skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["men holding hands: medium-light skin tone, medium-dark skin tone"]={ 0x1F468, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["men with bunny ears"]={ 0x1F46F, 0x200D, 0x2642, 0xFE0F },
 ["men wrestling"]={ 0x1F93C, 0x200D, 0x2642, 0xFE0F },
 ["menorah"]={ 0x1F54E },
 ["men’s room"]={ 0x1F6B9 },
 ["mermaid"]={ 0x1F9DC, 0x200D, 0x2640, 0xFE0F },
 ["mermaid: dark skin tone"]={ 0x1F9DC, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["mermaid: light skin tone"]={ 0x1F9DC, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["mermaid: medium skin tone"]={ 0x1F9DC, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["mermaid: medium-dark skin tone"]={ 0x1F9DC, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["mermaid: medium-light skin tone"]={ 0x1F9DC, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["merman"]={ 0x1F9DC, 0x200D, 0x2642, 0xFE0F },
 ["merman: dark skin tone"]={ 0x1F9DC, 0x1F3FF, 0x200D, 0x2642, 0xFE0F },
 ["merman: light skin tone"]={ 0x1F9DC, 0x1F3FB, 0x200D, 0x2642, 0xFE0F },
 ["merman: medium skin tone"]={ 0x1F9DC, 0x1F3FD, 0x200D, 0x2642, 0xFE0F },
 ["merman: medium-dark skin tone"]={ 0x1F9DC, 0x1F3FE, 0x200D, 0x2642, 0xFE0F },
 ["merman: medium-light skin tone"]={ 0x1F9DC, 0x1F3FC, 0x200D, 0x2642, 0xFE0F },
 ["merperson"]={ 0x1F9DC },
 ["merperson: dark skin tone"]={ 0x1F9DC, 0x1F3FF },
 ["merperson: light skin tone"]={ 0x1F9DC, 0x1F3FB },
 ["merperson: medium skin tone"]={ 0x1F9DC, 0x1F3FD },
 ["merperson: medium-dark skin tone"]={ 0x1F9DC, 0x1F3FE },
 ["merperson: medium-light skin tone"]={ 0x1F9DC, 0x1F3FC },
 ["metro"]={ 0x1F687 },
 ["microbe"]={ 0x1F9A0 },
 ["microphone"]={ 0x1F3A4 },
 ["microscope"]={ 0x1F52C },
 ["middle finger"]={ 0x1F595 },
 ["middle finger: dark skin tone"]={ 0x1F595, 0x1F3FF },
 ["middle finger: light skin tone"]={ 0x1F595, 0x1F3FB },
 ["middle finger: medium skin tone"]={ 0x1F595, 0x1F3FD },
 ["middle finger: medium-dark skin tone"]={ 0x1F595, 0x1F3FE },
 ["middle finger: medium-light skin tone"]={ 0x1F595, 0x1F3FC },
 ["military helmet"]={ 0x1FA96 },
 ["military medal"]={ 0x1F396, 0xFE0F },
 ["milky way"]={ 0x1F30C },
 ["minibus"]={ 0x1F690 },
 ["minus"]={ 0x2796 },
 ["mirror"]={ 0x1FA9E },
 ["moai"]={ 0x1F5FF },
 ["mobile phone"]={ 0x1F4F1 },
 ["mobile phone off"]={ 0x1F4F4 },
 ["mobile phone with arrow"]={ 0x1F4F2 },
 ["money bag"]={ 0x1F4B0 },
 ["money with wings"]={ 0x1F4B8 },
 ["money-mouth face"]={ 0x1F911 },
 ["monkey"]={ 0x1F412 },
 ["monkey face"]={ 0x1F435 },
 ["monorail"]={ 0x1F69D },
 ["moon cake"]={ 0x1F96E },
 ["moon viewing ceremony"]={ 0x1F391 },
 ["mosque"]={ 0x1F54C },
 ["mosquito"]={ 0x1F99F },
 ["motor boat"]={ 0x1F6E5, 0xFE0F },
 ["motor scooter"]={ 0x1F6F5 },
 ["motorcycle"]={ 0x1F3CD, 0xFE0F },
 ["motorized wheelchair"]={ 0x1F9BC },
 ["motorway"]={ 0x1F6E3, 0xFE0F },
 ["mount fuji"]={ 0x1F5FB },
 ["mountain"]={ 0x26F0, 0xFE0F },
 ["mountain cableway"]={ 0x1F6A0 },
 ["mountain railway"]={ 0x1F69E },
 ["mouse"]={ 0x1F401 },
 ["mouse face"]={ 0x1F42D },
 ["mouse trap"]={ 0x1FAA4 },
 ["mouth"]={ 0x1F444 },
 ["movie camera"]={ 0x1F3A5 },
 ["mrs. claus"]={ 0x1F936 },
 ["mrs. claus: dark skin tone"]={ 0x1F936, 0x1F3FF },
 ["mrs. claus: light skin tone"]={ 0x1F936, 0x1F3FB },
 ["mrs. claus: medium skin tone"]={ 0x1F936, 0x1F3FD },
 ["mrs. claus: medium-dark skin tone"]={ 0x1F936, 0x1F3FE },
 ["mrs. claus: medium-light skin tone"]={ 0x1F936, 0x1F3FC },
 ["multiply"]={ 0x2716, 0xFE0F },
 ["mushroom"]={ 0x1F344 },
 ["musical keyboard"]={ 0x1F3B9 },
 ["musical note"]={ 0x1F3B5 },
 ["musical notes"]={ 0x1F3B6 },
 ["musical score"]={ 0x1F3BC },
 ["muted speaker"]={ 0x1F507 },
 ["mx claus"]={ 0x1F9D1, 0x200D, 0x1F384 },
 ["mx claus: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F384 },
 ["mx claus: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F384 },
 ["mx claus: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F384 },
 ["mx claus: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F384 },
 ["mx claus: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F384 },
 ["nail polish"]={ 0x1F485 },
 ["nail polish: dark skin tone"]={ 0x1F485, 0x1F3FF },
 ["nail polish: light skin tone"]={ 0x1F485, 0x1F3FB },
 ["nail polish: medium skin tone"]={ 0x1F485, 0x1F3FD },
 ["nail polish: medium-dark skin tone"]={ 0x1F485, 0x1F3FE },
 ["nail polish: medium-light skin tone"]={ 0x1F485, 0x1F3FC },
 ["name badge"]={ 0x1F4DB },
 ["national park"]={ 0x1F3DE, 0xFE0F },
 ["nauseated face"]={ 0x1F922 },
 ["nazar amulet"]={ 0x1F9FF },
 ["necktie"]={ 0x1F454 },
 ["nerd face"]={ 0x1F913 },
 ["nesting dolls"]={ 0x1FA86 },
 ["neutral face"]={ 0x1F610 },
 ["new button"]={ 0x1F195 },
 ["new moon"]={ 0x1F311 },
 ["new moon face"]={ 0x1F31A },
 ["newspaper"]={ 0x1F4F0 },
 ["next track button"]={ 0x23ED, 0xFE0F },
 ["ng button"]={ 0x1F196 },
 ["night with stars"]={ 0x1F303 },
 ["nine o’clock"]={ 0x1F558 },
 ["nine-thirty"]={ 0x1F564 },
 ["ninja"]={ 0x1F977 },
 ["ninja: dark skin tone"]={ 0x1F977, 0x1F3FF },
 ["ninja: light skin tone"]={ 0x1F977, 0x1F3FB },
 ["ninja: medium skin tone"]={ 0x1F977, 0x1F3FD },
 ["ninja: medium-dark skin tone"]={ 0x1F977, 0x1F3FE },
 ["ninja: medium-light skin tone"]={ 0x1F977, 0x1F3FC },
 ["no bicycles"]={ 0x1F6B3 },
 ["no entry"]={ 0x26D4 },
 ["no littering"]={ 0x1F6AF },
 ["no mobile phones"]={ 0x1F4F5 },
 ["no one under eighteen"]={ 0x1F51E },
 ["no pedestrians"]={ 0x1F6B7 },
 ["no smoking"]={ 0x1F6AD },
 ["non-potable water"]={ 0x1F6B1 },
 ["nose"]={ 0x1F443 },
 ["nose: dark skin tone"]={ 0x1F443, 0x1F3FF },
 ["nose: light skin tone"]={ 0x1F443, 0x1F3FB },
 ["nose: medium skin tone"]={ 0x1F443, 0x1F3FD },
 ["nose: medium-dark skin tone"]={ 0x1F443, 0x1F3FE },
 ["nose: medium-light skin tone"]={ 0x1F443, 0x1F3FC },
 ["notebook"]={ 0x1F4D3 },
 ["notebook with decorative cover"]={ 0x1F4D4 },
 ["nut and bolt"]={ 0x1F529 },
 ["o button (blood type)"]={ 0x1F17E, 0xFE0F },
 ["octopus"]={ 0x1F419 },
 ["oden"]={ 0x1F362 },
 ["office building"]={ 0x1F3E2 },
 ["office worker"]={ 0x1F9D1, 0x200D, 0x1F4BC },
 ["office worker: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F4BC },
 ["office worker: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F4BC },
 ["office worker: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F4BC },
 ["office worker: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F4BC },
 ["office worker: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F4BC },
 ["ogre"]={ 0x1F479 },
 ["oil drum"]={ 0x1F6E2, 0xFE0F },
 ["ok button"]={ 0x1F197 },
 ["ok hand"]={ 0x1F44C },
 ["ok hand: dark skin tone"]={ 0x1F44C, 0x1F3FF },
 ["ok hand: light skin tone"]={ 0x1F44C, 0x1F3FB },
 ["ok hand: medium skin tone"]={ 0x1F44C, 0x1F3FD },
 ["ok hand: medium-dark skin tone"]={ 0x1F44C, 0x1F3FE },
 ["ok hand: medium-light skin tone"]={ 0x1F44C, 0x1F3FC },
 ["old key"]={ 0x1F5DD, 0xFE0F },
 ["old man"]={ 0x1F474 },
 ["old man: dark skin tone"]={ 0x1F474, 0x1F3FF },
 ["old man: light skin tone"]={ 0x1F474, 0x1F3FB },
 ["old man: medium skin tone"]={ 0x1F474, 0x1F3FD },
 ["old man: medium-dark skin tone"]={ 0x1F474, 0x1F3FE },
 ["old man: medium-light skin tone"]={ 0x1F474, 0x1F3FC },
 ["old woman"]={ 0x1F475 },
 ["old woman: dark skin tone"]={ 0x1F475, 0x1F3FF },
 ["old woman: light skin tone"]={ 0x1F475, 0x1F3FB },
 ["old woman: medium skin tone"]={ 0x1F475, 0x1F3FD },
 ["old woman: medium-dark skin tone"]={ 0x1F475, 0x1F3FE },
 ["old woman: medium-light skin tone"]={ 0x1F475, 0x1F3FC },
 ["older person"]={ 0x1F9D3 },
 ["older person: dark skin tone"]={ 0x1F9D3, 0x1F3FF },
 ["older person: light skin tone"]={ 0x1F9D3, 0x1F3FB },
 ["older person: medium skin tone"]={ 0x1F9D3, 0x1F3FD },
 ["older person: medium-dark skin tone"]={ 0x1F9D3, 0x1F3FE },
 ["older person: medium-light skin tone"]={ 0x1F9D3, 0x1F3FC },
 ["olive"]={ 0x1FAD2 },
 ["om"]={ 0x1F549, 0xFE0F },
 ["on! arrow"]={ 0x1F51B },
 ["oncoming automobile"]={ 0x1F698 },
 ["oncoming bus"]={ 0x1F68D },
 ["oncoming fist"]={ 0x1F44A },
 ["oncoming fist: dark skin tone"]={ 0x1F44A, 0x1F3FF },
 ["oncoming fist: light skin tone"]={ 0x1F44A, 0x1F3FB },
 ["oncoming fist: medium skin tone"]={ 0x1F44A, 0x1F3FD },
 ["oncoming fist: medium-dark skin tone"]={ 0x1F44A, 0x1F3FE },
 ["oncoming fist: medium-light skin tone"]={ 0x1F44A, 0x1F3FC },
 ["oncoming police car"]={ 0x1F694 },
 ["oncoming taxi"]={ 0x1F696 },
 ["one o’clock"]={ 0x1F550 },
 ["one-piece swimsuit"]={ 0x1FA71 },
 ["one-thirty"]={ 0x1F55C },
 ["onion"]={ 0x1F9C5 },
 ["open book"]={ 0x1F4D6 },
 ["open file folder"]={ 0x1F4C2 },
 ["open hands"]={ 0x1F450 },
 ["open hands: dark skin tone"]={ 0x1F450, 0x1F3FF },
 ["open hands: light skin tone"]={ 0x1F450, 0x1F3FB },
 ["open hands: medium skin tone"]={ 0x1F450, 0x1F3FD },
 ["open hands: medium-dark skin tone"]={ 0x1F450, 0x1F3FE },
 ["open hands: medium-light skin tone"]={ 0x1F450, 0x1F3FC },
 ["open mailbox with lowered flag"]={ 0x1F4ED },
 ["open mailbox with raised flag"]={ 0x1F4EC },
 ["ophiuchus"]={ 0x26CE },
 ["optical disk"]={ 0x1F4BF },
 ["orange book"]={ 0x1F4D9 },
 ["orange circle"]={ 0x1F7E0 },
 ["orange heart"]={ 0x1F9E1 },
 ["orange square"]={ 0x1F7E7 },
 ["orangutan"]={ 0x1F9A7 },
 ["orthodox cross"]={ 0x2626, 0xFE0F },
 ["otter"]={ 0x1F9A6 },
 ["outbox tray"]={ 0x1F4E4 },
 ["owl"]={ 0x1F989 },
 ["ox"]={ 0x1F402 },
 ["oyster"]={ 0x1F9AA },
 ["p button"]={ 0x1F17F, 0xFE0F },
 ["package"]={ 0x1F4E6 },
 ["page facing up"]={ 0x1F4C4 },
 ["page with curl"]={ 0x1F4C3 },
 ["pager"]={ 0x1F4DF },
 ["paintbrush"]={ 0x1F58C, 0xFE0F },
 ["palm tree"]={ 0x1F334 },
 ["palms up together"]={ 0x1F932 },
 ["palms up together: dark skin tone"]={ 0x1F932, 0x1F3FF },
 ["palms up together: light skin tone"]={ 0x1F932, 0x1F3FB },
 ["palms up together: medium skin tone"]={ 0x1F932, 0x1F3FD },
 ["palms up together: medium-dark skin tone"]={ 0x1F932, 0x1F3FE },
 ["palms up together: medium-light skin tone"]={ 0x1F932, 0x1F3FC },
 ["pancakes"]={ 0x1F95E },
 ["panda"]={ 0x1F43C },
 ["paperclip"]={ 0x1F4CE },
 ["parachute"]={ 0x1FA82 },
 ["parrot"]={ 0x1F99C },
 ["part alternation mark"]={ 0x303D, 0xFE0F },
 ["party popper"]={ 0x1F389 },
 ["partying face"]={ 0x1F973 },
 ["passenger ship"]={ 0x1F6F3, 0xFE0F },
 ["passport control"]={ 0x1F6C2 },
 ["pause button"]={ 0x23F8, 0xFE0F },
 ["paw prints"]={ 0x1F43E },
 ["peace symbol"]={ 0x262E, 0xFE0F },
 ["peach"]={ 0x1F351 },
 ["peacock"]={ 0x1F99A },
 ["peanuts"]={ 0x1F95C },
 ["pear"]={ 0x1F350 },
 ["pen"]={ 0x1F58A, 0xFE0F },
 ["pencil"]={ 0x270F, 0xFE0F },
 ["penguin"]={ 0x1F427 },
 ["pensive face"]={ 0x1F614 },
 ["people holding hands"]={ 0x1F9D1, 0x200D, 0x1F91D, 0x200D, 0x1F9D1 },
 ["people holding hands: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FF },
 ["people holding hands: dark skin tone, light skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FB },
 ["people holding hands: dark skin tone, medium skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FD },
 ["people holding hands: dark skin tone, medium-dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FE },
 ["people holding hands: dark skin tone, medium-light skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FC },
 ["people holding hands: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FB },
 ["people holding hands: light skin tone, dark skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FF },
 ["people holding hands: light skin tone, medium skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FD },
 ["people holding hands: light skin tone, medium-dark skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FE },
 ["people holding hands: light skin tone, medium-light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FC },
 ["people holding hands: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FD },
 ["people holding hands: medium skin tone, dark skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FF },
 ["people holding hands: medium skin tone, light skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FB },
 ["people holding hands: medium skin tone, medium-dark skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FE },
 ["people holding hands: medium skin tone, medium-light skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FC },
 ["people holding hands: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FE },
 ["people holding hands: medium-dark skin tone, dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FF },
 ["people holding hands: medium-dark skin tone, light skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FB },
 ["people holding hands: medium-dark skin tone, medium skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FD },
 ["people holding hands: medium-dark skin tone, medium-light skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FC },
 ["people holding hands: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FC },
 ["people holding hands: medium-light skin tone, dark skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FF },
 ["people holding hands: medium-light skin tone, light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FB },
 ["people holding hands: medium-light skin tone, medium skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FD },
 ["people holding hands: medium-light skin tone, medium-dark skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F9D1, 0x1F3FE },
 ["people hugging"]={ 0x1FAC2 },
 ["people with bunny ears"]={ 0x1F46F },
 ["people wrestling"]={ 0x1F93C },
 ["performing arts"]={ 0x1F3AD },
 ["persevering face"]={ 0x1F623 },
 ["person"]={ 0x1F9D1 },
 ["person biking"]={ 0x1F6B4 },
 ["person biking: dark skin tone"]={ 0x1F6B4, 0x1F3FF },
 ["person biking: light skin tone"]={ 0x1F6B4, 0x1F3FB },
 ["person biking: medium skin tone"]={ 0x1F6B4, 0x1F3FD },
 ["person biking: medium-dark skin tone"]={ 0x1F6B4, 0x1F3FE },
 ["person biking: medium-light skin tone"]={ 0x1F6B4, 0x1F3FC },
 ["person bouncing ball"]={ 0x26F9, 0xFE0F },
 ["person bouncing ball: dark skin tone"]={ 0x26F9, 0x1F3FF },
 ["person bouncing ball: light skin tone"]={ 0x26F9, 0x1F3FB },
 ["person bouncing ball: medium skin tone"]={ 0x26F9, 0x1F3FD },
 ["person bouncing ball: medium-dark skin tone"]={ 0x26F9, 0x1F3FE },
 ["person bouncing ball: medium-light skin tone"]={ 0x26F9, 0x1F3FC },
 ["person bowing"]={ 0x1F647 },
 ["person bowing: dark skin tone"]={ 0x1F647, 0x1F3FF },
 ["person bowing: light skin tone"]={ 0x1F647, 0x1F3FB },
 ["person bowing: medium skin tone"]={ 0x1F647, 0x1F3FD },
 ["person bowing: medium-dark skin tone"]={ 0x1F647, 0x1F3FE },
 ["person bowing: medium-light skin tone"]={ 0x1F647, 0x1F3FC },
 ["person cartwheeling"]={ 0x1F938 },
 ["person cartwheeling: dark skin tone"]={ 0x1F938, 0x1F3FF },
 ["person cartwheeling: light skin tone"]={ 0x1F938, 0x1F3FB },
 ["person cartwheeling: medium skin tone"]={ 0x1F938, 0x1F3FD },
 ["person cartwheeling: medium-dark skin tone"]={ 0x1F938, 0x1F3FE },
 ["person cartwheeling: medium-light skin tone"]={ 0x1F938, 0x1F3FC },
 ["person climbing"]={ 0x1F9D7 },
 ["person climbing: dark skin tone"]={ 0x1F9D7, 0x1F3FF },
 ["person climbing: light skin tone"]={ 0x1F9D7, 0x1F3FB },
 ["person climbing: medium skin tone"]={ 0x1F9D7, 0x1F3FD },
 ["person climbing: medium-dark skin tone"]={ 0x1F9D7, 0x1F3FE },
 ["person climbing: medium-light skin tone"]={ 0x1F9D7, 0x1F3FC },
 ["person facepalming"]={ 0x1F926 },
 ["person facepalming: dark skin tone"]={ 0x1F926, 0x1F3FF },
 ["person facepalming: light skin tone"]={ 0x1F926, 0x1F3FB },
 ["person facepalming: medium skin tone"]={ 0x1F926, 0x1F3FD },
 ["person facepalming: medium-dark skin tone"]={ 0x1F926, 0x1F3FE },
 ["person facepalming: medium-light skin tone"]={ 0x1F926, 0x1F3FC },
 ["person feeding baby"]={ 0x1F9D1, 0x200D, 0x1F37C },
 ["person feeding baby: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F37C },
 ["person feeding baby: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F37C },
 ["person feeding baby: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F37C },
 ["person feeding baby: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F37C },
 ["person feeding baby: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F37C },
 ["person fencing"]={ 0x1F93A },
 ["person frowning"]={ 0x1F64D },
 ["person frowning: dark skin tone"]={ 0x1F64D, 0x1F3FF },
 ["person frowning: light skin tone"]={ 0x1F64D, 0x1F3FB },
 ["person frowning: medium skin tone"]={ 0x1F64D, 0x1F3FD },
 ["person frowning: medium-dark skin tone"]={ 0x1F64D, 0x1F3FE },
 ["person frowning: medium-light skin tone"]={ 0x1F64D, 0x1F3FC },
 ["person gesturing no"]={ 0x1F645 },
 ["person gesturing no: dark skin tone"]={ 0x1F645, 0x1F3FF },
 ["person gesturing no: light skin tone"]={ 0x1F645, 0x1F3FB },
 ["person gesturing no: medium skin tone"]={ 0x1F645, 0x1F3FD },
 ["person gesturing no: medium-dark skin tone"]={ 0x1F645, 0x1F3FE },
 ["person gesturing no: medium-light skin tone"]={ 0x1F645, 0x1F3FC },
 ["person gesturing ok"]={ 0x1F646 },
 ["person gesturing ok: dark skin tone"]={ 0x1F646, 0x1F3FF },
 ["person gesturing ok: light skin tone"]={ 0x1F646, 0x1F3FB },
 ["person gesturing ok: medium skin tone"]={ 0x1F646, 0x1F3FD },
 ["person gesturing ok: medium-dark skin tone"]={ 0x1F646, 0x1F3FE },
 ["person gesturing ok: medium-light skin tone"]={ 0x1F646, 0x1F3FC },
 ["person getting haircut"]={ 0x1F487 },
 ["person getting haircut: dark skin tone"]={ 0x1F487, 0x1F3FF },
 ["person getting haircut: light skin tone"]={ 0x1F487, 0x1F3FB },
 ["person getting haircut: medium skin tone"]={ 0x1F487, 0x1F3FD },
 ["person getting haircut: medium-dark skin tone"]={ 0x1F487, 0x1F3FE },
 ["person getting haircut: medium-light skin tone"]={ 0x1F487, 0x1F3FC },
 ["person getting massage"]={ 0x1F486 },
 ["person getting massage: dark skin tone"]={ 0x1F486, 0x1F3FF },
 ["person getting massage: light skin tone"]={ 0x1F486, 0x1F3FB },
 ["person getting massage: medium skin tone"]={ 0x1F486, 0x1F3FD },
 ["person getting massage: medium-dark skin tone"]={ 0x1F486, 0x1F3FE },
 ["person getting massage: medium-light skin tone"]={ 0x1F486, 0x1F3FC },
 ["person golfing"]={ 0x1F3CC, 0xFE0F },
 ["person golfing: dark skin tone"]={ 0x1F3CC, 0x1F3FF },
 ["person golfing: light skin tone"]={ 0x1F3CC, 0x1F3FB },
 ["person golfing: medium skin tone"]={ 0x1F3CC, 0x1F3FD },
 ["person golfing: medium-dark skin tone"]={ 0x1F3CC, 0x1F3FE },
 ["person golfing: medium-light skin tone"]={ 0x1F3CC, 0x1F3FC },
 ["person in bed"]={ 0x1F6CC },
 ["person in bed: dark skin tone"]={ 0x1F6CC, 0x1F3FF },
 ["person in bed: light skin tone"]={ 0x1F6CC, 0x1F3FB },
 ["person in bed: medium skin tone"]={ 0x1F6CC, 0x1F3FD },
 ["person in bed: medium-dark skin tone"]={ 0x1F6CC, 0x1F3FE },
 ["person in bed: medium-light skin tone"]={ 0x1F6CC, 0x1F3FC },
 ["person in lotus position"]={ 0x1F9D8 },
 ["person in lotus position: dark skin tone"]={ 0x1F9D8, 0x1F3FF },
 ["person in lotus position: light skin tone"]={ 0x1F9D8, 0x1F3FB },
 ["person in lotus position: medium skin tone"]={ 0x1F9D8, 0x1F3FD },
 ["person in lotus position: medium-dark skin tone"]={ 0x1F9D8, 0x1F3FE },
 ["person in lotus position: medium-light skin tone"]={ 0x1F9D8, 0x1F3FC },
 ["person in manual wheelchair"]={ 0x1F9D1, 0x200D, 0x1F9BD },
 ["person in manual wheelchair: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9BD },
 ["person in manual wheelchair: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9BD },
 ["person in manual wheelchair: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9BD },
 ["person in manual wheelchair: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9BD },
 ["person in manual wheelchair: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9BD },
 ["person in motorized wheelchair"]={ 0x1F9D1, 0x200D, 0x1F9BC },
 ["person in motorized wheelchair: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9BC },
 ["person in motorized wheelchair: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9BC },
 ["person in motorized wheelchair: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9BC },
 ["person in motorized wheelchair: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9BC },
 ["person in motorized wheelchair: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9BC },
 ["person in steamy room"]={ 0x1F9D6 },
 ["person in steamy room: dark skin tone"]={ 0x1F9D6, 0x1F3FF },
 ["person in steamy room: light skin tone"]={ 0x1F9D6, 0x1F3FB },
 ["person in steamy room: medium skin tone"]={ 0x1F9D6, 0x1F3FD },
 ["person in steamy room: medium-dark skin tone"]={ 0x1F9D6, 0x1F3FE },
 ["person in steamy room: medium-light skin tone"]={ 0x1F9D6, 0x1F3FC },
 ["person in suit levitating"]={ 0x1F574, 0xFE0F },
 ["person in suit levitating: dark skin tone"]={ 0x1F574, 0x1F3FF },
 ["person in suit levitating: light skin tone"]={ 0x1F574, 0x1F3FB },
 ["person in suit levitating: medium skin tone"]={ 0x1F574, 0x1F3FD },
 ["person in suit levitating: medium-dark skin tone"]={ 0x1F574, 0x1F3FE },
 ["person in suit levitating: medium-light skin tone"]={ 0x1F574, 0x1F3FC },
 ["person in tuxedo"]={ 0x1F935 },
 ["person in tuxedo: dark skin tone"]={ 0x1F935, 0x1F3FF },
 ["person in tuxedo: light skin tone"]={ 0x1F935, 0x1F3FB },
 ["person in tuxedo: medium skin tone"]={ 0x1F935, 0x1F3FD },
 ["person in tuxedo: medium-dark skin tone"]={ 0x1F935, 0x1F3FE },
 ["person in tuxedo: medium-light skin tone"]={ 0x1F935, 0x1F3FC },
 ["person juggling"]={ 0x1F939 },
 ["person juggling: dark skin tone"]={ 0x1F939, 0x1F3FF },
 ["person juggling: light skin tone"]={ 0x1F939, 0x1F3FB },
 ["person juggling: medium skin tone"]={ 0x1F939, 0x1F3FD },
 ["person juggling: medium-dark skin tone"]={ 0x1F939, 0x1F3FE },
 ["person juggling: medium-light skin tone"]={ 0x1F939, 0x1F3FC },
 ["person kneeling"]={ 0x1F9CE },
 ["person kneeling: dark skin tone"]={ 0x1F9CE, 0x1F3FF },
 ["person kneeling: light skin tone"]={ 0x1F9CE, 0x1F3FB },
 ["person kneeling: medium skin tone"]={ 0x1F9CE, 0x1F3FD },
 ["person kneeling: medium-dark skin tone"]={ 0x1F9CE, 0x1F3FE },
 ["person kneeling: medium-light skin tone"]={ 0x1F9CE, 0x1F3FC },
 ["person lifting weights"]={ 0x1F3CB, 0xFE0F },
 ["person lifting weights: dark skin tone"]={ 0x1F3CB, 0x1F3FF },
 ["person lifting weights: light skin tone"]={ 0x1F3CB, 0x1F3FB },
 ["person lifting weights: medium skin tone"]={ 0x1F3CB, 0x1F3FD },
 ["person lifting weights: medium-dark skin tone"]={ 0x1F3CB, 0x1F3FE },
 ["person lifting weights: medium-light skin tone"]={ 0x1F3CB, 0x1F3FC },
 ["person mountain biking"]={ 0x1F6B5 },
 ["person mountain biking: dark skin tone"]={ 0x1F6B5, 0x1F3FF },
 ["person mountain biking: light skin tone"]={ 0x1F6B5, 0x1F3FB },
 ["person mountain biking: medium skin tone"]={ 0x1F6B5, 0x1F3FD },
 ["person mountain biking: medium-dark skin tone"]={ 0x1F6B5, 0x1F3FE },
 ["person mountain biking: medium-light skin tone"]={ 0x1F6B5, 0x1F3FC },
 ["person playing handball"]={ 0x1F93E },
 ["person playing handball: dark skin tone"]={ 0x1F93E, 0x1F3FF },
 ["person playing handball: light skin tone"]={ 0x1F93E, 0x1F3FB },
 ["person playing handball: medium skin tone"]={ 0x1F93E, 0x1F3FD },
 ["person playing handball: medium-dark skin tone"]={ 0x1F93E, 0x1F3FE },
 ["person playing handball: medium-light skin tone"]={ 0x1F93E, 0x1F3FC },
 ["person playing water polo"]={ 0x1F93D },
 ["person playing water polo: dark skin tone"]={ 0x1F93D, 0x1F3FF },
 ["person playing water polo: light skin tone"]={ 0x1F93D, 0x1F3FB },
 ["person playing water polo: medium skin tone"]={ 0x1F93D, 0x1F3FD },
 ["person playing water polo: medium-dark skin tone"]={ 0x1F93D, 0x1F3FE },
 ["person playing water polo: medium-light skin tone"]={ 0x1F93D, 0x1F3FC },
 ["person pouting"]={ 0x1F64E },
 ["person pouting: dark skin tone"]={ 0x1F64E, 0x1F3FF },
 ["person pouting: light skin tone"]={ 0x1F64E, 0x1F3FB },
 ["person pouting: medium skin tone"]={ 0x1F64E, 0x1F3FD },
 ["person pouting: medium-dark skin tone"]={ 0x1F64E, 0x1F3FE },
 ["person pouting: medium-light skin tone"]={ 0x1F64E, 0x1F3FC },
 ["person raising hand"]={ 0x1F64B },
 ["person raising hand: dark skin tone"]={ 0x1F64B, 0x1F3FF },
 ["person raising hand: light skin tone"]={ 0x1F64B, 0x1F3FB },
 ["person raising hand: medium skin tone"]={ 0x1F64B, 0x1F3FD },
 ["person raising hand: medium-dark skin tone"]={ 0x1F64B, 0x1F3FE },
 ["person raising hand: medium-light skin tone"]={ 0x1F64B, 0x1F3FC },
 ["person rowing boat"]={ 0x1F6A3 },
 ["person rowing boat: dark skin tone"]={ 0x1F6A3, 0x1F3FF },
 ["person rowing boat: light skin tone"]={ 0x1F6A3, 0x1F3FB },
 ["person rowing boat: medium skin tone"]={ 0x1F6A3, 0x1F3FD },
 ["person rowing boat: medium-dark skin tone"]={ 0x1F6A3, 0x1F3FE },
 ["person rowing boat: medium-light skin tone"]={ 0x1F6A3, 0x1F3FC },
 ["person running"]={ 0x1F3C3 },
 ["person running: dark skin tone"]={ 0x1F3C3, 0x1F3FF },
 ["person running: light skin tone"]={ 0x1F3C3, 0x1F3FB },
 ["person running: medium skin tone"]={ 0x1F3C3, 0x1F3FD },
 ["person running: medium-dark skin tone"]={ 0x1F3C3, 0x1F3FE },
 ["person running: medium-light skin tone"]={ 0x1F3C3, 0x1F3FC },
 ["person shrugging"]={ 0x1F937 },
 ["person shrugging: dark skin tone"]={ 0x1F937, 0x1F3FF },
 ["person shrugging: light skin tone"]={ 0x1F937, 0x1F3FB },
 ["person shrugging: medium skin tone"]={ 0x1F937, 0x1F3FD },
 ["person shrugging: medium-dark skin tone"]={ 0x1F937, 0x1F3FE },
 ["person shrugging: medium-light skin tone"]={ 0x1F937, 0x1F3FC },
 ["person standing"]={ 0x1F9CD },
 ["person standing: dark skin tone"]={ 0x1F9CD, 0x1F3FF },
 ["person standing: light skin tone"]={ 0x1F9CD, 0x1F3FB },
 ["person standing: medium skin tone"]={ 0x1F9CD, 0x1F3FD },
 ["person standing: medium-dark skin tone"]={ 0x1F9CD, 0x1F3FE },
 ["person standing: medium-light skin tone"]={ 0x1F9CD, 0x1F3FC },
 ["person surfing"]={ 0x1F3C4 },
 ["person surfing: dark skin tone"]={ 0x1F3C4, 0x1F3FF },
 ["person surfing: light skin tone"]={ 0x1F3C4, 0x1F3FB },
 ["person surfing: medium skin tone"]={ 0x1F3C4, 0x1F3FD },
 ["person surfing: medium-dark skin tone"]={ 0x1F3C4, 0x1F3FE },
 ["person surfing: medium-light skin tone"]={ 0x1F3C4, 0x1F3FC },
 ["person swimming"]={ 0x1F3CA },
 ["person swimming: dark skin tone"]={ 0x1F3CA, 0x1F3FF },
 ["person swimming: light skin tone"]={ 0x1F3CA, 0x1F3FB },
 ["person swimming: medium skin tone"]={ 0x1F3CA, 0x1F3FD },
 ["person swimming: medium-dark skin tone"]={ 0x1F3CA, 0x1F3FE },
 ["person swimming: medium-light skin tone"]={ 0x1F3CA, 0x1F3FC },
 ["person taking bath"]={ 0x1F6C0 },
 ["person taking bath: dark skin tone"]={ 0x1F6C0, 0x1F3FF },
 ["person taking bath: light skin tone"]={ 0x1F6C0, 0x1F3FB },
 ["person taking bath: medium skin tone"]={ 0x1F6C0, 0x1F3FD },
 ["person taking bath: medium-dark skin tone"]={ 0x1F6C0, 0x1F3FE },
 ["person taking bath: medium-light skin tone"]={ 0x1F6C0, 0x1F3FC },
 ["person tipping hand"]={ 0x1F481 },
 ["person tipping hand: dark skin tone"]={ 0x1F481, 0x1F3FF },
 ["person tipping hand: light skin tone"]={ 0x1F481, 0x1F3FB },
 ["person tipping hand: medium skin tone"]={ 0x1F481, 0x1F3FD },
 ["person tipping hand: medium-dark skin tone"]={ 0x1F481, 0x1F3FE },
 ["person tipping hand: medium-light skin tone"]={ 0x1F481, 0x1F3FC },
 ["person walking"]={ 0x1F6B6 },
 ["person walking: dark skin tone"]={ 0x1F6B6, 0x1F3FF },
 ["person walking: light skin tone"]={ 0x1F6B6, 0x1F3FB },
 ["person walking: medium skin tone"]={ 0x1F6B6, 0x1F3FD },
 ["person walking: medium-dark skin tone"]={ 0x1F6B6, 0x1F3FE },
 ["person walking: medium-light skin tone"]={ 0x1F6B6, 0x1F3FC },
 ["person wearing turban"]={ 0x1F473 },
 ["person wearing turban: dark skin tone"]={ 0x1F473, 0x1F3FF },
 ["person wearing turban: light skin tone"]={ 0x1F473, 0x1F3FB },
 ["person wearing turban: medium skin tone"]={ 0x1F473, 0x1F3FD },
 ["person wearing turban: medium-dark skin tone"]={ 0x1F473, 0x1F3FE },
 ["person wearing turban: medium-light skin tone"]={ 0x1F473, 0x1F3FC },
 ["person with skullcap"]={ 0x1F472 },
 ["person with skullcap: dark skin tone"]={ 0x1F472, 0x1F3FF },
 ["person with skullcap: light skin tone"]={ 0x1F472, 0x1F3FB },
 ["person with skullcap: medium skin tone"]={ 0x1F472, 0x1F3FD },
 ["person with skullcap: medium-dark skin tone"]={ 0x1F472, 0x1F3FE },
 ["person with skullcap: medium-light skin tone"]={ 0x1F472, 0x1F3FC },
 ["person with veil"]={ 0x1F470 },
 ["person with veil: dark skin tone"]={ 0x1F470, 0x1F3FF },
 ["person with veil: light skin tone"]={ 0x1F470, 0x1F3FB },
 ["person with veil: medium skin tone"]={ 0x1F470, 0x1F3FD },
 ["person with veil: medium-dark skin tone"]={ 0x1F470, 0x1F3FE },
 ["person with veil: medium-light skin tone"]={ 0x1F470, 0x1F3FC },
 ["person with white cane"]={ 0x1F9D1, 0x200D, 0x1F9AF },
 ["person with white cane: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9AF },
 ["person with white cane: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9AF },
 ["person with white cane: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9AF },
 ["person with white cane: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9AF },
 ["person with white cane: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9AF },
 ["person: bald"]={ 0x1F9D1, 0x200D, 0x1F9B2 },
 ["person: blond hair"]={ 0x1F471 },
 ["person: curly hair"]={ 0x1F9D1, 0x200D, 0x1F9B1 },
 ["person: dark skin tone"]={ 0x1F9D1, 0x1F3FF },
 ["person: dark skin tone, bald"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9B2 },
 ["person: dark skin tone, blond hair"]={ 0x1F471, 0x1F3FF },
 ["person: dark skin tone, curly hair"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9B1 },
 ["person: dark skin tone, red hair"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9B0 },
 ["person: dark skin tone, white hair"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F9B3 },
 ["person: light skin tone"]={ 0x1F9D1, 0x1F3FB },
 ["person: light skin tone, bald"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9B2 },
 ["person: light skin tone, blond hair"]={ 0x1F471, 0x1F3FB },
 ["person: light skin tone, curly hair"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9B1 },
 ["person: light skin tone, red hair"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9B0 },
 ["person: light skin tone, white hair"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F9B3 },
 ["person: medium skin tone"]={ 0x1F9D1, 0x1F3FD },
 ["person: medium skin tone, bald"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9B2 },
 ["person: medium skin tone, blond hair"]={ 0x1F471, 0x1F3FD },
 ["person: medium skin tone, curly hair"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9B1 },
 ["person: medium skin tone, red hair"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9B0 },
 ["person: medium skin tone, white hair"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F9B3 },
 ["person: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE },
 ["person: medium-dark skin tone, bald"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9B2 },
 ["person: medium-dark skin tone, blond hair"]={ 0x1F471, 0x1F3FE },
 ["person: medium-dark skin tone, curly hair"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9B1 },
 ["person: medium-dark skin tone, red hair"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9B0 },
 ["person: medium-dark skin tone, white hair"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F9B3 },
 ["person: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC },
 ["person: medium-light skin tone, bald"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9B2 },
 ["person: medium-light skin tone, blond hair"]={ 0x1F471, 0x1F3FC },
 ["person: medium-light skin tone, curly hair"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9B1 },
 ["person: medium-light skin tone, red hair"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9B0 },
 ["person: medium-light skin tone, white hair"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F9B3 },
 ["person: red hair"]={ 0x1F9D1, 0x200D, 0x1F9B0 },
 ["person: white hair"]={ 0x1F9D1, 0x200D, 0x1F9B3 },
 ["petri dish"]={ 0x1F9EB },
 ["pick"]={ 0x26CF, 0xFE0F },
 ["pickup truck"]={ 0x1F6FB },
 ["pie"]={ 0x1F967 },
 ["pig"]={ 0x1F416 },
 ["pig face"]={ 0x1F437 },
 ["pig nose"]={ 0x1F43D },
 ["pile of poo"]={ 0x1F4A9 },
 ["pill"]={ 0x1F48A },
 ["pilot"]={ 0x1F9D1, 0x200D, 0x2708, 0xFE0F },
 ["pilot: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x2708, 0xFE0F },
 ["pilot: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x2708, 0xFE0F },
 ["pilot: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x2708, 0xFE0F },
 ["pilot: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x2708, 0xFE0F },
 ["pilot: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x2708, 0xFE0F },
 ["pinched fingers"]={ 0x1F90C },
 ["pinched fingers: dark skin tone"]={ 0x1F90C, 0x1F3FF },
 ["pinched fingers: light skin tone"]={ 0x1F90C, 0x1F3FB },
 ["pinched fingers: medium skin tone"]={ 0x1F90C, 0x1F3FD },
 ["pinched fingers: medium-dark skin tone"]={ 0x1F90C, 0x1F3FE },
 ["pinched fingers: medium-light skin tone"]={ 0x1F90C, 0x1F3FC },
 ["pinching hand"]={ 0x1F90F },
 ["pinching hand: dark skin tone"]={ 0x1F90F, 0x1F3FF },
 ["pinching hand: light skin tone"]={ 0x1F90F, 0x1F3FB },
 ["pinching hand: medium skin tone"]={ 0x1F90F, 0x1F3FD },
 ["pinching hand: medium-dark skin tone"]={ 0x1F90F, 0x1F3FE },
 ["pinching hand: medium-light skin tone"]={ 0x1F90F, 0x1F3FC },
 ["pine decoration"]={ 0x1F38D },
 ["pineapple"]={ 0x1F34D },
 ["ping pong"]={ 0x1F3D3 },
 ["pirate flag"]={ 0x1F3F4, 0x200D, 0x2620, 0xFE0F },
 ["pisces"]={ 0x2653 },
 ["pistol"]={ 0x1F52B },
 ["pizza"]={ 0x1F355 },
 ["piñata"]={ 0x1FA85 },
 ["placard"]={ 0x1FAA7 },
 ["place of worship"]={ 0x1F6D0 },
 ["play button"]={ 0x25B6, 0xFE0F },
 ["play or pause button"]={ 0x23EF, 0xFE0F },
 ["pleading face"]={ 0x1F97A },
 ["plunger"]={ 0x1FAA0 },
 ["plus"]={ 0x2795 },
 ["polar bear"]={ 0x1F43B, 0x200D, 0x2744, 0xFE0F },
 ["police car"]={ 0x1F693 },
 ["police car light"]={ 0x1F6A8 },
 ["police officer"]={ 0x1F46E },
 ["police officer: dark skin tone"]={ 0x1F46E, 0x1F3FF },
 ["police officer: light skin tone"]={ 0x1F46E, 0x1F3FB },
 ["police officer: medium skin tone"]={ 0x1F46E, 0x1F3FD },
 ["police officer: medium-dark skin tone"]={ 0x1F46E, 0x1F3FE },
 ["police officer: medium-light skin tone"]={ 0x1F46E, 0x1F3FC },
 ["poodle"]={ 0x1F429 },
 ["pool 8 ball"]={ 0x1F3B1 },
 ["popcorn"]={ 0x1F37F },
 ["post office"]={ 0x1F3E4 },
 ["postal horn"]={ 0x1F4EF },
 ["postbox"]={ 0x1F4EE },
 ["pot of food"]={ 0x1F372 },
 ["potable water"]={ 0x1F6B0 },
 ["potato"]={ 0x1F954 },
 ["potted plant"]={ 0x1FAB4 },
 ["poultry leg"]={ 0x1F357 },
 ["pound banknote"]={ 0x1F4B7 },
 ["pouting cat"]={ 0x1F63E },
 ["pouting face"]={ 0x1F621 },
 ["prayer beads"]={ 0x1F4FF },
 ["pregnant woman"]={ 0x1F930 },
 ["pregnant woman: dark skin tone"]={ 0x1F930, 0x1F3FF },
 ["pregnant woman: light skin tone"]={ 0x1F930, 0x1F3FB },
 ["pregnant woman: medium skin tone"]={ 0x1F930, 0x1F3FD },
 ["pregnant woman: medium-dark skin tone"]={ 0x1F930, 0x1F3FE },
 ["pregnant woman: medium-light skin tone"]={ 0x1F930, 0x1F3FC },
 ["pretzel"]={ 0x1F968 },
 ["prince"]={ 0x1F934 },
 ["prince: dark skin tone"]={ 0x1F934, 0x1F3FF },
 ["prince: light skin tone"]={ 0x1F934, 0x1F3FB },
 ["prince: medium skin tone"]={ 0x1F934, 0x1F3FD },
 ["prince: medium-dark skin tone"]={ 0x1F934, 0x1F3FE },
 ["prince: medium-light skin tone"]={ 0x1F934, 0x1F3FC },
 ["princess"]={ 0x1F478 },
 ["princess: dark skin tone"]={ 0x1F478, 0x1F3FF },
 ["princess: light skin tone"]={ 0x1F478, 0x1F3FB },
 ["princess: medium skin tone"]={ 0x1F478, 0x1F3FD },
 ["princess: medium-dark skin tone"]={ 0x1F478, 0x1F3FE },
 ["princess: medium-light skin tone"]={ 0x1F478, 0x1F3FC },
 ["printer"]={ 0x1F5A8, 0xFE0F },
 ["prohibited"]={ 0x1F6AB },
 ["purple circle"]={ 0x1F7E3 },
 ["purple heart"]={ 0x1F49C },
 ["purple square"]={ 0x1F7EA },
 ["purse"]={ 0x1F45B },
 ["pushpin"]={ 0x1F4CC },
 ["puzzle piece"]={ 0x1F9E9 },
 ["question mark"]={ 0x2753 },
 ["rabbit"]={ 0x1F407 },
 ["rabbit face"]={ 0x1F430 },
 ["raccoon"]={ 0x1F99D },
 ["racing car"]={ 0x1F3CE, 0xFE0F },
 ["radio"]={ 0x1F4FB },
 ["radio button"]={ 0x1F518 },
 ["radioactive"]={ 0x2622, 0xFE0F },
 ["railway car"]={ 0x1F683 },
 ["railway track"]={ 0x1F6E4, 0xFE0F },
 ["rainbow"]={ 0x1F308 },
 ["rainbow flag"]={ 0x1F3F3, 0xFE0F, 0x200D, 0x1F308 },
 ["raised back of hand"]={ 0x1F91A },
 ["raised back of hand: dark skin tone"]={ 0x1F91A, 0x1F3FF },
 ["raised back of hand: light skin tone"]={ 0x1F91A, 0x1F3FB },
 ["raised back of hand: medium skin tone"]={ 0x1F91A, 0x1F3FD },
 ["raised back of hand: medium-dark skin tone"]={ 0x1F91A, 0x1F3FE },
 ["raised back of hand: medium-light skin tone"]={ 0x1F91A, 0x1F3FC },
 ["raised fist"]={ 0x270A },
 ["raised fist: dark skin tone"]={ 0x270A, 0x1F3FF },
 ["raised fist: light skin tone"]={ 0x270A, 0x1F3FB },
 ["raised fist: medium skin tone"]={ 0x270A, 0x1F3FD },
 ["raised fist: medium-dark skin tone"]={ 0x270A, 0x1F3FE },
 ["raised fist: medium-light skin tone"]={ 0x270A, 0x1F3FC },
 ["raised hand"]={ 0x270B },
 ["raised hand: dark skin tone"]={ 0x270B, 0x1F3FF },
 ["raised hand: light skin tone"]={ 0x270B, 0x1F3FB },
 ["raised hand: medium skin tone"]={ 0x270B, 0x1F3FD },
 ["raised hand: medium-dark skin tone"]={ 0x270B, 0x1F3FE },
 ["raised hand: medium-light skin tone"]={ 0x270B, 0x1F3FC },
 ["raising hands"]={ 0x1F64C },
 ["raising hands: dark skin tone"]={ 0x1F64C, 0x1F3FF },
 ["raising hands: light skin tone"]={ 0x1F64C, 0x1F3FB },
 ["raising hands: medium skin tone"]={ 0x1F64C, 0x1F3FD },
 ["raising hands: medium-dark skin tone"]={ 0x1F64C, 0x1F3FE },
 ["raising hands: medium-light skin tone"]={ 0x1F64C, 0x1F3FC },
 ["ram"]={ 0x1F40F },
 ["rat"]={ 0x1F400 },
 ["razor"]={ 0x1FA92 },
 ["receipt"]={ 0x1F9FE },
 ["record button"]={ 0x23FA, 0xFE0F },
 ["recycling symbol"]={ 0x267B, 0xFE0F },
 ["red apple"]={ 0x1F34E },
 ["red circle"]={ 0x1F534 },
 ["red envelope"]={ 0x1F9E7 },
 ["red heart"]={ 0x2764, 0xFE0F },
 ["red paper lantern"]={ 0x1F3EE },
 ["red square"]={ 0x1F7E5 },
 ["red triangle pointed down"]={ 0x1F53B },
 ["red triangle pointed up"]={ 0x1F53A },
 ["registered"]={ 0xAE, 0xFE0F },
 ["relieved face"]={ 0x1F60C },
 ["reminder ribbon"]={ 0x1F397, 0xFE0F },
 ["repeat button"]={ 0x1F501 },
 ["repeat single button"]={ 0x1F502 },
 ["rescue worker’s helmet"]={ 0x26D1, 0xFE0F },
 ["restroom"]={ 0x1F6BB },
 ["reverse button"]={ 0x25C0, 0xFE0F },
 ["revolving hearts"]={ 0x1F49E },
 ["rhinoceros"]={ 0x1F98F },
 ["ribbon"]={ 0x1F380 },
 ["rice ball"]={ 0x1F359 },
 ["rice cracker"]={ 0x1F358 },
 ["right anger bubble"]={ 0x1F5EF, 0xFE0F },
 ["right arrow"]={ 0x27A1, 0xFE0F },
 ["right arrow curving down"]={ 0x2935, 0xFE0F },
 ["right arrow curving left"]={ 0x21A9, 0xFE0F },
 ["right arrow curving up"]={ 0x2934, 0xFE0F },
 ["right-facing fist"]={ 0x1F91C },
 ["right-facing fist: dark skin tone"]={ 0x1F91C, 0x1F3FF },
 ["right-facing fist: light skin tone"]={ 0x1F91C, 0x1F3FB },
 ["right-facing fist: medium skin tone"]={ 0x1F91C, 0x1F3FD },
 ["right-facing fist: medium-dark skin tone"]={ 0x1F91C, 0x1F3FE },
 ["right-facing fist: medium-light skin tone"]={ 0x1F91C, 0x1F3FC },
 ["ring"]={ 0x1F48D },
 ["ringed planet"]={ 0x1FA90 },
 ["roasted sweet potato"]={ 0x1F360 },
 ["robot"]={ 0x1F916 },
 ["rock"]={ 0x1FAA8 },
 ["rocket"]={ 0x1F680 },
 ["roll of paper"]={ 0x1F9FB },
 ["rolled-up newspaper"]={ 0x1F5DE, 0xFE0F },
 ["roller coaster"]={ 0x1F3A2 },
 ["roller skate"]={ 0x1F6FC },
 ["rolling on the floor laughing"]={ 0x1F923 },
 ["rooster"]={ 0x1F413 },
 ["rose"]={ 0x1F339 },
 ["rosette"]={ 0x1F3F5, 0xFE0F },
 ["round pushpin"]={ 0x1F4CD },
 ["rugby football"]={ 0x1F3C9 },
 ["running shirt"]={ 0x1F3BD },
 ["running shoe"]={ 0x1F45F },
 ["sad but relieved face"]={ 0x1F625 },
 ["safety pin"]={ 0x1F9F7 },
 ["safety vest"]={ 0x1F9BA },
 ["sagittarius"]={ 0x2650 },
 ["sailboat"]={ 0x26F5 },
 ["sake"]={ 0x1F376 },
 ["salt"]={ 0x1F9C2 },
 ["sandwich"]={ 0x1F96A },
 ["santa claus"]={ 0x1F385 },
 ["santa claus: dark skin tone"]={ 0x1F385, 0x1F3FF },
 ["santa claus: light skin tone"]={ 0x1F385, 0x1F3FB },
 ["santa claus: medium skin tone"]={ 0x1F385, 0x1F3FD },
 ["santa claus: medium-dark skin tone"]={ 0x1F385, 0x1F3FE },
 ["santa claus: medium-light skin tone"]={ 0x1F385, 0x1F3FC },
 ["sari"]={ 0x1F97B },
 ["satellite"]={ 0x1F6F0, 0xFE0F },
 ["satellite antenna"]={ 0x1F4E1 },
 ["sauropod"]={ 0x1F995 },
 ["saxophone"]={ 0x1F3B7 },
 ["scarf"]={ 0x1F9E3 },
 ["school"]={ 0x1F3EB },
 ["scientist"]={ 0x1F9D1, 0x200D, 0x1F52C },
 ["scientist: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F52C },
 ["scientist: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F52C },
 ["scientist: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F52C },
 ["scientist: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F52C },
 ["scientist: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F52C },
 ["scissors"]={ 0x2702, 0xFE0F },
 ["scorpio"]={ 0x264F },
 ["scorpion"]={ 0x1F982 },
 ["screwdriver"]={ 0x1FA9B },
 ["scroll"]={ 0x1F4DC },
 ["seal"]={ 0x1F9AD },
 ["seat"]={ 0x1F4BA },
 ["see-no-evil monkey"]={ 0x1F648 },
 ["seedling"]={ 0x1F331 },
 ["selfie"]={ 0x1F933 },
 ["selfie: dark skin tone"]={ 0x1F933, 0x1F3FF },
 ["selfie: light skin tone"]={ 0x1F933, 0x1F3FB },
 ["selfie: medium skin tone"]={ 0x1F933, 0x1F3FD },
 ["selfie: medium-dark skin tone"]={ 0x1F933, 0x1F3FE },
 ["selfie: medium-light skin tone"]={ 0x1F933, 0x1F3FC },
 ["service dog"]={ 0x1F415, 0x200D, 0x1F9BA },
 ["seven o’clock"]={ 0x1F556 },
 ["seven-thirty"]={ 0x1F562 },
 ["sewing needle"]={ 0x1FAA1 },
 ["shallow pan of food"]={ 0x1F958 },
 ["shamrock"]={ 0x2618, 0xFE0F },
 ["shark"]={ 0x1F988 },
 ["shaved ice"]={ 0x1F367 },
 ["sheaf of rice"]={ 0x1F33E },
 ["shield"]={ 0x1F6E1, 0xFE0F },
 ["shinto shrine"]={ 0x26E9, 0xFE0F },
 ["ship"]={ 0x1F6A2 },
 ["shooting star"]={ 0x1F320 },
 ["shopping bags"]={ 0x1F6CD, 0xFE0F },
 ["shopping cart"]={ 0x1F6D2 },
 ["shortcake"]={ 0x1F370 },
 ["shorts"]={ 0x1FA73 },
 ["shower"]={ 0x1F6BF },
 ["shrimp"]={ 0x1F990 },
 ["shuffle tracks button"]={ 0x1F500 },
 ["shushing face"]={ 0x1F92B },
 ["sign of the horns"]={ 0x1F918 },
 ["sign of the horns: dark skin tone"]={ 0x1F918, 0x1F3FF },
 ["sign of the horns: light skin tone"]={ 0x1F918, 0x1F3FB },
 ["sign of the horns: medium skin tone"]={ 0x1F918, 0x1F3FD },
 ["sign of the horns: medium-dark skin tone"]={ 0x1F918, 0x1F3FE },
 ["sign of the horns: medium-light skin tone"]={ 0x1F918, 0x1F3FC },
 ["singer"]={ 0x1F9D1, 0x200D, 0x1F3A4 },
 ["singer: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F3A4 },
 ["singer: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F3A4 },
 ["singer: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F3A4 },
 ["singer: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F3A4 },
 ["singer: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F3A4 },
 ["six o’clock"]={ 0x1F555 },
 ["six-thirty"]={ 0x1F561 },
 ["skateboard"]={ 0x1F6F9 },
 ["skier"]={ 0x26F7, 0xFE0F },
 ["skis"]={ 0x1F3BF },
 ["skull"]={ 0x1F480 },
 ["skull and crossbones"]={ 0x2620, 0xFE0F },
 ["skunk"]={ 0x1F9A8 },
 ["sled"]={ 0x1F6F7 },
 ["sleeping face"]={ 0x1F634 },
 ["sleepy face"]={ 0x1F62A },
 ["slightly frowning face"]={ 0x1F641 },
 ["slightly smiling face"]={ 0x1F642 },
 ["slot machine"]={ 0x1F3B0 },
 ["sloth"]={ 0x1F9A5 },
 ["small airplane"]={ 0x1F6E9, 0xFE0F },
 ["small blue diamond"]={ 0x1F539 },
 ["small orange diamond"]={ 0x1F538 },
 ["smiling cat with heart-eyes"]={ 0x1F63B },
 ["smiling face"]={ 0x263A, 0xFE0F },
 ["smiling face with halo"]={ 0x1F607 },
 ["smiling face with heart-eyes"]={ 0x1F60D },
 ["smiling face with hearts"]={ 0x1F970 },
 ["smiling face with horns"]={ 0x1F608 },
 ["smiling face with smiling eyes"]={ 0x1F60A },
 ["smiling face with sunglasses"]={ 0x1F60E },
 ["smiling face with tear"]={ 0x1F972 },
 ["smirking face"]={ 0x1F60F },
 ["snail"]={ 0x1F40C },
 ["snake"]={ 0x1F40D },
 ["sneezing face"]={ 0x1F927 },
 ["snow-capped mountain"]={ 0x1F3D4, 0xFE0F },
 ["snowboarder"]={ 0x1F3C2 },
 ["snowboarder: dark skin tone"]={ 0x1F3C2, 0x1F3FF },
 ["snowboarder: light skin tone"]={ 0x1F3C2, 0x1F3FB },
 ["snowboarder: medium skin tone"]={ 0x1F3C2, 0x1F3FD },
 ["snowboarder: medium-dark skin tone"]={ 0x1F3C2, 0x1F3FE },
 ["snowboarder: medium-light skin tone"]={ 0x1F3C2, 0x1F3FC },
 ["snowflake"]={ 0x2744, 0xFE0F },
 ["snowman"]={ 0x2603, 0xFE0F },
 ["snowman without snow"]={ 0x26C4 },
 ["soap"]={ 0x1F9FC },
 ["soccer ball"]={ 0x26BD },
 ["socks"]={ 0x1F9E6 },
 ["soft ice cream"]={ 0x1F366 },
 ["softball"]={ 0x1F94E },
 ["soon arrow"]={ 0x1F51C },
 ["sos button"]={ 0x1F198 },
 ["spade suit"]={ 0x2660, 0xFE0F },
 ["spaghetti"]={ 0x1F35D },
 ["sparkle"]={ 0x2747, 0xFE0F },
 ["sparkler"]={ 0x1F387 },
 ["sparkles"]={ 0x2728 },
 ["sparkling heart"]={ 0x1F496 },
 ["speak-no-evil monkey"]={ 0x1F64A },
 ["speaker high volume"]={ 0x1F50A },
 ["speaker low volume"]={ 0x1F508 },
 ["speaker medium volume"]={ 0x1F509 },
 ["speaking head"]={ 0x1F5E3, 0xFE0F },
 ["speech balloon"]={ 0x1F4AC },
 ["speedboat"]={ 0x1F6A4 },
 ["spider"]={ 0x1F577, 0xFE0F },
 ["spider web"]={ 0x1F578, 0xFE0F },
 ["spiral calendar"]={ 0x1F5D3, 0xFE0F },
 ["spiral notepad"]={ 0x1F5D2, 0xFE0F },
 ["spiral shell"]={ 0x1F41A },
 ["sponge"]={ 0x1F9FD },
 ["spoon"]={ 0x1F944 },
 ["sport utility vehicle"]={ 0x1F699 },
 ["sports medal"]={ 0x1F3C5 },
 ["spouting whale"]={ 0x1F433 },
 ["squid"]={ 0x1F991 },
 ["squinting face with tongue"]={ 0x1F61D },
 ["stadium"]={ 0x1F3DF, 0xFE0F },
 ["star"]={ 0x2B50 },
 ["star and crescent"]={ 0x262A, 0xFE0F },
 ["star of david"]={ 0x2721, 0xFE0F },
 ["star-struck"]={ 0x1F929 },
 ["station"]={ 0x1F689 },
 ["statue of liberty"]={ 0x1F5FD },
 ["steaming bowl"]={ 0x1F35C },
 ["stethoscope"]={ 0x1FA7A },
 ["stop button"]={ 0x23F9, 0xFE0F },
 ["stop sign"]={ 0x1F6D1 },
 ["stopwatch"]={ 0x23F1, 0xFE0F },
 ["straight ruler"]={ 0x1F4CF },
 ["strawberry"]={ 0x1F353 },
 ["student"]={ 0x1F9D1, 0x200D, 0x1F393 },
 ["student: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F393 },
 ["student: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F393 },
 ["student: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F393 },
 ["student: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F393 },
 ["student: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F393 },
 ["studio microphone"]={ 0x1F399, 0xFE0F },
 ["stuffed flatbread"]={ 0x1F959 },
 ["sun"]={ 0x2600, 0xFE0F },
 ["sun behind cloud"]={ 0x26C5 },
 ["sun behind large cloud"]={ 0x1F325, 0xFE0F },
 ["sun behind rain cloud"]={ 0x1F326, 0xFE0F },
 ["sun behind small cloud"]={ 0x1F324, 0xFE0F },
 ["sun with face"]={ 0x1F31E },
 ["sunflower"]={ 0x1F33B },
 ["sunglasses"]={ 0x1F576, 0xFE0F },
 ["sunrise"]={ 0x1F305 },
 ["sunrise over mountains"]={ 0x1F304 },
 ["sunset"]={ 0x1F307 },
 ["superhero"]={ 0x1F9B8 },
 ["superhero: dark skin tone"]={ 0x1F9B8, 0x1F3FF },
 ["superhero: light skin tone"]={ 0x1F9B8, 0x1F3FB },
 ["superhero: medium skin tone"]={ 0x1F9B8, 0x1F3FD },
 ["superhero: medium-dark skin tone"]={ 0x1F9B8, 0x1F3FE },
 ["superhero: medium-light skin tone"]={ 0x1F9B8, 0x1F3FC },
 ["supervillain"]={ 0x1F9B9 },
 ["supervillain: dark skin tone"]={ 0x1F9B9, 0x1F3FF },
 ["supervillain: light skin tone"]={ 0x1F9B9, 0x1F3FB },
 ["supervillain: medium skin tone"]={ 0x1F9B9, 0x1F3FD },
 ["supervillain: medium-dark skin tone"]={ 0x1F9B9, 0x1F3FE },
 ["supervillain: medium-light skin tone"]={ 0x1F9B9, 0x1F3FC },
 ["sushi"]={ 0x1F363 },
 ["suspension railway"]={ 0x1F69F },
 ["swan"]={ 0x1F9A2 },
 ["sweat droplets"]={ 0x1F4A6 },
 ["synagogue"]={ 0x1F54D },
 ["syringe"]={ 0x1F489 },
 ["t-rex"]={ 0x1F996 },
 ["t-shirt"]={ 0x1F455 },
 ["taco"]={ 0x1F32E },
 ["takeout box"]={ 0x1F961 },
 ["tamale"]={ 0x1FAD4 },
 ["tanabata tree"]={ 0x1F38B },
 ["tangerine"]={ 0x1F34A },
 ["taurus"]={ 0x2649 },
 ["taxi"]={ 0x1F695 },
 ["teacher"]={ 0x1F9D1, 0x200D, 0x1F3EB },
 ["teacher: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F3EB },
 ["teacher: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F3EB },
 ["teacher: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F3EB },
 ["teacher: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F3EB },
 ["teacher: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F3EB },
 ["teacup without handle"]={ 0x1F375 },
 ["teapot"]={ 0x1FAD6 },
 ["tear-off calendar"]={ 0x1F4C6 },
 ["technologist"]={ 0x1F9D1, 0x200D, 0x1F4BB },
 ["technologist: dark skin tone"]={ 0x1F9D1, 0x1F3FF, 0x200D, 0x1F4BB },
 ["technologist: light skin tone"]={ 0x1F9D1, 0x1F3FB, 0x200D, 0x1F4BB },
 ["technologist: medium skin tone"]={ 0x1F9D1, 0x1F3FD, 0x200D, 0x1F4BB },
 ["technologist: medium-dark skin tone"]={ 0x1F9D1, 0x1F3FE, 0x200D, 0x1F4BB },
 ["technologist: medium-light skin tone"]={ 0x1F9D1, 0x1F3FC, 0x200D, 0x1F4BB },
 ["teddy bear"]={ 0x1F9F8 },
 ["telephone"]={ 0x260E, 0xFE0F },
 ["telephone receiver"]={ 0x1F4DE },
 ["telescope"]={ 0x1F52D },
 ["television"]={ 0x1F4FA },
 ["ten o’clock"]={ 0x1F559 },
 ["ten-thirty"]={ 0x1F565 },
 ["tennis"]={ 0x1F3BE },
 ["tent"]={ 0x26FA },
 ["test tube"]={ 0x1F9EA },
 ["thermometer"]={ 0x1F321, 0xFE0F },
 ["thinking face"]={ 0x1F914 },
 ["thong sandal"]={ 0x1FA74 },
 ["thought balloon"]={ 0x1F4AD },
 ["thread"]={ 0x1F9F5 },
 ["three o’clock"]={ 0x1F552 },
 ["three-thirty"]={ 0x1F55E },
 ["thumbs down"]={ 0x1F44E },
 ["thumbs down: dark skin tone"]={ 0x1F44E, 0x1F3FF },
 ["thumbs down: light skin tone"]={ 0x1F44E, 0x1F3FB },
 ["thumbs down: medium skin tone"]={ 0x1F44E, 0x1F3FD },
 ["thumbs down: medium-dark skin tone"]={ 0x1F44E, 0x1F3FE },
 ["thumbs down: medium-light skin tone"]={ 0x1F44E, 0x1F3FC },
 ["thumbs up"]={ 0x1F44D },
 ["thumbs up: dark skin tone"]={ 0x1F44D, 0x1F3FF },
 ["thumbs up: light skin tone"]={ 0x1F44D, 0x1F3FB },
 ["thumbs up: medium skin tone"]={ 0x1F44D, 0x1F3FD },
 ["thumbs up: medium-dark skin tone"]={ 0x1F44D, 0x1F3FE },
 ["thumbs up: medium-light skin tone"]={ 0x1F44D, 0x1F3FC },
 ["ticket"]={ 0x1F3AB },
 ["tiger"]={ 0x1F405 },
 ["tiger face"]={ 0x1F42F },
 ["timer clock"]={ 0x23F2, 0xFE0F },
 ["tired face"]={ 0x1F62B },
 ["toilet"]={ 0x1F6BD },
 ["tokyo tower"]={ 0x1F5FC },
 ["tomato"]={ 0x1F345 },
 ["tongue"]={ 0x1F445 },
 ["toolbox"]={ 0x1F9F0 },
 ["tooth"]={ 0x1F9B7 },
 ["toothbrush"]={ 0x1FAA5 },
 ["top arrow"]={ 0x1F51D },
 ["top hat"]={ 0x1F3A9 },
 ["tornado"]={ 0x1F32A, 0xFE0F },
 ["trackball"]={ 0x1F5B2, 0xFE0F },
 ["tractor"]={ 0x1F69C },
 ["trade mark"]={ 0x2122, 0xFE0F },
 ["train"]={ 0x1F686 },
 ["tram"]={ 0x1F68A },
 ["tram car"]={ 0x1F68B },
 ["transgender flag"]={ 0x1F3F3, 0xFE0F, 0x200D, 0x26A7, 0xFE0F },
 ["transgender symbol"]={ 0x26A7, 0xFE0F },
 ["triangular flag"]={ 0x1F6A9 },
 ["triangular ruler"]={ 0x1F4D0 },
 ["trident emblem"]={ 0x1F531 },
 ["trolleybus"]={ 0x1F68E },
 ["trophy"]={ 0x1F3C6 },
 ["tropical drink"]={ 0x1F379 },
 ["tropical fish"]={ 0x1F420 },
 ["trumpet"]={ 0x1F3BA },
 ["tulip"]={ 0x1F337 },
 ["tumbler glass"]={ 0x1F943 },
 ["turkey"]={ 0x1F983 },
 ["turtle"]={ 0x1F422 },
 ["twelve o’clock"]={ 0x1F55B },
 ["twelve-thirty"]={ 0x1F567 },
 ["two hearts"]={ 0x1F495 },
 ["two o’clock"]={ 0x1F551 },
 ["two-hump camel"]={ 0x1F42B },
 ["two-thirty"]={ 0x1F55D },
 ["umbrella"]={ 0x2602, 0xFE0F },
 ["umbrella on ground"]={ 0x26F1, 0xFE0F },
 ["umbrella with rain drops"]={ 0x2614 },
 ["unamused face"]={ 0x1F612 },
 ["unicorn"]={ 0x1F984 },
 ["unlocked"]={ 0x1F513 },
 ["up arrow"]={ 0x2B06, 0xFE0F },
 ["up! button"]={ 0x1F199 },
 ["up-down arrow"]={ 0x2195, 0xFE0F },
 ["up-left arrow"]={ 0x2196, 0xFE0F },
 ["up-right arrow"]={ 0x2197, 0xFE0F },
 ["upside-down face"]={ 0x1F643 },
 ["upwards button"]={ 0x1F53C },
 ["vampire"]={ 0x1F9DB },
 ["vampire: dark skin tone"]={ 0x1F9DB, 0x1F3FF },
 ["vampire: light skin tone"]={ 0x1F9DB, 0x1F3FB },
 ["vampire: medium skin tone"]={ 0x1F9DB, 0x1F3FD },
 ["vampire: medium-dark skin tone"]={ 0x1F9DB, 0x1F3FE },
 ["vampire: medium-light skin tone"]={ 0x1F9DB, 0x1F3FC },
 ["vertical traffic light"]={ 0x1F6A6 },
 ["vibration mode"]={ 0x1F4F3 },
 ["victory hand"]={ 0x270C, 0xFE0F },
 ["victory hand: dark skin tone"]={ 0x270C, 0x1F3FF },
 ["victory hand: light skin tone"]={ 0x270C, 0x1F3FB },
 ["victory hand: medium skin tone"]={ 0x270C, 0x1F3FD },
 ["victory hand: medium-dark skin tone"]={ 0x270C, 0x1F3FE },
 ["victory hand: medium-light skin tone"]={ 0x270C, 0x1F3FC },
 ["video camera"]={ 0x1F4F9 },
 ["video game"]={ 0x1F3AE },
 ["videocassette"]={ 0x1F4FC },
 ["violin"]={ 0x1F3BB },
 ["virgo"]={ 0x264D },
 ["volcano"]={ 0x1F30B },
 ["volleyball"]={ 0x1F3D0 },
 ["vs button"]={ 0x1F19A },
 ["vulcan salute"]={ 0x1F596 },
 ["vulcan salute: dark skin tone"]={ 0x1F596, 0x1F3FF },
 ["vulcan salute: light skin tone"]={ 0x1F596, 0x1F3FB },
 ["vulcan salute: medium skin tone"]={ 0x1F596, 0x1F3FD },
 ["vulcan salute: medium-dark skin tone"]={ 0x1F596, 0x1F3FE },
 ["vulcan salute: medium-light skin tone"]={ 0x1F596, 0x1F3FC },
 ["waffle"]={ 0x1F9C7 },
 ["waning crescent moon"]={ 0x1F318 },
 ["waning gibbous moon"]={ 0x1F316 },
 ["warning"]={ 0x26A0, 0xFE0F },
 ["wastebasket"]={ 0x1F5D1, 0xFE0F },
 ["watch"]={ 0x231A },
 ["water buffalo"]={ 0x1F403 },
 ["water closet"]={ 0x1F6BE },
 ["water wave"]={ 0x1F30A },
 ["watermelon"]={ 0x1F349 },
 ["waving hand"]={ 0x1F44B },
 ["waving hand: dark skin tone"]={ 0x1F44B, 0x1F3FF },
 ["waving hand: light skin tone"]={ 0x1F44B, 0x1F3FB },
 ["waving hand: medium skin tone"]={ 0x1F44B, 0x1F3FD },
 ["waving hand: medium-dark skin tone"]={ 0x1F44B, 0x1F3FE },
 ["waving hand: medium-light skin tone"]={ 0x1F44B, 0x1F3FC },
 ["wavy dash"]={ 0x3030, 0xFE0F },
 ["waxing crescent moon"]={ 0x1F312 },
 ["waxing gibbous moon"]={ 0x1F314 },
 ["weary cat"]={ 0x1F640 },
 ["weary face"]={ 0x1F629 },
 ["wedding"]={ 0x1F492 },
 ["whale"]={ 0x1F40B },
 ["wheel of dharma"]={ 0x2638, 0xFE0F },
 ["wheelchair symbol"]={ 0x267F },
 ["white cane"]={ 0x1F9AF },
 ["white circle"]={ 0x26AA },
 ["white exclamation mark"]={ 0x2755 },
 ["white flag"]={ 0x1F3F3, 0xFE0F },
 ["white flower"]={ 0x1F4AE },
 ["white heart"]={ 0x1F90D },
 ["white large square"]={ 0x2B1C },
 ["white medium square"]={ 0x25FB, 0xFE0F },
 ["white medium-small square"]={ 0x25FD },
 ["white question mark"]={ 0x2754 },
 ["white small square"]={ 0x25AB, 0xFE0F },
 ["white square button"]={ 0x1F533 },
 ["wilted flower"]={ 0x1F940 },
 ["wind chime"]={ 0x1F390 },
 ["wind face"]={ 0x1F32C, 0xFE0F },
 ["window"]={ 0x1FA9F },
 ["wine glass"]={ 0x1F377 },
 ["winking face"]={ 0x1F609 },
 ["winking face with tongue"]={ 0x1F61C },
 ["wolf"]={ 0x1F43A },
 ["woman"]={ 0x1F469 },
 ["woman and man holding hands"]={ 0x1F46B },
 ["woman and man holding hands: dark skin tone"]={ 0x1F46B, 0x1F3FF },
 ["woman and man holding hands: dark skin tone, light skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["woman and man holding hands: dark skin tone, medium skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["woman and man holding hands: dark skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["woman and man holding hands: dark skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["woman and man holding hands: light skin tone"]={ 0x1F46B, 0x1F3FB },
 ["woman and man holding hands: light skin tone, dark skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["woman and man holding hands: light skin tone, medium skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["woman and man holding hands: light skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["woman and man holding hands: light skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["woman and man holding hands: medium skin tone"]={ 0x1F46B, 0x1F3FD },
 ["woman and man holding hands: medium skin tone, dark skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["woman and man holding hands: medium skin tone, light skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["woman and man holding hands: medium skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["woman and man holding hands: medium skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["woman and man holding hands: medium-dark skin tone"]={ 0x1F46B, 0x1F3FE },
 ["woman and man holding hands: medium-dark skin tone, dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["woman and man holding hands: medium-dark skin tone, light skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["woman and man holding hands: medium-dark skin tone, medium skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["woman and man holding hands: medium-dark skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FC },
 ["woman and man holding hands: medium-light skin tone"]={ 0x1F46B, 0x1F3FC },
 ["woman and man holding hands: medium-light skin tone, dark skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FF },
 ["woman and man holding hands: medium-light skin tone, light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FB },
 ["woman and man holding hands: medium-light skin tone, medium skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FD },
 ["woman and man holding hands: medium-light skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F468, 0x1F3FE },
 ["woman artist"]={ 0x1F469, 0x200D, 0x1F3A8 },
 ["woman artist: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F3A8 },
 ["woman artist: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F3A8 },
 ["woman artist: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F3A8 },
 ["woman artist: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F3A8 },
 ["woman artist: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F3A8 },
 ["woman astronaut"]={ 0x1F469, 0x200D, 0x1F680 },
 ["woman astronaut: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F680 },
 ["woman astronaut: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F680 },
 ["woman astronaut: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F680 },
 ["woman astronaut: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F680 },
 ["woman astronaut: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F680 },
 ["woman biking"]={ 0x1F6B4, 0x200D, 0x2640, 0xFE0F },
 ["woman biking: dark skin tone"]={ 0x1F6B4, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman biking: light skin tone"]={ 0x1F6B4, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman biking: medium skin tone"]={ 0x1F6B4, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman biking: medium-dark skin tone"]={ 0x1F6B4, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman biking: medium-light skin tone"]={ 0x1F6B4, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball"]={ 0x26F9, 0xFE0F, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball: dark skin tone"]={ 0x26F9, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball: light skin tone"]={ 0x26F9, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball: medium skin tone"]={ 0x26F9, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball: medium-dark skin tone"]={ 0x26F9, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman bouncing ball: medium-light skin tone"]={ 0x26F9, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing"]={ 0x1F647, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing: dark skin tone"]={ 0x1F647, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing: light skin tone"]={ 0x1F647, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing: medium skin tone"]={ 0x1F647, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing: medium-dark skin tone"]={ 0x1F647, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman bowing: medium-light skin tone"]={ 0x1F647, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling"]={ 0x1F938, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling: dark skin tone"]={ 0x1F938, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling: light skin tone"]={ 0x1F938, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling: medium skin tone"]={ 0x1F938, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling: medium-dark skin tone"]={ 0x1F938, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman cartwheeling: medium-light skin tone"]={ 0x1F938, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing"]={ 0x1F9D7, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing: dark skin tone"]={ 0x1F9D7, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing: light skin tone"]={ 0x1F9D7, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing: medium skin tone"]={ 0x1F9D7, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing: medium-dark skin tone"]={ 0x1F9D7, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman climbing: medium-light skin tone"]={ 0x1F9D7, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker"]={ 0x1F477, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker: dark skin tone"]={ 0x1F477, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker: light skin tone"]={ 0x1F477, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker: medium skin tone"]={ 0x1F477, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker: medium-dark skin tone"]={ 0x1F477, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman construction worker: medium-light skin tone"]={ 0x1F477, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman cook"]={ 0x1F469, 0x200D, 0x1F373 },
 ["woman cook: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F373 },
 ["woman cook: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F373 },
 ["woman cook: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F373 },
 ["woman cook: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F373 },
 ["woman cook: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F373 },
 ["woman dancing"]={ 0x1F483 },
 ["woman dancing: dark skin tone"]={ 0x1F483, 0x1F3FF },
 ["woman dancing: light skin tone"]={ 0x1F483, 0x1F3FB },
 ["woman dancing: medium skin tone"]={ 0x1F483, 0x1F3FD },
 ["woman dancing: medium-dark skin tone"]={ 0x1F483, 0x1F3FE },
 ["woman dancing: medium-light skin tone"]={ 0x1F483, 0x1F3FC },
 ["woman detective"]={ 0x1F575, 0xFE0F, 0x200D, 0x2640, 0xFE0F },
 ["woman detective: dark skin tone"]={ 0x1F575, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman detective: light skin tone"]={ 0x1F575, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman detective: medium skin tone"]={ 0x1F575, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman detective: medium-dark skin tone"]={ 0x1F575, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman detective: medium-light skin tone"]={ 0x1F575, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman elf"]={ 0x1F9DD, 0x200D, 0x2640, 0xFE0F },
 ["woman elf: dark skin tone"]={ 0x1F9DD, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman elf: light skin tone"]={ 0x1F9DD, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman elf: medium skin tone"]={ 0x1F9DD, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman elf: medium-dark skin tone"]={ 0x1F9DD, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman elf: medium-light skin tone"]={ 0x1F9DD, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming"]={ 0x1F926, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming: dark skin tone"]={ 0x1F926, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming: light skin tone"]={ 0x1F926, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming: medium skin tone"]={ 0x1F926, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming: medium-dark skin tone"]={ 0x1F926, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman facepalming: medium-light skin tone"]={ 0x1F926, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman factory worker"]={ 0x1F469, 0x200D, 0x1F3ED },
 ["woman factory worker: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F3ED },
 ["woman factory worker: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F3ED },
 ["woman factory worker: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F3ED },
 ["woman factory worker: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F3ED },
 ["woman factory worker: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F3ED },
 ["woman fairy"]={ 0x1F9DA, 0x200D, 0x2640, 0xFE0F },
 ["woman fairy: dark skin tone"]={ 0x1F9DA, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman fairy: light skin tone"]={ 0x1F9DA, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman fairy: medium skin tone"]={ 0x1F9DA, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman fairy: medium-dark skin tone"]={ 0x1F9DA, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman fairy: medium-light skin tone"]={ 0x1F9DA, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman farmer"]={ 0x1F469, 0x200D, 0x1F33E },
 ["woman farmer: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F33E },
 ["woman farmer: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F33E },
 ["woman farmer: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F33E },
 ["woman farmer: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F33E },
 ["woman farmer: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F33E },
 ["woman feeding baby"]={ 0x1F469, 0x200D, 0x1F37C },
 ["woman feeding baby: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F37C },
 ["woman feeding baby: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F37C },
 ["woman feeding baby: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F37C },
 ["woman feeding baby: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F37C },
 ["woman feeding baby: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F37C },
 ["woman firefighter"]={ 0x1F469, 0x200D, 0x1F692 },
 ["woman firefighter: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F692 },
 ["woman firefighter: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F692 },
 ["woman firefighter: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F692 },
 ["woman firefighter: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F692 },
 ["woman firefighter: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F692 },
 ["woman frowning"]={ 0x1F64D, 0x200D, 0x2640, 0xFE0F },
 ["woman frowning: dark skin tone"]={ 0x1F64D, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman frowning: light skin tone"]={ 0x1F64D, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman frowning: medium skin tone"]={ 0x1F64D, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman frowning: medium-dark skin tone"]={ 0x1F64D, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman frowning: medium-light skin tone"]={ 0x1F64D, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman genie"]={ 0x1F9DE, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no"]={ 0x1F645, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no: dark skin tone"]={ 0x1F645, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no: light skin tone"]={ 0x1F645, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no: medium skin tone"]={ 0x1F645, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no: medium-dark skin tone"]={ 0x1F645, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing no: medium-light skin tone"]={ 0x1F645, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok"]={ 0x1F646, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok: dark skin tone"]={ 0x1F646, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok: light skin tone"]={ 0x1F646, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok: medium skin tone"]={ 0x1F646, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok: medium-dark skin tone"]={ 0x1F646, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman gesturing ok: medium-light skin tone"]={ 0x1F646, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut"]={ 0x1F487, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut: dark skin tone"]={ 0x1F487, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut: light skin tone"]={ 0x1F487, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut: medium skin tone"]={ 0x1F487, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut: medium-dark skin tone"]={ 0x1F487, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman getting haircut: medium-light skin tone"]={ 0x1F487, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage"]={ 0x1F486, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage: dark skin tone"]={ 0x1F486, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage: light skin tone"]={ 0x1F486, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage: medium skin tone"]={ 0x1F486, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage: medium-dark skin tone"]={ 0x1F486, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman getting massage: medium-light skin tone"]={ 0x1F486, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing"]={ 0x1F3CC, 0xFE0F, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing: dark skin tone"]={ 0x1F3CC, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing: light skin tone"]={ 0x1F3CC, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing: medium skin tone"]={ 0x1F3CC, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing: medium-dark skin tone"]={ 0x1F3CC, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman golfing: medium-light skin tone"]={ 0x1F3CC, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman guard"]={ 0x1F482, 0x200D, 0x2640, 0xFE0F },
 ["woman guard: dark skin tone"]={ 0x1F482, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman guard: light skin tone"]={ 0x1F482, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman guard: medium skin tone"]={ 0x1F482, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman guard: medium-dark skin tone"]={ 0x1F482, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman guard: medium-light skin tone"]={ 0x1F482, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman health worker"]={ 0x1F469, 0x200D, 0x2695, 0xFE0F },
 ["woman health worker: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x2695, 0xFE0F },
 ["woman health worker: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x2695, 0xFE0F },
 ["woman health worker: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x2695, 0xFE0F },
 ["woman health worker: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x2695, 0xFE0F },
 ["woman health worker: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x2695, 0xFE0F },
 ["woman in lotus position"]={ 0x1F9D8, 0x200D, 0x2640, 0xFE0F },
 ["woman in lotus position: dark skin tone"]={ 0x1F9D8, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman in lotus position: light skin tone"]={ 0x1F9D8, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman in lotus position: medium skin tone"]={ 0x1F9D8, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman in lotus position: medium-dark skin tone"]={ 0x1F9D8, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman in lotus position: medium-light skin tone"]={ 0x1F9D8, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman in manual wheelchair"]={ 0x1F469, 0x200D, 0x1F9BD },
 ["woman in manual wheelchair: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9BD },
 ["woman in manual wheelchair: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9BD },
 ["woman in manual wheelchair: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9BD },
 ["woman in manual wheelchair: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9BD },
 ["woman in manual wheelchair: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9BD },
 ["woman in motorized wheelchair"]={ 0x1F469, 0x200D, 0x1F9BC },
 ["woman in motorized wheelchair: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9BC },
 ["woman in motorized wheelchair: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9BC },
 ["woman in motorized wheelchair: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9BC },
 ["woman in motorized wheelchair: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9BC },
 ["woman in motorized wheelchair: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9BC },
 ["woman in steamy room"]={ 0x1F9D6, 0x200D, 0x2640, 0xFE0F },
 ["woman in steamy room: dark skin tone"]={ 0x1F9D6, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman in steamy room: light skin tone"]={ 0x1F9D6, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman in steamy room: medium skin tone"]={ 0x1F9D6, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman in steamy room: medium-dark skin tone"]={ 0x1F9D6, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman in steamy room: medium-light skin tone"]={ 0x1F9D6, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo"]={ 0x1F935, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo: dark skin tone"]={ 0x1F935, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo: light skin tone"]={ 0x1F935, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo: medium skin tone"]={ 0x1F935, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo: medium-dark skin tone"]={ 0x1F935, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman in tuxedo: medium-light skin tone"]={ 0x1F935, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman judge"]={ 0x1F469, 0x200D, 0x2696, 0xFE0F },
 ["woman judge: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x2696, 0xFE0F },
 ["woman judge: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x2696, 0xFE0F },
 ["woman judge: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x2696, 0xFE0F },
 ["woman judge: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x2696, 0xFE0F },
 ["woman judge: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x2696, 0xFE0F },
 ["woman juggling"]={ 0x1F939, 0x200D, 0x2640, 0xFE0F },
 ["woman juggling: dark skin tone"]={ 0x1F939, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman juggling: light skin tone"]={ 0x1F939, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman juggling: medium skin tone"]={ 0x1F939, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman juggling: medium-dark skin tone"]={ 0x1F939, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman juggling: medium-light skin tone"]={ 0x1F939, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling"]={ 0x1F9CE, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling: dark skin tone"]={ 0x1F9CE, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling: light skin tone"]={ 0x1F9CE, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling: medium skin tone"]={ 0x1F9CE, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling: medium-dark skin tone"]={ 0x1F9CE, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman kneeling: medium-light skin tone"]={ 0x1F9CE, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights"]={ 0x1F3CB, 0xFE0F, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights: dark skin tone"]={ 0x1F3CB, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights: light skin tone"]={ 0x1F3CB, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights: medium skin tone"]={ 0x1F3CB, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights: medium-dark skin tone"]={ 0x1F3CB, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman lifting weights: medium-light skin tone"]={ 0x1F3CB, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman mage"]={ 0x1F9D9, 0x200D, 0x2640, 0xFE0F },
 ["woman mage: dark skin tone"]={ 0x1F9D9, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman mage: light skin tone"]={ 0x1F9D9, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman mage: medium skin tone"]={ 0x1F9D9, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman mage: medium-dark skin tone"]={ 0x1F9D9, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman mage: medium-light skin tone"]={ 0x1F9D9, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman mechanic"]={ 0x1F469, 0x200D, 0x1F527 },
 ["woman mechanic: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F527 },
 ["woman mechanic: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F527 },
 ["woman mechanic: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F527 },
 ["woman mechanic: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F527 },
 ["woman mechanic: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F527 },
 ["woman mountain biking"]={ 0x1F6B5, 0x200D, 0x2640, 0xFE0F },
 ["woman mountain biking: dark skin tone"]={ 0x1F6B5, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman mountain biking: light skin tone"]={ 0x1F6B5, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman mountain biking: medium skin tone"]={ 0x1F6B5, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman mountain biking: medium-dark skin tone"]={ 0x1F6B5, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman mountain biking: medium-light skin tone"]={ 0x1F6B5, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman office worker"]={ 0x1F469, 0x200D, 0x1F4BC },
 ["woman office worker: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F4BC },
 ["woman office worker: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F4BC },
 ["woman office worker: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F4BC },
 ["woman office worker: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F4BC },
 ["woman office worker: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F4BC },
 ["woman pilot"]={ 0x1F469, 0x200D, 0x2708, 0xFE0F },
 ["woman pilot: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x2708, 0xFE0F },
 ["woman pilot: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x2708, 0xFE0F },
 ["woman pilot: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x2708, 0xFE0F },
 ["woman pilot: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x2708, 0xFE0F },
 ["woman pilot: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x2708, 0xFE0F },
 ["woman playing handball"]={ 0x1F93E, 0x200D, 0x2640, 0xFE0F },
 ["woman playing handball: dark skin tone"]={ 0x1F93E, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman playing handball: light skin tone"]={ 0x1F93E, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman playing handball: medium skin tone"]={ 0x1F93E, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman playing handball: medium-dark skin tone"]={ 0x1F93E, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman playing handball: medium-light skin tone"]={ 0x1F93E, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo"]={ 0x1F93D, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo: dark skin tone"]={ 0x1F93D, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo: light skin tone"]={ 0x1F93D, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo: medium skin tone"]={ 0x1F93D, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo: medium-dark skin tone"]={ 0x1F93D, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman playing water polo: medium-light skin tone"]={ 0x1F93D, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer"]={ 0x1F46E, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer: dark skin tone"]={ 0x1F46E, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer: light skin tone"]={ 0x1F46E, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer: medium skin tone"]={ 0x1F46E, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer: medium-dark skin tone"]={ 0x1F46E, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman police officer: medium-light skin tone"]={ 0x1F46E, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting"]={ 0x1F64E, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting: dark skin tone"]={ 0x1F64E, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting: light skin tone"]={ 0x1F64E, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting: medium skin tone"]={ 0x1F64E, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting: medium-dark skin tone"]={ 0x1F64E, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman pouting: medium-light skin tone"]={ 0x1F64E, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand"]={ 0x1F64B, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand: dark skin tone"]={ 0x1F64B, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand: light skin tone"]={ 0x1F64B, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand: medium skin tone"]={ 0x1F64B, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand: medium-dark skin tone"]={ 0x1F64B, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman raising hand: medium-light skin tone"]={ 0x1F64B, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat"]={ 0x1F6A3, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat: dark skin tone"]={ 0x1F6A3, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat: light skin tone"]={ 0x1F6A3, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat: medium skin tone"]={ 0x1F6A3, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat: medium-dark skin tone"]={ 0x1F6A3, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman rowing boat: medium-light skin tone"]={ 0x1F6A3, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman running"]={ 0x1F3C3, 0x200D, 0x2640, 0xFE0F },
 ["woman running: dark skin tone"]={ 0x1F3C3, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman running: light skin tone"]={ 0x1F3C3, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman running: medium skin tone"]={ 0x1F3C3, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman running: medium-dark skin tone"]={ 0x1F3C3, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman running: medium-light skin tone"]={ 0x1F3C3, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman scientist"]={ 0x1F469, 0x200D, 0x1F52C },
 ["woman scientist: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F52C },
 ["woman scientist: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F52C },
 ["woman scientist: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F52C },
 ["woman scientist: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F52C },
 ["woman scientist: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F52C },
 ["woman shrugging"]={ 0x1F937, 0x200D, 0x2640, 0xFE0F },
 ["woman shrugging: dark skin tone"]={ 0x1F937, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman shrugging: light skin tone"]={ 0x1F937, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman shrugging: medium skin tone"]={ 0x1F937, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman shrugging: medium-dark skin tone"]={ 0x1F937, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman shrugging: medium-light skin tone"]={ 0x1F937, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman singer"]={ 0x1F469, 0x200D, 0x1F3A4 },
 ["woman singer: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F3A4 },
 ["woman singer: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F3A4 },
 ["woman singer: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F3A4 },
 ["woman singer: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F3A4 },
 ["woman singer: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F3A4 },
 ["woman standing"]={ 0x1F9CD, 0x200D, 0x2640, 0xFE0F },
 ["woman standing: dark skin tone"]={ 0x1F9CD, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman standing: light skin tone"]={ 0x1F9CD, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman standing: medium skin tone"]={ 0x1F9CD, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman standing: medium-dark skin tone"]={ 0x1F9CD, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman standing: medium-light skin tone"]={ 0x1F9CD, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman student"]={ 0x1F469, 0x200D, 0x1F393 },
 ["woman student: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F393 },
 ["woman student: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F393 },
 ["woman student: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F393 },
 ["woman student: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F393 },
 ["woman student: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F393 },
 ["woman superhero"]={ 0x1F9B8, 0x200D, 0x2640, 0xFE0F },
 ["woman superhero: dark skin tone"]={ 0x1F9B8, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman superhero: light skin tone"]={ 0x1F9B8, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman superhero: medium skin tone"]={ 0x1F9B8, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman superhero: medium-dark skin tone"]={ 0x1F9B8, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman superhero: medium-light skin tone"]={ 0x1F9B8, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain"]={ 0x1F9B9, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain: dark skin tone"]={ 0x1F9B9, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain: light skin tone"]={ 0x1F9B9, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain: medium skin tone"]={ 0x1F9B9, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain: medium-dark skin tone"]={ 0x1F9B9, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman supervillain: medium-light skin tone"]={ 0x1F9B9, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing"]={ 0x1F3C4, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing: dark skin tone"]={ 0x1F3C4, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing: light skin tone"]={ 0x1F3C4, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing: medium skin tone"]={ 0x1F3C4, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing: medium-dark skin tone"]={ 0x1F3C4, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman surfing: medium-light skin tone"]={ 0x1F3C4, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming"]={ 0x1F3CA, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming: dark skin tone"]={ 0x1F3CA, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming: light skin tone"]={ 0x1F3CA, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming: medium skin tone"]={ 0x1F3CA, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming: medium-dark skin tone"]={ 0x1F3CA, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman swimming: medium-light skin tone"]={ 0x1F3CA, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman teacher"]={ 0x1F469, 0x200D, 0x1F3EB },
 ["woman teacher: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F3EB },
 ["woman teacher: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F3EB },
 ["woman teacher: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F3EB },
 ["woman teacher: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F3EB },
 ["woman teacher: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F3EB },
 ["woman technologist"]={ 0x1F469, 0x200D, 0x1F4BB },
 ["woman technologist: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F4BB },
 ["woman technologist: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F4BB },
 ["woman technologist: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F4BB },
 ["woman technologist: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F4BB },
 ["woman technologist: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F4BB },
 ["woman tipping hand"]={ 0x1F481, 0x200D, 0x2640, 0xFE0F },
 ["woman tipping hand: dark skin tone"]={ 0x1F481, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman tipping hand: light skin tone"]={ 0x1F481, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman tipping hand: medium skin tone"]={ 0x1F481, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman tipping hand: medium-dark skin tone"]={ 0x1F481, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman tipping hand: medium-light skin tone"]={ 0x1F481, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire"]={ 0x1F9DB, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire: dark skin tone"]={ 0x1F9DB, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire: light skin tone"]={ 0x1F9DB, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire: medium skin tone"]={ 0x1F9DB, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire: medium-dark skin tone"]={ 0x1F9DB, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman vampire: medium-light skin tone"]={ 0x1F9DB, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman walking"]={ 0x1F6B6, 0x200D, 0x2640, 0xFE0F },
 ["woman walking: dark skin tone"]={ 0x1F6B6, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman walking: light skin tone"]={ 0x1F6B6, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman walking: medium skin tone"]={ 0x1F6B6, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman walking: medium-dark skin tone"]={ 0x1F6B6, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman walking: medium-light skin tone"]={ 0x1F6B6, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban"]={ 0x1F473, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban: dark skin tone"]={ 0x1F473, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban: light skin tone"]={ 0x1F473, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban: medium skin tone"]={ 0x1F473, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban: medium-dark skin tone"]={ 0x1F473, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman wearing turban: medium-light skin tone"]={ 0x1F473, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman with headscarf"]={ 0x1F9D5 },
 ["woman with headscarf: dark skin tone"]={ 0x1F9D5, 0x1F3FF },
 ["woman with headscarf: light skin tone"]={ 0x1F9D5, 0x1F3FB },
 ["woman with headscarf: medium skin tone"]={ 0x1F9D5, 0x1F3FD },
 ["woman with headscarf: medium-dark skin tone"]={ 0x1F9D5, 0x1F3FE },
 ["woman with headscarf: medium-light skin tone"]={ 0x1F9D5, 0x1F3FC },
 ["woman with veil"]={ 0x1F470, 0x200D, 0x2640, 0xFE0F },
 ["woman with veil: dark skin tone"]={ 0x1F470, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman with veil: light skin tone"]={ 0x1F470, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman with veil: medium skin tone"]={ 0x1F470, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman with veil: medium-dark skin tone"]={ 0x1F470, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman with veil: medium-light skin tone"]={ 0x1F470, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman with white cane"]={ 0x1F469, 0x200D, 0x1F9AF },
 ["woman with white cane: dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9AF },
 ["woman with white cane: light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9AF },
 ["woman with white cane: medium skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9AF },
 ["woman with white cane: medium-dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9AF },
 ["woman with white cane: medium-light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9AF },
 ["woman zombie"]={ 0x1F9DF, 0x200D, 0x2640, 0xFE0F },
 ["woman: bald"]={ 0x1F469, 0x200D, 0x1F9B2 },
 ["woman: blond hair"]={ 0x1F471, 0x200D, 0x2640, 0xFE0F },
 ["woman: curly hair"]={ 0x1F469, 0x200D, 0x1F9B1 },
 ["woman: dark skin tone"]={ 0x1F469, 0x1F3FF },
 ["woman: dark skin tone, bald"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9B2 },
 ["woman: dark skin tone, blond hair"]={ 0x1F471, 0x1F3FF, 0x200D, 0x2640, 0xFE0F },
 ["woman: dark skin tone, curly hair"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9B1 },
 ["woman: dark skin tone, red hair"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9B0 },
 ["woman: dark skin tone, white hair"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F9B3 },
 ["woman: light skin tone"]={ 0x1F469, 0x1F3FB },
 ["woman: light skin tone, bald"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9B2 },
 ["woman: light skin tone, blond hair"]={ 0x1F471, 0x1F3FB, 0x200D, 0x2640, 0xFE0F },
 ["woman: light skin tone, curly hair"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9B1 },
 ["woman: light skin tone, red hair"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9B0 },
 ["woman: light skin tone, white hair"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F9B3 },
 ["woman: medium skin tone"]={ 0x1F469, 0x1F3FD },
 ["woman: medium skin tone, bald"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9B2 },
 ["woman: medium skin tone, blond hair"]={ 0x1F471, 0x1F3FD, 0x200D, 0x2640, 0xFE0F },
 ["woman: medium skin tone, curly hair"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9B1 },
 ["woman: medium skin tone, red hair"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9B0 },
 ["woman: medium skin tone, white hair"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F9B3 },
 ["woman: medium-dark skin tone"]={ 0x1F469, 0x1F3FE },
 ["woman: medium-dark skin tone, bald"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9B2 },
 ["woman: medium-dark skin tone, blond hair"]={ 0x1F471, 0x1F3FE, 0x200D, 0x2640, 0xFE0F },
 ["woman: medium-dark skin tone, curly hair"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9B1 },
 ["woman: medium-dark skin tone, red hair"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9B0 },
 ["woman: medium-dark skin tone, white hair"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F9B3 },
 ["woman: medium-light skin tone"]={ 0x1F469, 0x1F3FC },
 ["woman: medium-light skin tone, bald"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9B2 },
 ["woman: medium-light skin tone, blond hair"]={ 0x1F471, 0x1F3FC, 0x200D, 0x2640, 0xFE0F },
 ["woman: medium-light skin tone, curly hair"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9B1 },
 ["woman: medium-light skin tone, red hair"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9B0 },
 ["woman: medium-light skin tone, white hair"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F9B3 },
 ["woman: red hair"]={ 0x1F469, 0x200D, 0x1F9B0 },
 ["woman: white hair"]={ 0x1F469, 0x200D, 0x1F9B3 },
 ["woman’s boot"]={ 0x1F462 },
 ["woman’s clothes"]={ 0x1F45A },
 ["woman’s hat"]={ 0x1F452 },
 ["woman’s sandal"]={ 0x1F461 },
 ["women holding hands"]={ 0x1F46D },
 ["women holding hands: dark skin tone"]={ 0x1F46D, 0x1F3FF },
 ["women holding hands: dark skin tone, light skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FB },
 ["women holding hands: dark skin tone, medium skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FD },
 ["women holding hands: dark skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FE },
 ["women holding hands: dark skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FF, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FC },
 ["women holding hands: light skin tone"]={ 0x1F46D, 0x1F3FB },
 ["women holding hands: light skin tone, dark skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FF },
 ["women holding hands: light skin tone, medium skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FD },
 ["women holding hands: light skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FE },
 ["women holding hands: light skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FB, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FC },
 ["women holding hands: medium skin tone"]={ 0x1F46D, 0x1F3FD },
 ["women holding hands: medium skin tone, dark skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FF },
 ["women holding hands: medium skin tone, light skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FB },
 ["women holding hands: medium skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FE },
 ["women holding hands: medium skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FD, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FC },
 ["women holding hands: medium-dark skin tone"]={ 0x1F46D, 0x1F3FE },
 ["women holding hands: medium-dark skin tone, dark skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FF },
 ["women holding hands: medium-dark skin tone, light skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FB },
 ["women holding hands: medium-dark skin tone, medium skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FD },
 ["women holding hands: medium-dark skin tone, medium-light skin tone"]={ 0x1F469, 0x1F3FE, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FC },
 ["women holding hands: medium-light skin tone"]={ 0x1F46D, 0x1F3FC },
 ["women holding hands: medium-light skin tone, dark skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FF },
 ["women holding hands: medium-light skin tone, light skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FB },
 ["women holding hands: medium-light skin tone, medium skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FD },
 ["women holding hands: medium-light skin tone, medium-dark skin tone"]={ 0x1F469, 0x1F3FC, 0x200D, 0x1F91D, 0x200D, 0x1F469, 0x1F3FE },
 ["women with bunny ears"]={ 0x1F46F, 0x200D, 0x2640, 0xFE0F },
 ["women wrestling"]={ 0x1F93C, 0x200D, 0x2640, 0xFE0F },
 ["women’s room"]={ 0x1F6BA },
 ["wood"]={ 0x1FAB5 },
 ["woozy face"]={ 0x1F974 },
 ["world map"]={ 0x1F5FA, 0xFE0F },
 ["worm"]={ 0x1FAB1 },
 ["worried face"]={ 0x1F61F },
 ["wrapped gift"]={ 0x1F381 },
 ["wrench"]={ 0x1F527 },
 ["writing hand"]={ 0x270D, 0xFE0F },
 ["writing hand: dark skin tone"]={ 0x270D, 0x1F3FF },
 ["writing hand: light skin tone"]={ 0x270D, 0x1F3FB },
 ["writing hand: medium skin tone"]={ 0x270D, 0x1F3FD },
 ["writing hand: medium-dark skin tone"]={ 0x270D, 0x1F3FE },
 ["writing hand: medium-light skin tone"]={ 0x270D, 0x1F3FC },
 ["yarn"]={ 0x1F9F6 },
 ["yawning face"]={ 0x1F971 },
 ["yellow circle"]={ 0x1F7E1 },
 ["yellow heart"]={ 0x1F49B },
 ["yellow square"]={ 0x1F7E8 },
 ["yen banknote"]={ 0x1F4B4 },
 ["yin yang"]={ 0x262F, 0xFE0F },
 ["yo-yo"]={ 0x1FA80 },
 ["zany face"]={ 0x1F92A },
 ["zebra"]={ 0x1F993 },
 ["zipper-mouth face"]={ 0x1F910 },
 ["zombie"]={ 0x1F9DF },
 ["zzz"]={ 0x1F4A4 },
}